<?php

/**
 * SomoThemes Theme specific functions.
 *
 * WARNING: DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
//* Define Theme Info Constants
define( 'SOMO_PARENT_THEME_NAME', 'Moderne Theme' );
define( 'SOMO_PARENT_THEME_SLUG', 'moderne-somo' );
define( 'SOMO_PARENT_THEME_URL', 'http://one.somothemes.com/themes/moderne/' );
define( 'SOMO_PARENT_THEME_VERSION', '1.0.0' );
define( 'SOMO_PARENT_THEME_BRANCH', '1.0' );
define( 'SOMO_PARENT_DB_VERSION', '1000' );
define( 'SOMO_THEME_RELEASE_DATE', date_i18n( 'F j, Y', '1390892505' ) );
//define( 'SOMO_PARENT_THEME_RELEASE_DATE', 'TBD' );

/**
 * Database upgrade function for Moderne Theme
 *
 * @since 1.0.0
 *
 * @see somo_upgrade_db function
 *
 */
function somo_upgrade_db_moderne_somo() {
	if ( genesis_get_option( 'db_version', null, false ) < '1000' ) {
		//* Update Settings
		_genesis_update_settings( array(
			'theme_version' => '1.0.0',
			'db_version' => '1000',
		) );
	}
}

//* Add external library credits
add_action( 'admin_init', 'moderne_somo_admin_init' );

function moderne_somo_admin_init() {
	add_filter( 'somo_get_credits_external_libraries', 'moderne_somo_get_credits_external_libraries', 10, 1 );
}

function moderne_somo_get_credits_external_libraries( array $external_libraries ) {
	$external_libraries[ ] = array(
		'name' => 'Backstretch',
		'web' => 'http://srobbin.com/jquery-plugins/backstretch/',
	);
	$external_libraries[ ] = array(
		'name' => 'Kelly Dwan & Mel Choyce',
		'web' => 'http://themes.redradar.net/',
		'extra' => __( '(Design Inspiration)', 'somo' ),
	);
	return $external_libraries;
}

/** Create theme color style options */
add_theme_support( 'genesis-style-selector', array(
	'moderne-somo-blue' => 'Blue',
	'moderne-somo-red' => 'Red',
	'moderne-somo-violet' => 'Violet',
	'moderne-somo-yellow' => 'Yellow',
	'moderne-somo-gray' => 'Gray',
	'moderne-somo-custom' => 'Custom',
) );


/** Create support for post formats */
add_theme_support( 'post-formats', array( 'aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video' ) );

//* Add Share buttons support
add_theme_support( 'somozine-share-buttons' );

/** Update theme support for menus */
remove_theme_support( 'genesis-menus' );
add_theme_support( 'genesis-menus', array(
	'primary' => __( 'Primary Navigation Menu', 'genesis' ),
	'mobile' => __( 'Mobile Navigation Menu', 'somo' ),
) );

/** Reposition the Primary Navigation */
remove_action( 'genesis_after_header', 'genesis_do_nav' );
add_action( 'genesis_header', 'genesis_do_nav' );

/** Add support for new image sizes */
add_image_size( 'featured-image', 535, 9999, FALSE );

/** Unregister Default widget areas */
remove_action( 'load-themes.php', 'genesis_remove_default_widgets_from_header_right' );

add_action( 'genesis_setup', 'moderne_remove_sidebars', 12 );

function moderne_remove_sidebars() {
	unregister_sidebar( 'header-right' );
	unregister_sidebar( 'sidebar-alt' );
}

add_action( 'genesis_setup', 'moderne_somo_remove_default_layouts' );

function moderne_somo_remove_default_layouts() {
	/* Remove layouts */
	genesis_unregister_layout( 'content-sidebar-sidebar' );
	genesis_unregister_layout( 'sidebar-sidebar-content' );
	genesis_unregister_layout( 'sidebar-content-sidebar' );
	genesis_unregister_layout( 'sidebar-content' );
}

remove_theme_support( 'genesis-footer-widgets' );

//* Reposition the footer
remove_action( 'genesis_footer', 'genesis_footer_markup_open', 5 );
remove_action( 'genesis_footer', 'genesis_do_footer' );
remove_action( 'genesis_footer', 'genesis_footer_markup_close', 15 );
add_action( 'genesis_after_content_sidebar_wrap', 'genesis_footer_markup_open' );
add_action( 'genesis_after_content_sidebar_wrap', 'genesis_do_footer' );
add_action( 'genesis_after_content_sidebar_wrap', 'genesis_footer_markup_close' );

//* Enqueue Google font
add_action( 'wp_enqueue_scripts', 'moderne_somo_google_fonts', 5 );

function moderne_somo_google_fonts() {

	wp_enqueue_style( 'google-font', '//fonts.googleapis.com/css?family=Open+Sans|Arimo:400,700', array( ), SOMO_PARENT_THEME_VERSION );
}

add_action( 'genesis_before_loop', 'moderne_before_loop' );

function moderne_before_loop() {
	if ( is_single() || is_home() || is_page_template( 'page_blog.php' ) || is_archive() ) {
		remove_action( 'genesis_entry_content', 'genesis_do_post_image', 8 );
		remove_action( 'genesis_entry_header', 'genesis_post_info', 12 );

		add_filter( 'moderne_somo_post_info_box', 'do_shortcode', 20 );
		add_action( 'genesis_entry_footer', 'moderne_somo_post_info_box', 8 );
		add_filter( 'genesis_post_author_posts_link_shortcode', 'somo_post_author_posts_link_shortcode', 10, 2 );
		add_filter( 'genesis_post_date_shortcode', 'somo_post_date_shortcode', 10, 2 );

		add_filter( 'moderne_somo_post_format_info', 'do_shortcode', 20 );
		add_action( 'genesis_entry_header', 'moderne_somo_post_format_info', 12 );
	}
}

function moderne_somo_post_format_info() {

	if ( false === get_post_format() ) {
		return;
	}

	$author = get_the_author();
	$url = get_author_posts_url( get_the_author_meta( 'ID' ) );
	$author_link = sprintf( '<span %s>', genesis_attr( 'entry-author' ) );
	$author_link .= $atts[ 'before' ];
	$author_link .= sprintf( '<a href="%s" %s>', $url, genesis_attr( 'entry-author-link' ) );
	$author_link .= sprintf( '<span %s>', genesis_attr( 'entry-author-name' ) );
	$author_link .= esc_html( $author );
	$author_link .= '</span></a>' . $atts[ 'after' ] . '</span>';

	$post_info = '<div class="author-info">' . $author_link . '</div>';

	$post_info .= '<div class="post-date">' . '[post_date]</div>';
	$post_info .= '<div class="clear"></div>';

	$post_info = apply_filters( 'moderne_somo_post_format_info', $post_info );
	genesis_markup( array(
		'html5' => sprintf( '<div class="entry-meta">%s</div>', $post_info ),
		'xhtml' => sprintf( '<div class="post-info">%s</div>', $post_info ),
	) );
}

function moderne_somo_post_info_box() {
	if ( false !== get_post_format() ) {
		$post_info = '<div class="author-info">[post_author_posts_link]</div>';
	} else {
		$post_info = '<div class="author-info">[post_author_posts_link]</div>';
		$post_info .= '<div class="post-date">' . '[post_date]</div>';
	}

	$post_info = apply_filters( 'moderne_somo_post_info_box', $post_info );
	genesis_markup( array(
		'html5' => sprintf( '<div class="entry-meta entry-meta-box">%s</div>', $post_info ),
		'xhtml' => sprintf( '<div class="post-info">%s</div>', $post_info ),
	) );
}

function somo_post_author_posts_link_shortcode( $output, $atts ) {
	$author = get_the_author();
	$url = get_author_posts_url( get_the_author_meta( 'ID' ) );


	$gravatar = sprintf( '<div class="author-image"><a href="%s" title="%s">%s</a><div class="clear"></div></div>', $url, $author, get_avatar( get_the_author_meta( 'email' ), 120 ) );

	$output = sprintf( '<div %s>', genesis_attr( 'entry-author' ) );
	$output .= $atts[ 'before' ];
	$output .= $gravatar;

	if ( false === get_post_format() ) {
		$output .= sprintf( '<a href="%s" %s>', $url, genesis_attr( 'entry-author-link' ) );
		$output .= sprintf( '<span %s>', genesis_attr( 'entry-author-name' ) );
		$output .= esc_html( $author );
		$output .= '</span>';
		$output .= '</a>';
	}

	$output .= $atts[ 'after' ] . '</div>';

	return apply_filters( 'somo_post_author_posts_link_shortcode', $output, $atts );
}

function somo_post_date_shortcode( $atts ) {

	$defaults = array(
		'after' => '',
		'before' => '',
		'format' => get_option( 'date_format' ),
		'label' => '',
	);

	$atts = shortcode_atts( $defaults, $atts, 'post_date' );

	$display = ( 'relative' === $atts[ 'format' ] ) ? genesis_human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) . ' ' . __( 'ago', 'genesis' ) : get_the_time( $atts[ 'format' ] );

	$output = sprintf( '<a href="%s" title="%s" rel="bookmark"><time %s>%s%s%s%s</time></a>', get_permalink(), the_title_attribute( 'echo=0' ), genesis_attr( 'entry-time' ), $atts[ 'before' ], $atts[ 'label' ], $display, $atts[ 'after' ] );

	return apply_filters( 'somo_post_date_shortcode', $output, $atts );
}

add_shortcode( 'somo_share_buttons', 'somo_share_buttons_shortcode' );

function somo_share_buttons_shortcode( $atts ) {

	$defaults = array(
		'after' => '',
		'before' => '',
	);

	$atts = shortcode_atts( $defaults, $atts, 'somo_share_buttons' );
	$img_url = genesis_get_image( array( 'format' => 'url', 'size' => 'full' ) );

	$output = sprintf( '%s', somozine_show_sharebuttons( $img_url ) );

	return apply_filters( 'somo_share_buttons_shortcode', $output, $atts );
}

add_filter( 'genesis_post_meta', 'somo_post_meta' );

function somo_post_meta() {
	global $post;

	if ( 'page' == get_post_type( $post->ID ) )
		return;

	$post_meta = sprintf( '[post_categories before=""] [post_tags before=""][post_comments before=""][post_edit][somo_share_buttons]' );
	return apply_filters( 'somo_post_meta', $post_meta );
}

//* Add support for custom background
add_theme_support( 'custom-background', array( 'wp-head-callback' => '__return_false' ) );

//* Load scripts and prepare images for loading
add_action( 'wp_enqueue_scripts', 'moderne_somo_enqueue_scripts' );

function moderne_somo_enqueue_scripts() {
	//* Load scripts only if custom background is being used
	if ( get_background_image() ) {
		wp_enqueue_script( 'somo-backstretch', SOMO_PARENT_URL . '/js/backstretch.js', array( 'jquery' ), SOMO_PARENT_THEME_VERSION );
		wp_enqueue_script( 'somo-backstretch-set', SOMO_PARENT_URL . '/js/backstretch-set.js', array( 'jquery', 'somo-backstretch' ), SOMO_PARENT_THEME_VERSION );

		wp_localize_script( 'somo-backstretch-set', 'BackStretchImg', array( 'src' => get_background_image() ) );
	}
}

//* Add support for custom header
add_theme_support( 'custom-header', array(
	'admin-preview-callback' => 'moderne_somo_admin_header_callback',
	'header-selector' => '.site-header .site-logo a img',
	'height' => 120,
	'width' => 120,
	'flex-height' => true,
	'flex-width' => true,
	'header-text' => false,
	'wp-head-callback' => 'moderne_somo_header_callback',
) );

function moderne_somo_admin_header_callback() {
	echo get_header_image() ? '<imgsrc="' . get_header_image() . '" />' : '<img alt="" src="' . SOMO_IMAGES_URL . '/logo.png' . '"  style="background:#f5f5f5;" />';
}

//* Hook site avatar before site title
add_action( 'genesis_header', 'moderne_somo_site_logo', 5 );

function moderne_somo_header_callback() {
	return;
}

function moderne_somo_site_logo() {

	$header_image = get_header_image() ? '<img alt="" src="' . get_header_image() . '" />' : '<img alt="" src="' . SOMO_IMAGES_URL . '/logo.png' . '" />';
	printf( '<div class="site-logo"><a href="%s">%s</a></div>', home_url( '/' ), $header_image );
}

add_action( 'genesis_before_loop', 'moderne_somo_before_loop' );

function moderne_somo_before_loop() {
	if ( is_home() || is_archive() || is_page_template( 'page_blog.php' ) ) {
		if ( is_page_template() ) {
			global $somo;
			$custom_field = genesis_get_custom_field( '_genesis_layout' );
			$somo[ 'page_layout' ] = $custom_field ? $custom_field : genesis_get_option( 'site_layout' );
		}
		remove_action( 'genesis_entry_content', 'genesis_do_post_image', 8 );
		add_action( 'genesis_entry_content', 'moderne_somo_do_post_image', 8 );
	}
}

function moderne_somo_do_post_image() {
	global $somo;
	if ( has_post_thumbnail() && genesis_get_option( 'content_archive_thumbnail' ) && !(has_post_format( 'gallery' )) ) {

		if ( isset( $somo[ 'page_layout' ] ) ) {
			$layout = esc_attr( $somo[ 'page_layout' ] );
		} else {
			$layout = genesis_site_layout( 0 );
		}

		switch ( $layout ) {
			case 'content-sidebar':
				$size = 'featured-image';
				break;

			case 'full-width-content':
			default:
				$size = 'large';
				break;
		}

		$img = genesis_get_image( array(
			'format' => 'html',
			'size' => $size,
			'context' => '',
			'attr' => genesis_parse_attr( 'entry-image' ),
			) );

		if ( !empty( $img ) ) {
			printf( '<div class="featured-image"><a href="%s" title="%s" class="post-image-link">%s</a><div class="clear"></div></div>', get_permalink(), the_title_attribute( 'echo=0' ), $img );
		}
	}
}

/* Display no social title */
add_filter( 'somo_get_author_box_social_title', 'writer_somo_get_author_box_social_title', 10, 4 );

function writer_somo_get_author_box_social_title( $html, $title, $author_id, $context ) {
	return '';
}

function somozine_show_sharebuttons( $img_url = '' ) {
	global $post;

	if ( !current_theme_supports( 'somozine-share-buttons' ) ) {
		return;
	}

	$url = get_permalink();
	$title = the_title_attribute( 'echo=0' );

	$html = '<div class="entry-meta social-actions"><ul>';
	$html .= '<li class="social-action social-action-twitter">' . '<a href="https://twitter.com/share?url=' . urlencode( $url ) . '&counturl=' . urlencode( $url ) . '&text=' . $title . '" onclick="window.open(this.href, \'popupwindow\', \'width=550,height=420,scrollbars,resizable\'); return false;"></a>' . '</li>';
	$html .= '<li class="social-action social-action-facebook">' . '<a href="http://www.facebook.com/sharer.php?u=' . urlencode( $url ) . '&t=' . $title . '" onclick="window.open(this.href, \'popupwindow\', \'width=655,height=380,scrollbars,resizable\'); return false;"></a>' . '</li>';
	$html .= '<li class="social-action social-action-googleplus">' . '<a href="https://plus.google.com/share?url=' . urlencode( $url ) . '" onclick="window.open(this.href, \'popupwindow\', \'width=495,height=440,scrollbars,resizable\'); return false;"></a>' . '</li>';
	if ( $img_url ) {
		$html .= '<li class="social-action social-action-pinterest">' . '<a href="http://pinterest.com/pin/create/button/?url=' . urlencode( $url ) . '&media=' . urlencode( $img_url ) . '&description=' . $title . '" onclick="window.open(this.href, \'popupwindow\', \'width=670,height=300,scrollbars,resizable\'); return false;"></a>' . '</li>';
	}
	$html .= '</ul></div>';

	return apply_filters( 'somozine_show_sharebuttons', $html, $img_url, $post );
}
