<?php
/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */

/**
 * Registers a new admin page, providing content and corresponding menu item for the "What's new" page.
 *
 * @package Genesis\Admin
 *
 * @since 1.0.0
 */
class Somo_Admin_About extends Genesis_Admin_Basic {

	/**
	 * Create the page.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		$page_id = 'somo-about';

		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => 'admin.php',
				'menu_title' => '',
				'page_title' => __( 'About SomoThemes', 'somo' ),
			)
		);

		$this->create( $page_id, $menu_ops );

		add_action( 'admin_enqueue_scripts', 'add_thickbox' );
	}

	/**
	 * Callback for displaying the What's New admin page.
	 *
	 * @since 1.0.0
	 */
	public function admin() {
		?>
		<div class="wrap about-wrap">

			<img src="<?php echo get_template_directory_uri() . '/lib/admin/images/somo-badge.png'; ?>" class="alignright whats-new" />

			<h1><?php echo esc_html( sprintf( __( 'Welcome to %s %s', 'somo' ), SOMO_PARENT_THEME_NAME, SOMO_PARENT_THEME_BRANCH ) ); ?></h1>

			<div class="about-text"><?php printf( __( 'Thank you for choosing SomoThemes. Every SomoTheme makes your website social and mobile friendly.', 'somo' ), 'SomoThemes' ); ?></div>
			<h2 class="nav-tab-wrapper">
				<a href="<?php menu_page_url( 'somo-welcome' ); ?>" class="nav-tab">
					<?php _e( 'Getting Started', 'somo' ); ?>
				</a><a href="<?php menu_page_url( 'somo-about' ); ?>" class="nav-tab nav-tab-active">
					<?php _e( 'About' ); ?>
				</a>
			</h2>

			<?php
			$new_features_content = somo_get_new_features();

			if ( $new_features_content[ 'data' ] && !empty( $new_features_content[ 'data' ] ) ) {
				?>
				<div class="changelog">
					<?php if ( $new_features_content[ 'tagline' ] && !empty( $new_features_content[ 'tagline' ] ) ) { ?>
						<p class="about-description"><?php echo esc_html( $new_features_content[ 'tagline' ] ); ?></p>
					<?php } ?>
					<div class="feature-section">
						<?php foreach ( $new_features_content[ 'data' ] as $data ) { ?>
							<h4><?php echo wp_kses_post( $data[ 'title' ] ); ?></h4>
							<p><?php echo wp_kses_post( $data[ 'content' ] ); ?></p>
						<?php } ?>
					</div>
				</div>
				<?php
			}
			?>

			<?php
			$credits = somo_get_credits();
			if ( $credits && !empty( $credits ) ) {
				?>
				<div class="credits">
					<p class="about-description"><?php _e( 'SomoThemes software is built by a team of creative individuals.', 'somo' ); ?></p>
					<?php
					$gravatar = is_ssl() ? 'https://secure.gravatar.com/avatar/' : 'http://0.gravatar.com/avatar/';
					$size = '120';
					foreach ( $credits[ 'groups' ] as $group_slug => $group_data ) {
						echo '<h4 class="wp-people-group">' . $group_data[ 'name' ] . "</h4>\n";

						if ( !empty( $group_data[ 'shuffle' ] ) )
							shuffle( $group_data[ 'data' ] );

						switch ( $group_data[ 'type' ] ) {
							case 'libraries' :
								array_walk( $group_data[ 'data' ], 'somo_credits_build_object_link' );
								echo '<p class="wp-credits-list">' . wp_sprintf( '%l.', $group_data[ 'data' ] ) . "</p>\n\n";
								break;
							default:
								$classes = 'wp-people-group wp-people-group-' . $group_slug;
								echo '<ul class="' . $classes . '">' . "\n";
								foreach ( $group_data[ 'data' ] as $person_data ) {
									echo '<li class="wp-person" id="wp-person-' . $person_data[ 'slug' ] . '">' . "\n\t";
									if ( isset( $person_data[ 'web' ] ) && !empty( $person_data[ 'web' ] ) ) {
										echo '<a href="' . esc_url( $person_data[ 'web' ] ) . '">';
										echo '<img src="' . $gravatar . $person_data[ 'gravatar' ] . '?s=' . $size . '" class="gravatar" alt="' . esc_attr( $person_data[ 'name' ] ) . '" /></a>' . "\n\t";
										echo '<a class="web" href="' . esc_url( $person_data[ 'web' ] ) . '">' . $person_data[ 'name' ] . "</a>\n\t";
										echo '<span class="title">' . translate( $person_data[ 'title' ] ) . "</span>\n";
									} else {
										echo '<img src="' . $gravatar . $person_data[ 'gravatar' ] . '?s=' . $size . '" class="gravatar" alt="' . esc_attr( $person_data[ 'name' ] ) . '" />' . "\n\t";
										echo '<div class="web">' . $person_data[ 'name' ] . '</div>' . "\n\t";
										echo '<span class="title">' . translate( $person_data[ 'title' ] ) . "</span>\n";
									}
									echo "</li>\n";
								}
								echo "</ul>\n";
								break;
						}
					}
					?>
				</div>
				<?php
			}
			?>
			<div class="somo-freedoms">
				<p class="about-description"><?php printf( __( 'We embrace your freedom.' ) ); ?></p>
				<p><?php printf( __( 'Just like WordPress, all our themes are Free, open source and come with some awesome, worldview-changing rights courtesy of its <a href="%s">license</a>, the GPL. All our themes are 100%% GPL, including artwork and CSS.' ), 'http://www.gnu.org/licenses/gpl-2.0.html' ); ?></p>
				<ol start="0">
					<li><p><?php _e( 'You have the freedom to run the program, for any purpose.' ); ?></p></li>
					<li><p><?php _e( 'You have access to the source code, the freedom to study how the program works, and the freedom to change it to make it do what you wish.' ); ?></p></li>
					<li><p><?php _e( 'You have the freedom to redistribute copies of the original program so you can help your neighbor.' ); ?></p></li>
					<li><p><?php _e( 'You have the freedom to distribute copies of your modified versions to others. By doing this you can give the whole community a chance to benefit from your changes. At the same time, we do expect that our branding including trademarks and logos are respected, and not misused.' ); ?></p></li>
				</ol>
				<p><?php _e( 'WordPress grows when people like you tell their friends about it, and the thousands of businesses and services that are built on and around WordPress share that fact with their users. We are doing our bit.' ); ?></p>
				<p><?php _e( 'Don&#8217;t you wish all software came with these freedoms? So do we! For more information, check out the <a href="http://www.fsf.org/">Free Software Foundation</a>.' ); ?></p>
			</div>
		</div>
		<?php
	}

}

