<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
remove_action( 'after_setup_theme', 'genesis_add_admin_menu' );
add_action( 'after_setup_theme', 'somo_add_admin_menu' );

/**
 * Add SomoThemes top-level item in admin menu.
 *
 * Calls the `genesis_admin_menu hook` at the end - all submenu items should be attached to that hook to ensure
 * correct ordering.
 *
 * @since 1.0.0
 *
 * @global \Genesis_Admin_Settings _genesis_admin_settings          Theme Settings page object.
 * @global string                  _genesis_theme_settings_pagehook Old backwards-compatible pagehook.
 *
 * @return null Returns null if Genesis menu is disabled, or disabled for current user
 */
function somo_add_admin_menu() {

	if ( !is_admin() )
		return;

	global $_genesis_admin_settings;

	if ( !current_theme_supports( 'genesis-admin-menu' ) )
		return;

	//* Don't add menu item if disabled for current user
	$user = wp_get_current_user();
	if ( !get_the_author_meta( 'genesis_admin_menu', $user->ID ) )
		return;

	$_genesis_admin_settings = new Somo_Admin_Settings;

	//* Set the old global pagehook var for backward compatibility
	global $_genesis_theme_settings_pagehook;
	$_genesis_theme_settings_pagehook = $_genesis_admin_settings->pagehook;

	do_action( 'genesis_admin_menu' );
}

remove_action( 'genesis_admin_menu', 'genesis_add_admin_submenus' );
add_action( 'genesis_admin_menu', 'somo_add_admin_submenus' );

/**
 * Add submenu items under Genesis item in admin menu.
 *
 * @since 1.0.0
 *
 * @see Genesis_Admin_SEO_Settings SEO Settings class
 * @see Genesis_Admin_Import_export Import / Export class
 * @see Somo_Admin_Social_Settings Social Settings class
 * @see Somo_Admin_Quick_Setup Quick Setup class
 * @see Genesis_Admin_Readme Readme class
 *
 * @global object $_genesis_admin_seo_settings
 * @global object $_genesis_admin_import_export
 * @global object $_somo_admin_social_settings
 * @global object $_somo_admin_quick_setup
 * @global object $_genesis_admin_readme
 *
 * @return null Returns null if Genesis menu is disabled
 */
function somo_add_admin_submenus() {

	//* Do nothing, if not viewing the admin
	if ( !is_admin() )
		return;

	// global $_genesis_admin_readme;
	global $_genesis_admin_seo_settings, $_genesis_admin_import_export, $_somo_admin_social_settings, $_somo_admin_quick_setup;

	//* Don't add submenu items if Genesis menu is disabled
	if ( !current_theme_supports( 'genesis-admin-menu' ) )
		return;

	$user = wp_get_current_user();

	//* Add "Social Settings" submenu item
	if ( current_theme_supports( 'somo-social-settings-menu' ) && get_the_author_meta( 'somo_social_settings_menu', $user->ID ) ) {
		$_somo_admin_social_settings = new Somo_Admin_Social_Settings;
	}

	//* Add "SEO Settings" submenu item
	if ( current_theme_supports( 'genesis-seo-settings-menu' ) && get_the_author_meta( 'genesis_seo_settings_menu', $user->ID ) ) {
		$_genesis_admin_seo_settings = new Somo_Admin_SEO_Settings;

		//* set the old global pagehook var for backward compatibility
		global $_genesis_seo_settings_pagehook;
		$_genesis_seo_settings_pagehook = $_genesis_admin_seo_settings->pagehook;
	}

	/*
	  //* Add "Import/Export" submenu item
	  if ( current_theme_supports( 'genesis-import-export-menu' ) && get_the_author_meta( 'genesis_import_export_menu', $user->ID ) )
	  $_genesis_admin_import_export = new Somo_Admin_Import_Export;
	 */

	//* Add "Quick Setup" submenu item
	if ( current_theme_supports( 'somo-quick-setup-menu' ) && get_the_author_meta( 'somo_quick_setup_menu', $user->ID ) )
		$_somo_admin_quick_setup = new Somo_Admin_Quick_Setup;

	//* Add the welcome page
	new Somo_Admin_Welcome;

	//* Add the about page
	new Somo_Admin_About;
}

remove_action( 'admin_menu', 'genesis_add_cpt_archive_page', 5 );
add_action( 'admin_menu', 'somo_add_cpt_archive_page', 5 );

/**
 * Add archive settings page to relevant custom post type registrations.
 *
 * An instance of `Genesis_Admin_CPT_Archive_Settings` is instantiated for each relevant CPT, assigned to an individual
 * global variable.
 *
 * @since 1.0.0
 *
 * @uses \Somo_Admin_CPT_Archive_Settings	     CPT Archive Settings page class.
 * @uses genesis_get_cpt_archive_types()         Get list of custom post types which need an archive settings page.
 * @uses genesis_has_post_type_archive_support() Check post type has archive support.
 */
function somo_add_cpt_archive_page() {
	$post_types = genesis_get_cpt_archive_types();

	foreach ( $post_types as $post_type ) {
		if ( genesis_has_post_type_archive_support( $post_type->name ) ) {
			$admin_object_name = '_genesis_admin_cpt_archives_' . $post_type->name;
			global ${$admin_object_name};
			${$admin_object_name} = new Somo_Admin_CPT_Archive_Settings( $post_type );
		}
	}
}

