<?php
/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 *
 * Credits:
 * Widget import/export functions have been adapted from Widget Data - Setting Import/Export Plugin
 * created by http://vocecommunications.com
 */

/**
 * Registers a new admin page, providing content and corresponding menu item for the Quick Setup page.
 *
 * @package Somo\Admin
 *
 * @since 1.0.0
 */
class Somo_Admin_Quick_Setup extends Genesis_Admin_Boxes {

	/**
	 * Create an admin menu item and settings page.
	 *
	 * @since 1.0.0
	 *
	 * @uses SOMO_QUICK_SETUP_SETTINGS_FIELD Settings field key.
	 * @uses \Genesis_Admin::create()   Create an admin menu item and settings page.
	 */
	function __construct() {

		$page_id = 'somo-quick-setup';

		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => 'genesis',
				'page_title' => __( 'SomoThemes - Quick Setup Tools', 'somo' ),
				'menu_title' => __( 'Quick Setup', 'somo' )
			)
		);

		$page_ops = array(
			'screen_icon' => 'somo-screen-icon',
			'save_button_text' => __( 'Save Settings', 'genesis' ),
			'reset_button_text' => __( 'Reset Settings', 'genesis' ),
			'saved_notice_text' => __( 'Settings saved.', 'genesis' ),
			'reset_notice_text' => __( 'Settings reset.', 'genesis' ),
			'error_notice_text' => __( 'Error saving settings.', 'genesis' ),
		);

		$settings_field = SOMO_QUICK_SETUP_SETTINGS_FIELD;

		$default_settings = apply_filters(
			'somo_social_settings_defaults', array(
			'imported_cats' => array( ),
			'imported_tags' => array( ),
			'imported_terms' => array( ),
			'imported_nav_menus' => array( ),
			'imported_posts' => array( ),
			'imported_nav_menu_items' => array( ),
			)
		);

		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );

		add_action( 'genesis_settings_sanitizer_init', array( $this, 'sanitizer_filters' ) );

		add_action( 'admin_init', array( $this, 'oneclick_setup' ) );
		add_action( 'admin_init', array( $this, 'oneclick_cleanup' ) );
		add_action( 'admin_init', array( $this, 'import' ) );
		add_action( 'admin_init', array( $this, 'export' ) );
		add_action( 'admin_init', array( $this, 'export_widgets' ) );
		add_action( 'admin_init', array( $this, 'import_widgets' ) );
	}

	/**
	 * Register each of the settings with a sanitization filter type.
	 *
	 * @since 1.0.0
	 *
	 * @uses genesis_add_option_filter() Assign filter to array of settings.
	 *
	 * @see \Genesis_Settings_Sanitizer::add_filter() Add sanitization filters to options.
	 */
	public function sanitizer_filters() {
		//* Nothing here yet
	}

	/**
	 * Contextual help content.
	 *
	 * @since 1.0.0
	 */
	public function help() {

		$screen = get_current_screen();

		$quicksetup_help =
			'<h3>' . __( 'Quick Setup Tools', 'somo' ) . '</h3>' .
			'<p>' . __( 'SomoThemes provide a set of productivity tools to help you get started with the theme setup quickly.', 'somo' ) . '</p>' .
			'<p>' . sprintf( __( 'There are four types of tools: %s', 'somo' ), sprintf( '<ul><li>%s</li><li>%s</li><li>%s</li><li>%s</li></ul>', __( '<strong>One Click Setup</strong> - allows you to setup your site with sample content and settings by importing sample data shipped with the theme', 'somo' ), __( '<strong>One Click Cleanup</strong> - allows you to cleanup any content or settings that were previously imported using one of the quick setup tools', 'somo' ), __( '<strong>Import Tools</strong> - allows you to import theme settings and widgets you\'ve previously exported', 'somo' ), __( '<strong>Export Tools</strong> - allows you to export theme settings and widgets to your local computer', 'somo' ) ) ) . '</p>' .
			'<p>' . __( 'Learn about each of these tools via menu tabs on the left side.', 'somo' ) . '</p>';

		$oneclick_setup_help =
			'<h3>' . __( 'One Click Setup', 'somo' ) . '</h3>' .
			'<p>' . __( 'This tool allows you to setup your site with sample content and settings by importing sample data shipped with the theme.', 'somo' ) . '</p>' .
			'<p>' . __( 'Simply click on the "Run One Click Setup" button to begin one click setup. Choosing Customize Setup option allows you to customize options before importing sample content and settings. These options have been described below:', 'somo' ) . '</p>' .
			'<ol><li><strong>' . __( 'Import Sample Content', 'somo' ) . '</strong> - ' . __( 'Imports posts, pages, categories, tags, terms, media, and custom post types if any.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Import Navigation Menus and Setup Theme Locations', 'somo' ) . '</strong> - ' . __( 'Imports navigation menus and attempts to set them up at appropriate locations. Menus will be imported only if you have chosen to import sample content (option 1 above).', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Replace/Overwrite a Navigation Menu if it already exists', 'somo' ) . '</strong> - ' . __( 'If a navigation menu with the same name (slug) already exists or was previously imported, choosing this option will replace that old menu with new one. If the option is unchecked then the old and new menus will be merged together to contain menu items from both the menus. This option is only applicable if you have chosen to import navigation menus (option 2 above).', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Import Sample Widgets', 'somo' ) . '</strong> - ' . __( 'Imports sample widgets into theme\'s widget areas. Any existing widgets will be moved to Inactive Widgets section unless you have chosen to delete all inactive widgets (option 5).', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Delete All Inactive Widgets', 'somo' ) . '</strong> - ' . __( 'Deletes all widgets from the Inactive Widgets section. This cannot be undone.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Import Theme Settings', 'somo' ) . '</strong> - ' . __( 'Imports sample Theme settings. This cannot be undone. Imported settings can still be reset to default values using the cleanup tool.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Import Social Settings', 'somo' ) . '</strong> - ' . __( 'Imports sample Social settings. This cannot be undone. Imported settings can still be reset to default values using the cleanup tool.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Import SEO Settings', 'somo' ) . '</strong> - ' . __( 'Imports sample SEO settings. This cannot be undone. Imported settings can still be reset to default values using the cleanup tool.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Show Verbose Messages', 'somo' ) . '</strong> - ' . __( 'Displays detailed status messages during One Click Setup execution.', 'somo' ) . '</li></ol>' .
			'<p>' . __( 'Certain tasks are NOT performed by this tool and you may have to do them manually. Some of these tasks may be:', 'somo' ) . '</p>' .
			'<ul><li>' . __( 'Installing any plugins', 'somo' ) . '</li>' .
			'<li>' . __( 'Adding header or background images', 'somo' ) . '</li>' .
			'<li>' . __( 'Configuring WordPress settings', 'somo' ) . '</li>' .
			'<li>' . __( 'Adding users or configuring user-specific metadata information', 'somo' ) . '</li>' .
			'<li>' . __( 'Configuring term-specific information (i.e. metadata related to categories, tags, etc.) ', 'somo' ) . '</li></ul>' .
			'<p>' . sprintf( __( 'To learn more about recommended plugins and steps to configure these settings, please visit the Getting Started help page for this theme in your %s.', 'somo' ), sprintf( '<a href="%s" target="_blank">%s</a>', somo_get_membersite_url(), __( 'SomoThemes account', 'somo' ) ) ) . '</p>';


		$oneclick_cleanup_help =
			'<h3>' . __( 'One Click Cleanup', 'somo' ) . '</h3>' .
			'<p>' . __( 'This tool allows you to cleanup any content or settings that were previously imported using one of the quick setup tools.', 'somo' ) . '</p>' .
			'<p>' . __( 'Simply click on the "Run One Click Cleanup" button to begin one click cleanup. Choosing Customize Cleanup option allows you to customize options before running the cleanup. These options have been described below:', 'somo' ) . '</p>' .
			'<ol><li><strong>' . __( 'Delete Imported Posts, Pages, Media, and Custom Post Types', 'somo' ) . '</strong> - ' . __( 'Deletes previously imported posts, pages, media, and custom post types if any.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Delete Imported Navigation Menus', 'somo' ) . '</strong> - ' . __( 'Deletes previously imported navigation menus. This will also delete navigation menu items contained in the deleted menu.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Delete Navigation Menu Items Only', 'somo' ) . '</strong> - ' . __( 'Deletes previously imported navigation menu items, but retains the navigation menu itself. If the menu is assigned to a theme location, the assignment is also kept intact. This option will be ignored if you have chosen to delete imported navigation menus (option 2 above).', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Delete Imported Categories, Tags, and Terms', 'somo' ) . '</strong> - ' . __( 'Deletes previously imported categories, tags, and custom taxonomy terms.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Move All Active Widgets to Inactive Widgets area', 'somo' ) . '</strong> - ' . __( 'Removes all active widgets from the widget areas and places them inside the Inactive Widgets section so that you can reuse them later if needed.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Delete All Inactive Widgets', 'somo' ) . '</strong> - ' . __( 'Deletes all widgets from the Inactive Widgets section. This cannot be undone.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Reset Theme Settings', 'somo' ) . '</strong> - ' . __( 'Resets Theme settings to their default values.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Reset Social Settings', 'somo' ) . '</strong> - ' . __( 'Resets Social settings to their default values.', 'somo' ) . '</li>' .
			'<li><strong>' . __( 'Reset SEO Settings', 'somo' ) . '</strong> - ' . __( 'Resets SEO settings to their default values.', 'somo' ) . '</li></ol>';

		$import_help =
			'<h3>' . __( 'Import Tools', 'somo' ) . '</h3>' .
			'<p>' . __( 'These tools allow you to import theme settings and widgets you\'ve previously exported. This is specific to Theme-related settings and does not includes posts, pages, or images, which is what the built-in WordPress import/export menu does. It also does not include other settings for plugins, or post/page/term/user specific settings.', 'somo' ) . '</p>' .
			'<h4>' . __( 'Import Theme Settings', 'somo' ) . '</h4>' .
			'<p>' . sprintf( __( 'This allows you to import a file you\'ve previously exported. The file name generally starts with %s followed by one or more strings indicating which settings it contains, finally followed by the date and time it was exported.', 'somo' ), genesis_code( '<theme_name>-' ) ) . '</p>' .
			'<p>' . __( 'Once you upload an import file, it will automatically overwrite your existing settings.', 'somo' ) . __( 'This cannot be undone. Imported settings can still be reset to default values using the cleanup tool.', 'somo' ) . '</p>' .
			'<h4>' . __( 'Import Widget Settings', 'somo' ) . '</h4>' .
			'<p>' . __( 'This tool allows you to import a widget settings file you\'ve previously exported.', 'somo' ) . '</p>' .
			'<p>' . __( 'Once you upload an import file, it will create new widgets from the file after moving any existing widgets to Inactive widgets section. All inactive widgets will be deleted if you select "Delete all inactive widgets" option.', 'somo' );

		$export_help =
			'<h3>' . __( 'Export Tools', 'somo' ) . '</h3>' .
			'<p>' . __( 'These tools allow you to export theme-related settings and widgets to your local computer so you can back them up, or copy them to another site. The settings are exported in JSON format.', 'somo' ) . '</p>' .
			'<h4>' . __( 'Export Theme Settings', 'somo' ) . '</h4>' .
			'<p>' . __( 'This tool allows you to export your Theme-related settings to your computer.', 'somo' ) . '</p>' .
			'<p>' . sprintf( __( 'Choose the settings you wish to export and click the download button. A data file (%s) will then be generated for you to save to your computer. Once you have saved the downloaded file, you can use the import tool on another site to import this data.', 'somo' ), genesis_code( '.json' ) ) . '</p>' .
			'<h4>' . __( 'Export Widget Settings', 'somo' ) . '</h4>' .
			'<p>' . __( 'This tool allows you to export active widgets settings to your computer.', 'somo' ) . '</p>' .
			'<p>' . sprintf( __( 'Click the download button to run the exporter. A data file (%s) will then be generated for you to save to your computer. Once you have saved the downloaded file, you can use the widget settings import tool on another site to import this data.', 'somo' ), genesis_code( '.json' ) ) . '</p>';

		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-$quicksetup',
			'title' => __( 'Introduction', 'somo' ),
			'content' => $quicksetup_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-oneclick_setup',
			'title' => __( 'One Click Setup', 'somo' ),
			'content' => $oneclick_setup_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-oneclick_cleanup',
			'title' => __( 'One Click Cleanup', 'somo' ),
			'content' => $oneclick_cleanup_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-import_help',
			'title' => __( 'Import Tools', 'somo' ),
			'content' => $import_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-export_help',
			'title' => __( 'Export Tools', 'somo' ),
			'content' => $export_help,
		) );

		//* Add help sidebar
		$screen->set_help_sidebar(
			'<p><strong>' . __( 'For more information:', 'somo' ) . '</strong></p>' .
			'<p><a href="http://somothemes.com/support/" target="_blank" title="' . __( 'Get Support', 'somo' ) . '">' . __( 'Get Support', 'somo' ) . '</a></p>' .
			'<p><a href="http://somothemes.com/tutorials/" target="_blank" title="' . __( 'SomoThemes Tutorials', 'somo' ) . '">' . __( 'SomoThemes Tutorials', 'somo' ) . '</a></p>' .
			'<p><a href="http://somothemes.com/themes/" target="_blank" title="' . __( 'More Themes', 'somo' ) . '">' . __( 'More Themes', 'somo' ) . '</a></p>'
		);
	}

	/**
	 * Use this as the settings admin callback to create an admin page with sortable metaboxes.
	 * Create a 'settings_boxes' method to add metaboxes.
	 *
	 * @since 1.0.0
	 */
	public function admin() {
		?>
		<div class="wrap genesis-metaboxes">
			<?php wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false ); ?>
			<?php wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false ); ?>

			<?php screen_icon( $this->page_ops[ 'screen_icon' ] ); ?>
			<h2><?php echo esc_html( get_admin_page_title() ); ?></h2>

			<?php do_action( $this->pagehook . '_settings_page_boxes', $this->pagehook ); ?>
		</div>
		<script type="text/javascript">
			//<![CDATA[
			jQuery(document).ready(function($) {
				// close postboxes that should be closed
				$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
				// postboxes setup
				postboxes.add_postbox_toggles('<?php echo $this->pagehook; ?>');
			});
			//]]>
		</script>
		<?php
	}

	/**
	 * Register meta boxes on the Social Settings page.
	 *
	 * @since 1.0.0
	 *
	 * @see \Somo_Admin_Quick_Setup::oneclick_setup_box()	Callback for One Click Setup box.
	 * @see \Somo_Admin_Quick_Setup::cleanup_box()			Callback for One Click Cleanup box.
	 * @see \Somo_Admin_Quick_Setup::import_box()			Callback for Import Tools box.
	 * @see \Somo_Admin_Quick_Setup::export_box()			Callback for Export Tools box.
	 */
	function metaboxes() {
		add_meta_box( 'somo-quick-setup-oneclick', __( 'One Click Setup', 'somo' ), array( $this, 'oneclick_setup_box' ), $this->pagehook, 'main' );
		add_meta_box( 'somo-quick-setup-cleanup', __( 'One Click Cleanup', 'somo' ), array( $this, 'cleanup_box' ), $this->pagehook, 'main' );
		add_meta_box( 'somo-quick-setup-import', __( 'Import Tools', 'somo' ), array( $this, 'import_box' ), $this->pagehook, 'main' );
		add_meta_box( 'somo-quick-setup-export', __( 'Export Tools', 'somo' ), array( $this, 'export_box' ), $this->pagehook, 'main' );
	}

	/**
	 * Callback for One Click Setup meta box.
	 *
	 * @since 1.0.0
	 *
	 * @see \Somo_Admin_Quick_Setup::metaboxes() Register meta boxes on the Quick Setup page.
	 */
	function oneclick_setup_box() {
		?>
		<h4><?php _e( 'One Click Setup', 'somo' ); ?></h4>
		<p>
			<?php _e( 'This tool allows you to setup your site with sample content and settings by importing sample data shipped with the theme.', 'somo' ); ?>
		</p>
		<form method="post" action="<?php echo menu_page_url( 'somo-quick-setup', 0 ); ?>">
			<?php
			wp_nonce_field( 'somo-oneclick' );
			$this->oneclick_setup_checkboxes();
			if ( $this->get_oneclick_setup_options() )
				submit_button( __( 'Run One Click Setup', 'somo' ), 'primary', 'oneclick-submit', false );
			?>
		</form>
		<p>
			<span class="description">
				<?php _e( 'Click on the button above to begin one click setup.', 'somo' ); ?>
				<?php _e( 'Choosing Customize Setup option allows you to customize options before importing sample content and settings.', 'somo' ); ?>
			</span>
		</p>
		<p>
			<span class="description">
				<?php _e( 'Some tasks are not performed by this tool. To learn more, see Help section via Help menu on top-right corner of this page.', 'somo' ); ?>
			</span>
		</p>
		<?php
	}

	/**
	 * Callback for One Click Cleanup meta box.
	 *
	 * @since 1.0.0
	 *
	 * @see \Somo_Admin_Quick_Setup::metaboxes() Register meta boxes on the Quick Setup page.
	 */
	function cleanup_box() {
		?>
		<h4><?php _e( 'Cleanup Imported Content and Settings', 'somo' ); ?></h4>
		<p>
			<?php _e( 'This tool allows you to cleanup any content or settings that were previously imported using one of the quick setup tools.', 'somo' ); ?>
		</p>
		<form method="post" action="<?php echo menu_page_url( 'somo-quick-setup', 0 ); ?>">
			<?php
			wp_nonce_field( 'somo-cleanup' );
			?>
			<input type="hidden" name="somo-cleanup" value="1" />
			<?php
			$this->cleanup_checkboxes();
			if ( $this->get_cleanup_options() )
				submit_button( __( 'Run One Click Cleanup', 'somo' ), 'primary', 'cleanup-submit', false );
			?>
		</form>
		<p>
			<span class="description">
				<?php _e( 'Click on the button above to begin one click cleanup.', 'somo' ); ?>
				<?php _e( 'Choosing Customize Setup option allows you to customize options before running the cleanup.', 'somo' ); ?>

			</span>
		</p>
		<p>
			<span class="description">
				<?php _e( 'To learn more, see Help section via Help menu on top-right corner of this page.', 'somo' ); ?>
			</span>
		</p>
		<?php
	}

	/**
	 * Callback for Import meta box.
	 *
	 * @since 1.0.0
	 *
	 * @see \Somo_Admin_Quick_Setup::metaboxes() Register meta boxes on the Quick Setup page.
	 */
	function import_box() {
		?>
		<h4><?php _e( 'Import Theme Settings', 'somo' ); ?></h4>
		<p>
			<?php _e( 'This tool allows you to import a theme settings file you\'ve previously exported. ', 'somo' ); ?>
			<?php _e( 'Once you upload an import file, it will automatically overwrite your existing settings.', 'genesis' ); ?>
		</p>

		<form enctype="multipart/form-data" method="post" action="<?php echo menu_page_url( 'somo-quick-setup', 0 ); ?>">
			<?php wp_nonce_field( 'somo-import' ); ?>
			<input type="hidden" name="somo-import" value="1" />
			<label for="somo-import-upload"><?php sprintf( __( 'Upload File: (Maximum Size: %s)', 'genesis' ), ini_get( 'post_max_size' ) ); ?></label>
			<input type="file" id="somo-import-upload" name="somo-import-upload" />
			<?php
			submit_button( __( 'Upload File and Import', 'genesis' ), 'primary', 'upload', false );
			?>
		</form>
		<p>
			<span class="description">
				<?php printf( __( 'Upload the data file (%s) from your computer and we\'ll import your settings.', 'somo' ), genesis_code( '.json' ) ); ?>
				<?php printf( __( 'Choose the %s file from your computer and click "Upload file and Import".', 'somo' ), 'theme settings' ); ?>
			</span>
		</p>
		<hr class="div">
		<h4><?php _e( 'Import Widget Settings', 'somo' ); ?></h4>
		<p>
			<?php
			_e( 'This tool allows you to import a widget settings file you\'ve previously exported.', 'somo' );
			echo " ";
			_e( 'Once you upload an import file, it will create new widgets from the file after moving any existing widgets to Inactive widgets section. All inactive widgets will be deleted if you select "Delete all inactive widgets" option.', 'somo' );
			?>
		</p>

		<form enctype="multipart/form-data" method="post" action="<?php echo menu_page_url( 'somo-quick-setup', 0 ); ?>">
			<?php wp_nonce_field( 'somo-import-widgets' ); ?>
			<input type="hidden" name="somo-import-widgets" value="1" />

			<p>
				<label for="somo-import-widgets-delete-inactive">
					<input id="somo-import-widgets-delete-inactive" name="somo-import-widgets-delete-inactive" type="checkbox" value="1" /> <?php _e( 'Delete All Inactive Widgets', 'somo' ); ?>
				</label>
			</p>

			<label for="somo-import-widgets-upload"><?php sprintf( __( 'Upload File: (Maximum Size: %s)', 'genesis' ), ini_get( 'post_max_size' ) ); ?></label>
			<input type="file" id="somo-import-upload" name="somo-import-widgets-upload" />
			<?php
			submit_button( __( 'Upload File and Import', 'genesis' ), 'primary', 'upload-widgets', false );
			?>
		</form>
		<p>
			<span class="description">
				<?php printf( __( 'Upload the data file (%s) from your computer and we\'ll import your settings.', 'somo' ), genesis_code( '.json' ) ); ?>
				<?php printf( __( 'Choose the %s file from your computer and click "Upload file and Import".', 'somo' ), 'widget settings' ); ?>
			</span>
		</p>
		<?php
	}

	/**
	 * Callback for Export meta box.
	 *
	 * @since 1.0.0
	 *
	 * @see \Somo_Admin_Quick_Setup::metaboxes() Register meta boxes on the Quick Setup page.
	 */
	function export_box() {
		?>
		<h4><?php _e( 'Export Theme Settings', 'somo' ); ?></h4>
		<p>
			<?php printf( __( 'This tool allows you to export your Theme-related settings to your computer so you can back them up, or copy them to another site. The settings are exported in %s format.', 'somo' ), '<abbr title="' . __( 'JavaScript Object Notation', 'genesis' ) . '">' . __( 'JSON', 'genesis' ) . '</abbr>' ); ?>
		</p>
		<form method="post" action="<?php echo menu_page_url( 'somo-quick-setup', 0 ); ?>">
			<?php wp_nonce_field( 'somo-export' ); ?>
			<?php
			$this->export_checkboxes();
			if ( $this->get_export_options() )
				submit_button( __( 'Download Theme Settings File', 'genesis' ), 'primary', 'download', false );
			?>
		</form>
		<p>
			<span class="description">
				<?php _e( 'Choose the settings you wish to export and click the download button.', 'somo' ); ?>
				<?php printf( __( 'A data file (%s) will then be generated for you to save to your computer.', 'somo' ), genesis_code( '.json' ) ); ?>
				<?php _e( 'Once you have saved the downloaded file, you can use the import tool on another site to import this data.', 'somo' ); ?>
			</span>

		</p>
		<hr class="div">
		<h4><?php _e( 'Export Widget Settings', 'somo' ); ?></h4>
		<p>
			<?php printf( __( 'This tool allows you to export active widgets settings to your computer so you can back them up, or copy them to another site. The settings are exported in %s format.', 'somo' ), '<abbr title="' . __( 'JavaScript Object Notation', 'genesis' ) . '">' . __( 'JSON', 'genesis' ) . '</abbr>' ); ?>
		</p>
		<form method="post" action="<?php echo menu_page_url( 'somo-quick-setup', 0 ); ?>">
			<?php wp_nonce_field( 'somo-export-widgets' ); ?>
			<input type="hidden" name="somo-export-widgets" value="1" />
			<?php
			submit_button( __( 'Download Widget Settings File', 'somo' ), 'primary', 'download-widgets', false );
			?>
		</form>
		<p>
			<span class="description">
				<?php _e( 'Click the download button to run the exporter.', 'somo' ); ?>
				<?php printf( __( 'A data file (%s) will then be generated for you to save to your computer.', 'somo' ), genesis_code( '.json' ) ); ?>
				<?php _e( 'Once you have saved the downloaded file, you can use the widget settings import tool on another site to import this data.', 'somo' ); ?>
			</span>

		</p>
		<?php
	}

	/**
	 * Return array of export options and their arguments.
	 *
	 * Plugins and themes can hook into the somo_export_options filter to add
	 * their own settings to the exporter.
	 *
	 * @since 1.0.0
	 *
	 * @return array Export options
	 */
	protected function get_export_options() {

		$options = array(
			'theme' => array(
				'label' => __( 'Theme Settings', 'genesis' ),
				'settings-field' => GENESIS_SETTINGS_FIELD,
				'checked' => 'checked',
			),
			'social' => array(
				'label' => __( 'Social Settings', 'somo' ),
				'settings-field' => SOMO_SOCIAL_SETTINGS_FIELD,
				'checked' => '',
			),
			'seo' => array(
				'label' => __( 'SEO Settings', 'genesis' ),
				'settings-field' => GENESIS_SEO_SETTINGS_FIELD,
				'checked' => '',
			)
		);

		return ( array ) apply_filters( 'somo_export_options', $options );
	}

	/**
	 * Echo out the checkboxes for the export options.
	 *
	 * @since 1.0.0
	 *
	 * @uses \Somo_Admin_Quick_Setup::get_export_options() Get array of export options.
	 *
	 * @return null Return null if there are no options to export.
	 */
	protected function export_checkboxes() {

		if ( !$options = $this->get_export_options() ) {
			//* Not even the Genesis theme / seo export options were returned from the filter
			printf( '<p><em>%s</em></p>', __( 'No export options available.', 'genesis' ) );
			return;
		}

		foreach ( $options as $name => $args ) {
			//* Ensure option item has an array key, and that label and settings-field appear populated
			if ( is_int( $name ) || !isset( $args[ 'label' ] ) || !isset( $args[ 'settings-field' ] ) || '' === $args[ 'label' ] || '' === $args[ 'settings-field' ] )
				return;
			$checked = 'checked' === $args[ 'checked' ] ? 'checked="checked"' : '';
			printf( '<p><label for="somo-export-%1$s"><input id="somo-export-%1$s" name="somo-export[%1$s]" type="checkbox" value="1" %2$s /> %3$s</label></p>', esc_attr( $name ), $checked, esc_html( $args[ 'label' ] ) );
		}
	}

	/**
	 * Return array of one click setup options and their arguments.
	 *
	 * @since 1.0.0
	 *
	 * @return array	One Click Setup options
	 */
	protected function get_oneclick_setup_options() {

		$options = array(
			'wp' => array(
				'label' => __( 'Import Sample Content (Posts, Pages, Categories, Tags, Terms, Media, CPTs etc.)', 'somo' ),
				'context' => 'wp',
				'checked' => 'checked',
			),
			'menus' => array(
				'label' => __( 'Import Navigation Menus and Setup Theme Locations', 'somo' ),
				'context' => 'wp',
				'checked' => 'checked',
			),
			'replace_menus' => array(
				'label' => __( 'Replace/Overwrite a Navigation Menu if it already exists (was previously imported)', 'somo' ),
				'context' => 'wp',
				'checked' => '',
			),
			'widgets' => array(
				'label' => __( 'Import Sample Widgets', 'somo' ),
				'context' => 'widgets',
				'checked' => 'checked',
			),
			'delete_inactive_widgets' => array(
				'label' => __( 'Delete All Inactive Widgets', 'somo' ),
				'context' => 'widgets',
				'checked' => '',
			),
			'theme' => array(
				'label' => __( 'Import Theme Settings', 'somo' ),
				'settings-field' => GENESIS_SETTINGS_FIELD,
				'context' => 'theme',
				'checked' => 'checked',
			),
			'social' => array(
				'label' => __( 'Import Social Settings', 'somo' ),
				'settings-field' => SOMO_SOCIAL_SETTINGS_FIELD,
				'context' => 'theme',
				'checked' => 'checked',
			),
			'seo' => array(
				'label' => __( 'Import SEO Settings', 'somo' ),
				'settings-field' => GENESIS_SEO_SETTINGS_FIELD,
				'context' => 'theme',
				'checked' => 'checked',
			),
			'verbose' => array(
				'label' => __( 'Show Verbose Messages', 'somo' ),
				'context' => 'wp',
				'checked' => '',
			),
		);

		//* return ( array ) apply_filters( 'somo_one_click_setup_options', $options );
		return ( array ) $options;
	}

	/**
	 * Echo out the checkboxes for the one click setup options.
	 *
	 * @since 1.0.0
	 *
	 * @uses \Somo_Admin_Quick_Setup::get_oneclick_setup_options() Get array of one click setup options.
	 *
	 * @return null Return null if there are no options to export.
	 */
	protected function oneclick_setup_checkboxes() {

		if ( !$options = $this->get_oneclick_setup_options() ) {
			//* No options were returned from the filter
			printf( '<p><em>%s</em></p>', __( 'No setup options available.', 'somo' ) );
			return;
		}
		printf( '<p><label for="somo-oneclick-%1$s"><input id="somo-oneclick-%1$s" name="somo-oneclick[%1$s]" type="checkbox" value="1"/> %2$s</label></p>', 'advanced', __( 'Customize Setup', 'somo' ) );
		?>
		<div id="somo_oneclick_setting">
			<?php
			foreach ( $options as $name => $args ) {
				//* Ensure option item has an array key, and that label and settings-field appear populated
				if ( is_int( $name ) || !isset( $args[ 'label' ] ) || ( 'theme' === $args[ 'context' ] && !isset( $args[ 'settings-field' ] ) ) || '' === $args[ 'label' ] || ( 'theme' === $args[ 'context' ] && '' === $args[ 'settings-field' ]) )
					return;
				$checked = 'checked' === $args[ 'checked' ] ? 'checked="checked"' : '';
				printf( '<p><label for="somo-oneclick-%1$s"><input id="somo-oneclick-%1$s" name="somo-oneclick[%1$s]" type="checkbox" value="1" %2$s /> %3$s</label></p>', esc_attr( $name ), $checked, esc_html( $args[ 'label' ] ) );
			}
			?>
		</div>
		<?php
	}

	/**
	 * Return array of one click cleanup options and their arguments.
	 *
	 * @since 1.0.0
	 *
	 * @return array	One Click Cleanup options
	 */
	protected function get_cleanup_options() {

		$options = array(
			'wp' => array(
				'label' => __( 'Delete Imported Posts, Pages, Media, and Custom Post Types', 'somo' ),
				'context' => 'wp',
				'checked' => 'checked',
			),
			'menus' => array(
				'label' => __( 'Delete Imported Navigation Menus (Including Navigation Menu Items)', 'somo' ),
				'context' => 'wp',
				'checked' => '',
			),
			'menu_items' => array(
				'label' => __( 'Delete Navigation Menu Items Only (Retaining Navigation Menus)', 'somo' ),
				'context' => 'wp',
				'checked' => 'checked',
			),
			'terms' => array(
				'label' => __( 'Delete Imported Categories, Tags, and Terms', 'somo' ),
				'context' => 'wp',
				'checked' => 'checked',
			),
			'widgets' => array(
				'label' => __( 'Move All Active Widgets to Inactive Widgets area', 'somo' ),
				'context' => 'widgets',
				'checked' => '',
			),
			'delete_inactive_widgets' => array(
				'label' => __( 'Delete All Inactive Widgets', 'somo' ),
				'context' => 'widgets',
				'checked' => '',
			),
			'theme' => array(
				'label' => __( 'Reset Theme Settings', 'somo' ),
				'settings-field' => GENESIS_SETTINGS_FIELD,
				'context' => 'theme',
				'checked' => '',
			),
			'social' => array(
				'label' => __( 'Reset Social Settings', 'somo' ),
				'settings-field' => SOMO_SOCIAL_SETTINGS_FIELD,
				'context' => 'theme',
				'checked' => '',
			),
			'seo' => array(
				'label' => __( 'Reset SEO Settings', 'somo' ),
				'settings-field' => GENESIS_SEO_SETTINGS_FIELD,
				'context' => 'theme',
				'checked' => '',
			),
		);

		//* return ( array ) apply_filters( 'somo_one_click_setup_options', $options );
		return ( array ) $options;
	}

	/**
	 * Echo out the checkboxes for the one click cleanup options.
	 *
	 * @since 1.0.0
	 *
	 * @uses \Somo_Admin_Quick_Setup::get_cleanup_options() Get array of cleanup options.
	 *
	 * @return null Return null if there are no options to export.
	 */
	protected function cleanup_checkboxes() {

		if ( !$options = $this->get_cleanup_options() ) {
			//* No options were returned from the filter
			printf( '<p><em>%s</em></p>', __( 'No setup options available.', 'somo' ) );
			return;
		}
		printf( '<p><label for="somo-cleanup-%1$s"><input id="somo-cleanup-%1$s" name="somo-cleanup[%1$s]" type="checkbox" value="1"/> %2$s</label></p>', 'advanced', __( 'Customize Cleanup', 'somo' ) );
		?>
		<div id="somo_cleanup_setting">
			<?php
			foreach ( $options as $name => $args ) {
				//* Ensure option item has an array key, and that label and settings-field appear populated
				if ( is_int( $name ) || !isset( $args[ 'label' ] ) || ( 'theme' === $args[ 'context' ] && !isset( $args[ 'settings-field' ] )) || '' === $args[ 'label' ] || ( 'theme' === $args[ 'context' ] && '' === $args[ 'settings-field' ] ) )
					return;
				$checked = 'checked' === $args[ 'checked' ] ? 'checked="checked"' : '';
				printf( '<p><label for="somo-cleanup-%1$s"><input id="somo-cleanup-%1$s" name="somo-cleanup[%1$s]" type="checkbox" value="1" %2$s /> %3$s</label></p>', esc_attr( $name ), $checked, esc_html( $args[ 'label' ] ) );
			}
			?>
		</div>
		<?php
	}

	/**
	 * Handles widget settings (.json) data file upload and runs widget import routine
	 *
	 */
	public function import_widgets() {
		if ( !genesis_is_menu_page( 'somo-quick-setup' ) )
			return;

		if ( empty( $_REQUEST[ 'somo-import-widgets' ] ) )
			return;

		check_admin_referer( 'somo-import-widgets' );
		$messages = get_transient( '_somo_widgets_import_messages' );
		$upload = file_get_contents( $_FILES[ 'somo-import-widgets-upload' ][ 'tmp_name' ] );

		$importables = json_decode( $upload, true );

		//* Check for errors
		if ( !$importables || $_FILES[ 'somo-import-widgets-upload' ][ 'error' ] ) {
			$messages[ ] = array(
				'status' => 'error',
				'message' => sprintf( __( 'Sample widgets could not be created. Sample data file %s missing or malformed.', 'somo' ), '' ),
			);
			set_transient( '_somo_widgets_import_messages', $messages, 60 );
			genesis_admin_redirect( 'somo-quick-setup', array( 'widgets_import' => 'true' ) );
			exit;
		}

		$imported_sidebars = $importables[ 0 ];
		$imported_widgets_config = $importables[ 1 ];
		$existing_sidebars = get_option( 'sidebars_widgets' );
		if ( !$existing_sidebars || !is_array( $existing_sidebars ) || !$imported_sidebars || !is_array( $imported_sidebars ) || !$imported_widgets_config || !is_array( $imported_widgets_config ) ) {
			$messages[ ] = array(
				'status' => 'error',
				'message' => sprintf( __( 'We could not find any sidebar widgets to update.', 'somo' ), '' ),
			);
			set_transient( '_somo_widgets_import_messages', $messages, 60 );
			genesis_admin_redirect( 'somo-quick-setup', array( 'widgets_import' => 'true' ) );
			exit;
		}

		$delete_inactive_widgets = '1' === $_REQUEST[ 'somo-import-widgets-delete-inactive' ] ? true : false;
		$this->widgets_importer( $imported_sidebars, $imported_widgets_config, $existing_sidebars, $delete_inactive_widgets );

		//* Redirect, add success flag to the URI
		genesis_admin_redirect( 'somo-quick-setup', array( 'imported' => 'true' ) );
		exit;
	}

	/**
	 * Imports widgets into existing widget areas moving existing widgets to inactive widgets section.
	 * Inactive widgets can be optionally deleted using the $delete_inactive_widgets flag
	 *
	 * @param array $imported_sidebars				New sidebars data
	 * @param array $imported_widgets_config		New widgets data
	 * @param array $existing_sidebars				Existing sidebars data
	 * @param boolean $delete_inactive_widgets		Whether to all delete inactive widgets
	 */
	public function widgets_importer( $imported_sidebars, $imported_widgets_config, $existing_sidebars = array( ), $delete_inactive_widgets = false ) {

		if ( empty( $existing_sidebars ) )
			$existing_sidebars = get_option( 'sidebars_widgets' );

		//* Empty existing sidebars which need to be updated
		$new_sidebars = $existing_sidebars;
		$sidebars_to_import = array_keys( $imported_sidebars );
		foreach ( $existing_sidebars as $existing_sidebar => $existing_widgets ) {
			if ( 'wp_inactive_widgets' === $existing_sidebar || 'array_version' === $existing_sidebar )
				continue;

			//* If existing sidebar name is found in the imported data
			if ( in_array( $existing_sidebar, $sidebars_to_import ) ) {
				if ( is_array( $existing_widgets ) && !empty( $existing_widgets ) ) {
					foreach ( $existing_widgets as $existing_widget ) {
						//* Move the existing widget to inactive widgets area
						if ( !$delete_inactive_widgets )
							$new_sidebars[ 'wp_inactive_widgets' ][ ] = $existing_widget;
					}
				}
				$new_sidebars[ $existing_sidebar ] = array( );
			}
		}
		if ( $delete_inactive_widgets ) {
			$new_sidebars[ 'wp_inactive_widgets' ] = array( );
		}
		//* Save updated sidebars (empty sidebars)
		update_option( 'sidebars_widgets', $new_sidebars );

		//* Update the sidebars with widgets configuration from imported data
		$existing_sidebar_names = array_keys( $existing_sidebars );
		foreach ( $imported_sidebars as $imported_sidebar => $imported_widgets ) {
			if ( 'wp_inactive_widgets' === $imported_sidebar || 'array_version' === $imported_sidebar )
				continue;

			//* If the sidebar name is found in the imported data
			if ( in_array( $imported_sidebar, $existing_sidebar_names ) ) {
				foreach ( $imported_widgets as $imported_widget ) {

					if ( is_array( $imported_widget ) ) {
						continue;
					}

					$widget_type = trim( substr( $imported_widget, 0, strrpos( $imported_widget, '-' ) ) );
					$widget_id = trim( substr( $imported_widget, strrpos( $imported_widget, '-' ) + 1 ) );

					$existing_widget_config = get_option( 'widget_' . $widget_type );
					if ( !$existing_widget_config || !is_array( $existing_widget_config ) ) {
						$existing_widget_config = array( );
					}

					$existing_widget_ids = array_keys( $existing_widget_config );
					$new_widget_id = 1;
					foreach ( $existing_widget_ids as $id ) {
						if ( intval( $id ) > $new_widget_id )
							$new_widget_id = $id;
					}
					$new_widget_id++;

					//* Populate new widget configuration
					$existing_widget_config[ $new_widget_id ] = $imported_widgets_config[ $widget_type ][ $widget_id ];
					$existing_multiwidget_flag = $existing_widget_config[ '_multiwidget' ];
					$imported_multiwidget_flag = $imported_widgets_config[ $widget_type ][ '_multiwidget' ];
					if ( !$existing_multiwidget_flag || empty( $existing_multiwidget_flag ) )
						$is_multiwidget = $imported_multiwidget_flag ? $imported_multiwidget_flag : 1;
					else {
						$is_multiwidget = $existing_multiwidget_flag;
					}
					unset( $existing_widget_config[ '_multiwidget' ] );
					$existing_widget_config[ '_multiwidget' ] = $is_multiwidget;

					$new_widget_name = $widget_type . "-" . $new_widget_id;

					//* Add the new widget name to the sidebar
					$new_sidebars[ $imported_sidebar ][ ] = $new_widget_name;

					//* Save the sidebar with new widget added
					update_option( 'sidebars_widgets', $new_sidebars );

					//* Save widget configuration with new widget added
					update_option( 'widget_' . $widget_type, $existing_widget_config );
				}
			}
		}
	}

	/**
	 * Export existing sidebars and widgets configuration to a downloadble .json file.
	 *
	 */
	public function export_widgets() {
		if ( !genesis_is_menu_page( 'somo-quick-setup' ) )
			return;

		if ( empty( $_REQUEST[ 'somo-export-widgets' ] ) )
			return;

		check_admin_referer( 'somo-export-widgets' );
		$messages = get_transient( '_somo_widgets_export_messages' );
		$sidebars = get_option( 'sidebars_widgets' );
		if ( !$sidebars ) {
			$messages[ ] = array(
				'status' => 'error',
				'message' => sprintf( __( 'Widget configuration not found.', 'somo' ), genesis_code( $filename ) ),
			);
			set_transient( '_somo_widgets_export_messages', $messages, 60 );
			genesis_admin_redirect( 'somo-quick-setup', array( 'widgets_export' => 'true' ) );
			exit;
		}

		$exportable_sidebars = array( );
		$exportable_widgets = array( );
		foreach ( $sidebars as $sidebar => $widgets ) {
			if ( 'wp_inactive_widgets' === $sidebar )
				continue;

			if ( is_array( $widgets ) ) {
				if ( empty( $widgets ) ) {
					$exportable_sidebars[ $sidebar ][ ] = array( );
				}
				foreach ( $widgets as $widget_name ) {
					$exportable_sidebars[ $sidebar ][ ] = $widget_name;

					$widget_type = trim( substr( $widget_name, 0, strrpos( $widget_name, '-' ) ) );
					$widget_id = trim( substr( $widget_name, strrpos( $widget_name, '-' ) + 1 ) );

					$widget_config = get_option( 'widget_' . $widget_type );
					$is_multiwidget = $widget_config[ '_multiwidget' ];
					$exportable_widgets[ $widget_type ][ $widget_id ] = $widget_config[ $widget_id ];
					if ( isset( $exportable_widgets[ $widget_type ][ '_multiwidget' ] ) )
						unset( $exportable_widgets[ $widget_type ][ '_multiwidget' ] );
					$exportable_widgets[ $widget_type ][ '_multiwidget' ] = $is_multiwidget;
				}
			}
		}

		$exportables = array( $exportable_sidebars, $exportable_widgets );
		if ( !$exportables || empty( $exportables ) ) {
			$messages[ ] = array(
				'status' => 'error',
				'message' => sprintf( __( 'There are no widgets to export.', 'somo' ), genesis_code( $filename ) ),
			);
			set_transient( '_somo_widgets_export_messages', $messages, 60 );
			genesis_admin_redirect( 'somo-quick-setup', array( 'widgets_export' => 'true' ) );
			exit;
		}

		//* Exported file name always starts with <theme-name>
		$prefix_slug = SOMO_PARENT_THEME_SLUG ? SOMO_PARENT_THEME_SLUG : 'somo';
		$prefix = $prefix_slug . '-widget-data';

		$output = json_encode( $exportables );

		//* Prepare and send the export file to the browser
		header( 'Content-Description: File Transfer' );
		header( 'Cache-Control: public, must-revalidate' );
		header( 'Pragma: hack' );
		header( 'Content-Type: text/plain' );
		header( 'Content-Disposition: attachment; filename="' . $prefix . '-' . date( 'Ymd-His' ) . '.json"' );
		header( 'Content-Length: ' . mb_strlen( $output ) );
		echo $output;
		exit;
	}

	/**
	 * Generate the export file of theme-related settings, if requested, in JSON format.
	 *
	 * After checking we're on the right page, and trying to export, loop through the list of requested options to
	 * export, grabbing the settings from the database, and building up a file name that represents that collection of
	 * settings.
	 *
	 * A .json file is then sent to the browser, named with <theme-name> at the start and ending with the current
	 * date-time.
	 *
	 * The genesis_export action is fired after checking we can proceed, but before the array of export options are
	 * retrieved.
	 *
	 * @since 1.0.0
	 *
	 * @uses genesis_is_menu_page()                             Check if we're on a Genesis page.
	 * @uses \Somo_Admin_Quick_Setup::get_export_options()		Get array of export options.
	 *
	 * @return null Return null if not correct page, or we're not exporting.
	 */
	public function export() {

		if ( !genesis_is_menu_page( 'somo-quick-setup' ) )
			return;

		if ( empty( $_REQUEST[ 'somo-export' ] ) )
			return;

		check_admin_referer( 'somo-export' );

		do_action( 'somo_export', $_REQUEST[ 'somo-export' ] );

		$options = $this->get_export_options();

		$settings = array( );

		//* Exported file name always starts with <theme-name>
		$prefix_slug = SOMO_PARENT_THEME_SLUG ? SOMO_PARENT_THEME_SLUG : 'somo';
		$prefix = array( $prefix_slug );

		//* Loop through set(s) of options
		foreach ( ( array ) $_REQUEST[ 'somo-export' ] as $export => $value ) {
			//* Grab settings field name (key)
			$settings_field = $options[ $export ][ 'settings-field' ];

			//* Grab all of the settings from the database under that key
			$settings[ $settings_field ] = get_option( $settings_field );

			//* Add name of option set to build up export file name
			$prefix[ ] = $export;
		}

		if ( !$settings )
			return;

		//* Complete the export file name by joining parts together
		$prefix = join( '-', $prefix );

		$output = json_encode( ( array ) $settings );

		//* Prepare and send the export file to the browser
		header( 'Content-Description: File Transfer' );
		header( 'Cache-Control: public, must-revalidate' );
		header( 'Pragma: hack' );
		header( 'Content-Type: text/plain' );
		header( 'Content-Disposition: attachment; filename="' . $prefix . '-' . date( 'Ymd-His' ) . '.json"' );
		header( 'Content-Length: ' . mb_strlen( $output ) );
		echo $output;
		exit;
	}

	/**
	 * Handle the file uploaded to import settings.
	 *
	 * Upon upload, the file contents are JSON-decoded. If there were errors, or no options to import, then reload the
	 * page to show an error message.
	 *
	 * Otherwise, loop through the array of option sets, and update the data under those keys in the database.
	 * Afterwards, reload the page with a success message.
	 *
	 * Calls somo_import action is fired after checking we can proceed, but before attempting to extract the contents
	 * from the uploaded file.
	 *
	 * @since 1.0.0
	 *
	 * @uses genesis_is_menu_page()   Check if we're on a Genesis page
	 * @uses genesis_admin_redirect() Redirect user to an admin page
	 *
	 * @return null Return null if not correct admin page, we're not importing
	 */
	public function import() {

		if ( !genesis_is_menu_page( 'somo-quick-setup' ) )
			return;

		if ( empty( $_REQUEST[ 'somo-import' ] ) )
			return;

		check_admin_referer( 'somo-import' );

		do_action( 'somo_import', $_REQUEST[ 'somo-import' ], $_FILES[ 'somo-import-upload' ] );

		$upload = file_get_contents( $_FILES[ 'somo-import-upload' ][ 'tmp_name' ] );

		$options = json_decode( $upload, true );

		//* Check for errors
		if ( !$options || $_FILES[ 'somo-import-upload' ][ 'error' ] ) {
			genesis_admin_redirect( 'somo-quick-setup', array( 'error' => 'true' ) );
			exit;
		}

		//* Identify the settings keys that we should import
		$exportables = $this->get_export_options();
		$importable_keys = array( );
		foreach ( $exportables as $exportable ) {
			$importable_keys[ ] = $exportable[ 'settings-field' ];
		}

		//* Cycle through data, import Theme settings
		foreach ( ( array ) $options as $key => $settings ) {
			if ( in_array( $key, $importable_keys ) )
				update_option( $key, $settings );
		}

		//* Redirect, add success flag to the URI
		genesis_admin_redirect( 'somo-quick-setup', array( 'imported' => 'true' ) );
		exit;
	}

	/**
	 * Setup the site with sample content and settings by importing sample data shipped with the theme.
	 *
	 */
	public function oneclick_setup() {
		if ( !genesis_is_menu_page( 'somo-quick-setup' ) )
			return;

		if ( empty( $_REQUEST[ 'somo-oneclick' ] ) )
			return;

		check_admin_referer( 'somo-oneclick' );

		$messages = array( );
		set_transient( '_somo_oneclick_import_messages', $messages, 600 );

		$oneclick_options = $_REQUEST[ 'somo-oneclick' ];
		if ( !isset( $oneclick_options[ 'advanced' ] ) || empty( $oneclick_options[ 'advanced' ] ) ) {
			$oneclick_options[ 'wp' ] = '1';
			$oneclick_options[ 'menus' ] = '1';
			$oneclick_options[ 'replace_menus' ] = '';
			$oneclick_options[ 'widgets' ] = '1';
			$oneclick_options[ 'delete_inactive_widgets' ] = '';
			$oneclick_options[ 'theme' ] = '1';
			$oneclick_options[ 'social' ] = '1';
			$oneclick_options[ 'seo' ] = '1';
			$oneclick_options[ 'verbose' ] = '';
		}

		set_time_limit( 0 );

		//* Import WordPress content
		$this->oneclick_wp_import( $oneclick_options );

		//* Import Widgets configuration
		$this->oneclick_widgets_import( $oneclick_options );

		//* Import theme settings
		$this->oneclick_theme_settings_import( $oneclick_options );

		genesis_admin_redirect( 'somo-quick-setup', array( 'oneclick' => 'true' ) );
		exit;
	}

	/**
	 * Cleanup any content or settings that were previously imported using one of the quick setup tools
	 *
	 * @global object $_genesis_admin_settings
	 * @global object $_somo_admin_social_settings
	 * @global object $_genesis_admin_seo_settings
	 *
	 */
	public function oneclick_cleanup() {
		if ( !genesis_is_menu_page( 'somo-quick-setup' ) )
			return;

		if ( empty( $_REQUEST[ 'somo-cleanup' ] ) )
			return;

		check_admin_referer( 'somo-cleanup' );

		$messages = array( );
		set_transient( '_somo_cleanup_messages', $messages, 600 );

		$cleanup_options = $_REQUEST[ 'somo-cleanup' ];
		if ( !isset( $cleanup_options[ 'advanced' ] ) || empty( $cleanup_options[ 'advanced' ] ) ) {
			$cleanup_options[ 'wp' ] = '1';
			$cleanup_options[ 'menus' ] = '';
			$cleanup_options[ 'menu_items' ] = '1';
			$cleanup_options[ 'terms' ] = '1';
			$cleanup_options[ 'widgets' ] = '';
			$cleanup_options[ 'delete_inactive_widgets' ] = '';
			$cleanup_options[ 'theme' ] = '';
			$cleanup_options[ 'social' ] = '';
			$cleanup_options[ 'seo' ] = '';
		}

		set_time_limit( 0 );

		//* Delete Imported Posts, Pages, Media, and Custom Post Types
		if ( '1' === $cleanup_options[ 'wp' ] ) {
			$imported_posts = genesis_get_option( 'imported_posts', $this->settings_field );
			if ( is_array( $imported_posts ) && !empty( $imported_posts ) ) {

				foreach ( $imported_posts as $key => $imported_post ) {
					wp_delete_post( $imported_post, apply_filters( 'somo_cleanup_posts_force_delete', true ) );
					unset( $imported_posts[ $key ] );
				}

				_genesis_update_settings( array(
					'imported_posts' => $imported_posts
					), $this->settings_field );
			}
		}

		//* Delete Imported Navigation Menus (Including Navigation Menu Items)
		if ( '1' === $cleanup_options[ 'menus' ] ) {
			$imported_nav_menus = genesis_get_option( 'imported_nav_menus', $this->settings_field );
			if ( is_array( $imported_nav_menus ) && !empty( $imported_nav_menus ) ) {

				foreach ( $imported_nav_menus as $key => $imported_nav_menu ) {
					wp_delete_nav_menu( $imported_nav_menu );
					unset( $imported_nav_menus[ $key ] );
				}

				_genesis_update_settings( array(
					'imported_nav_menus' => $imported_nav_menus
					), $this->settings_field );
			}
		}

		//* Delete Navigation Menu Items Only (Retaining Navigation Menus)
		if ( '1' === $cleanup_options[ 'menu_items' ] ) {
			$imported_nav_menu_items = genesis_get_option( 'imported_nav_menu_items', $this->settings_field );
			if ( is_array( $imported_nav_menu_items ) && !empty( $imported_nav_menu_items ) ) {

				foreach ( $imported_nav_menu_items as $key => $imported_nav_menu_item ) {
					wp_delete_post( $imported_nav_menu_item );
					unset( $imported_nav_menu_items[ $key ] );
				}

				_genesis_update_settings( array(
					'imported_nav_menu_items' => $imported_nav_menu_items
					), $this->settings_field );
			}
		}

		//* Delete Imported Categories, Tags, and Terms (Excluding nav_menu Terms)
		if ( '1' === $cleanup_options[ 'terms' ] ) {
			$imported_cats = genesis_get_option( 'imported_cats', $this->settings_field );
			if ( is_array( $imported_cats ) && !empty( $imported_cats ) ) {

				foreach ( $imported_cats as $key => $imported_cat ) {
					wp_delete_category( $imported_cat );
					unset( $imported_cats[ $key ] );
				}

				_genesis_update_settings( array(
					'imported_cats' => $imported_cats
					), $this->settings_field );
			}

			$imported_tags = genesis_get_option( 'imported_tags', $this->settings_field );
			if ( is_array( $imported_tags ) && !empty( $imported_tags ) ) {

				foreach ( $imported_tags as $key => $imported_tag ) {
					wp_delete_term( $imported_tag, 'post_tag' );
					unset( $imported_tags[ $key ] );
				}

				_genesis_update_settings( array(
					'imported_tags' => $imported_tags
					), $this->settings_field );
			}

			$imported_terms = genesis_get_option( 'imported_terms', $this->settings_field );
			if ( is_array( $imported_terms ) && !empty( $imported_terms ) ) {

				foreach ( $imported_terms as $key => $imported_term ) {
					wp_delete_term( $imported_term[ 'id' ], $imported_term[ 'taxonomy' ] );
					unset( $imported_terms[ $key ] );
				}

				_genesis_update_settings( array(
					'imported_terms' => $imported_terms
					), $this->settings_field );
			}
		}

		//* Move All Active Widgets to Inactive Widgets area
		if ( '1' === $cleanup_options[ 'widgets' ] ) {
			$existing_sidebars = get_option( 'sidebars_widgets' );

			$new_sidebars = $existing_sidebars;
			if ( is_array( $existing_sidebars ) && !empty( $existing_sidebars ) ) {
				foreach ( $existing_sidebars as $existing_sidebar => $existing_widgets ) {
					if ( 'wp_inactive_widgets' === $existing_sidebar || 'array_version' === $existing_sidebar )
						continue;

					if ( is_array( $existing_widgets ) && !empty( $existing_widgets ) ) {
						foreach ( $existing_widgets as $existing_widget ) {
							//* Move the existing widget to inactive widgets area
							$new_sidebars[ 'wp_inactive_widgets' ][ ] = $existing_widget;
						}
					}
					$new_sidebars[ $existing_sidebar ] = array( );
				}
			}
			//* Save updated sidebars
			update_option( 'sidebars_widgets', $new_sidebars );
		}

		//* Delete All Inactive Widgets
		if ( '1' === $cleanup_options[ 'delete_inactive_widgets' ] ) {
			$existing_sidebars = get_option( 'sidebars_widgets' );
			$existing_sidebars[ 'wp_inactive_widgets' ] = array( );

			//* Save updated sidebars
			update_option( 'sidebars_widgets', $existing_sidebars );
		}

		$cleanup_config = $this->get_cleanup_options();
		global $_genesis_admin_settings, $_somo_admin_social_settings, $_genesis_admin_seo_settings;

		//* Reset Theme Settings
		if ( '1' === $cleanup_options[ 'theme' ] ) {
			update_option( $cleanup_config[ 'theme' ][ 'settings-field' ], $_genesis_admin_settings->default_settings );
		}

		//* Reset Social Settings
		if ( '1' === $cleanup_options[ 'social' ] ) {
			update_option( $cleanup_config[ 'social' ][ 'settings-field' ], $_somo_admin_social_settings->default_settings );
		}

		//* Reset SEO Settings
		if ( '1' === $cleanup_options[ 'seo' ] ) {
			update_option( $cleanup_config[ 'seo' ][ 'settings-field' ], $_genesis_admin_seo_settings->default_settings );
		}

		genesis_admin_redirect( 'somo-quick-setup', array( 'cleanup' => 'true' ) );
		exit;
	}

	/**
	 * Add custom notices that display after successfully importing or exporting the settings.
	 *
	 * @since 1.0.0
	 *
	 * @uses genesis_is_menu_page() Check if we're on a Genesis page.
	 *
	 * @return null Return early if not on the correct admin page.
	 */
	public function notices() {

		if ( !genesis_is_menu_page( 'somo-quick-setup' ) )
			return;

		if ( isset( $_REQUEST[ 'oneclick' ] ) && 'true' === $_REQUEST[ 'oneclick' ] ) {
			$messages = get_transient( '_somo_oneclick_import_messages' );
			if ( false === $messages ) {
				$message = __( 'We encountered an unknown issue. Please try again.', 'somo' );
				echo '<div id="message" class="error"><p><strong>' . $message . '</strong></p></div>';
			} else {
				foreach ( $messages as $message_arr ) {
					if ( 'success' === $message_arr[ 'status' ] )
						echo '<div id="message" class="updated"><p><strong>' . $message_arr[ 'message' ] . '</strong></p></div>';
					elseif ( 'error' === $message_arr[ 'status' ] )
						echo '<div id="message" class="error"><p><strong>' . $message_arr[ 'message' ] . '</strong></p></div>';
				}
				delete_transient( '_somo_oneclick_import_messages' );
			}
			echo '<div id="message" class="updated"><p><strong>' . __( 'Setup completed.', 'somo' ) . '</strong></p></div>';
		} elseif ( isset( $_REQUEST[ 'cleanup' ] ) && 'true' === $_REQUEST[ 'cleanup' ] ) {
			$messages = get_transient( '_somo_cleanup_messages' );
			if ( false === $messages ) {
				$message = __( 'We encountered an unknown issue. Please try again.', 'somo' );
				echo '<div id="message" class="error"><p><strong>' . $message . '</strong></p></div>';
			} else {
				foreach ( $messages as $message_arr ) {
					if ( 'success' === $message_arr[ 'status' ] )
						echo '<div id="message" class="updated"><p><strong>' . $message_arr[ 'message' ] . '</strong></p></div>';
					elseif ( 'error' === $message_arr[ 'status' ] )
						echo '<div id="message" class="error"><p><strong>' . $message_arr[ 'message' ] . '</strong></p></div>';
				}
				delete_transient( '_somo_cleanup_messages' );
			}
			echo '<div id="message" class="updated"><p><strong>' . __( 'Cleanup completed.', 'somo' ) . '</strong></p></div>';
		} elseif ( isset( $_REQUEST[ 'widgets_export' ] ) && 'true' === $_REQUEST[ 'widgets_export' ] ) {
			$messages = get_transient( '_somo_widgets_export_messages' );
			if ( false === $messages ) {
				$message = __( 'We encountered an unknown issue. Please try again.', 'somo' );
				echo '<div id="message" class="error"><p><strong>' . $message . '</strong></p></div>';
			} else {
				foreach ( $messages as $message_arr ) {
					if ( 'success' === $message_arr[ 'status' ] )
						echo '<div id="message" class="updated"><p><strong>' . $message_arr[ 'message' ] . '</strong></p></div>';
					elseif ( 'error' === $message_arr[ 'status' ] )
						echo '<div id="message" class="error"><p><strong>' . $message_arr[ 'message' ] . '</strong></p></div>';
				}
				delete_transient( '_somo_widgets_export_messages' );
			}
		} elseif ( isset( $_REQUEST[ 'widgets_import' ] ) && 'true' === $_REQUEST[ 'widgets_import' ] ) {
			$messages = get_transient( '_somo_widgets_import_messages' );
			if ( false === $messages ) {
				$message = __( 'We encountered an unknown issue. Please try again.', 'somo' );
				echo '<div id="message" class="error"><p><strong>' . $message . '</strong></p></div>';
			} else {
				foreach ( $messages as $message_arr ) {
					if ( 'success' === $message_arr[ 'status' ] )
						echo '<div id="message" class="updated"><p><strong>' . $message_arr[ 'message' ] . '</strong></p></div>';
					elseif ( 'error' === $message_arr[ 'status' ] )
						echo '<div id="message" class="error"><p><strong>' . $message_arr[ 'message' ] . '</strong></p></div>';
				}
				delete_transient( '_somo_widgets_import_messages' );
			}
		} elseif ( isset( $_REQUEST[ 'imported' ] ) && 'true' === $_REQUEST[ 'imported' ] )
			echo '<div id="message" class="updated"><p><strong>' . __( 'Settings successfully imported.', 'genesis' ) . '</strong></p></div>';
		elseif ( isset( $_REQUEST[ 'error' ] ) && 'true' === $_REQUEST[ 'error' ] )
			echo '<div id="message" class="error"><p><strong>' . __( 'There was a problem importing your settings. Please try again.', 'genesis' ) . '</strong></p></div>';
	}

	/**
	 * Imports WordPress content
	 *
	 * @uses \Somo_Importer::do_wp_import()	Run importer
	 *
	 * @param array $args
	 * @return array		$messages		Status messages and array of imported content identifiers
	 */
	protected function wp_import( $args ) {

		$defaults = array(
			'file_path' => '',
			'file_url' => '',
			'map_user_id' => 0,
			'oneclick_options' => array( ),
		);
		$args = wp_parse_args( $args, $defaults );

		$somo_importer = new Somo_Importer( $args );
		$messages = $somo_importer->do_wp_import();

		return $messages;
	}

	/**
	 * Executes WordPress content import using one-click options
	 *
	 * @param array $oneclick_options	One Click options array
	 * @return boolean					Status of import
	 */
	protected function oneclick_wp_import( $oneclick_options ) {
		$messages = get_transient( '_somo_oneclick_import_messages' );

		if ( '1' !== $oneclick_options[ 'wp' ] ) {
			$messages[ ] = array(
				'status' => 'success',
				'message' => __( 'WordPress content import skipped.', 'somo' ),
			);
			set_transient( '_somo_oneclick_import_messages', $messages, 600 );
			return;
		}

		require_once( SOMO_ADMIN_DIR . '/somo-importer.php' );
		if ( !class_exists( 'Somo_Importer' ) || !class_exists( 'WP_Importer' ) ) {
			$messages[ ] = array(
				'status' => 'error',
				'message' => __( 'WP_Importer/Somo_Importer classes not found. WordPress content import skipped.', 'somo' ),
			);
			set_transient( '_somo_oneclick_import_messages', $messages, 600 );
			return;
		}

		$prefix_slug = SOMO_PARENT_THEME_SLUG ? SOMO_PARENT_THEME_SLUG : 'somo';
		$filename = $prefix_slug . '-wp-data.xml';

		//Carry out WP Import
		$args = array(
			'file_path' => SOMO_DATA_DIR . '/' . $filename,
			'file_url' => SOMO_DATA_URL . '/' . $filename,
//			'map_user_id' => 1,
			'oneclick_options' => $oneclick_options,
		);

		$wp_messages = $this->wp_import( $args );
		foreach ( $wp_messages as $wp_message ) {
			if ( isset( $wp_message[ 'imported' ] ) ) {
				$imported = $wp_message[ 'imported' ];
				unset( $wp_message[ 'imported' ] );
			}
			$messages[ ] = $wp_message;
		}

		if ( is_array( $imported ) && !empty( $imported ) ) {

			if ( isset( $imported[ 'cats' ] ) ) {
				$imported_cats = genesis_get_option( 'imported_cats', $this->settings_field );
				$new_imported_cats = array_unique( array_merge( $imported_cats, $imported[ 'cats' ] ) );
				_genesis_update_settings( array(
					'imported_cats' => $new_imported_cats
					), $this->settings_field );
			}

			if ( isset( $imported[ 'tags' ] ) ) {
				$imported_tags = genesis_get_option( 'imported_tags', $this->settings_field );
				$new_imported_tags = array_unique( array_merge( $imported_tags, $imported[ 'tags' ] ) );
				_genesis_update_settings( array(
					'imported_tags' => $new_imported_tags
					), $this->settings_field );
			}

			if ( isset( $imported[ 'terms' ] ) ) {
				$imported_terms = genesis_get_option( 'imported_terms', $this->settings_field );
				$merged_terms = array_merge( $imported_terms, $imported[ 'terms' ] );
				/**
				 * Remove duplicates from multi-dimensional array
				 * @link http://stackoverflow.com/a/946300
				 */
				$new_imported_terms = array_map( "unserialize", array_unique( array_map( "serialize", $merged_terms ) ) );
				_genesis_update_settings( array(
					'imported_terms' => $new_imported_terms
					), $this->settings_field );
			}

			if ( isset( $imported[ 'nav_menus' ] ) ) {
				$imported_nav_menus = genesis_get_option( 'imported_nav_menus', $this->settings_field );
				$new_imported_nav_menus = array_unique( array_merge( $imported_nav_menus, $imported[ 'nav_menus' ] ) );
				_genesis_update_settings( array(
					'imported_nav_menus' => $new_imported_nav_menus
					), $this->settings_field );
			}

			if ( isset( $imported[ 'posts' ] ) ) {
				$imported_posts = genesis_get_option( 'imported_posts', $this->settings_field );
				$new_imported_posts = array_unique( array_merge( $imported_posts, $imported[ 'posts' ] ) );
				_genesis_update_settings( array(
					'imported_posts' => $new_imported_posts
					), $this->settings_field );
			}

			if ( isset( $imported[ 'nav_menu_items' ] ) ) {
				$imported_nav_menu_items = genesis_get_option( 'imported_nav_menu_items', $this->settings_field );
				$new_imported_nav_menu_items = array_unique( array_merge( $imported_nav_menu_items, $imported[ 'nav_menu_items' ] ) );
				_genesis_update_settings( array(
					'imported_nav_menu_items' => $new_imported_nav_menu_items
					), $this->settings_field );
			}
		}

		set_transient( '_somo_oneclick_import_messages', $messages, 600 );

		return true;
	}

	/**
	 * Executes Theme-related settings import using one-click options
	 *
	 * @param array $oneclick_options	One Click options array
	 * @return boolean					Status of import
	 */
	protected function oneclick_theme_settings_import( $oneclick_options ) {
		$messages = get_transient( '_somo_oneclick_import_messages' );

		if ( '1' !== $oneclick_options[ 'theme' ] && '1' !== $oneclick_options[ 'social' ] && '1' !== $oneclick_options[ 'seo' ] ) {
			$messages[ ] = array(
				'status' => 'success',
				'message' => __( 'Theme-related settings import skipped.', 'somo' ),
			);
			set_transient( '_somo_oneclick_import_messages', $messages, 600 );
			return;
		}

		$prefix_slug = SOMO_PARENT_THEME_SLUG ? SOMO_PARENT_THEME_SLUG : 'somo';
		$filename = $prefix_slug . '-theme-settings.json';

		$upload = file_get_contents( SOMO_DATA_URL . '/' . $filename );
		$options = json_decode( $upload, true );

		//* Check for errors
		if ( !$options ) {
			$messages[ ] = array(
				'status' => 'error',
				'message' => sprintf( __( 'Theme-related settings could not be updated. Sample data file %s missing or malformed.', 'somo' ), genesis_code( $filename ) ),
			);
			set_transient( '_somo_oneclick_import_messages', $messages, 600 );
			return false;
		}

		//* Identify the settings keys that we should import
		$exportables = $this->get_oneclick_setup_options();
		$importable_keys = array( );

		foreach ( $exportables as $exportable_key => $exportable ) {
			if ( 'theme' === $exportable[ 'context' ] && '1' === $oneclick_options[ $exportable_key ] )
				$importable_keys[ ] = $exportable[ 'settings-field' ];
		}

		//* Cycle through data, import Theme settings
		$updated = false;
		foreach ( ( array ) $options as $key => $settings ) {
			if ( in_array( $key, $importable_keys ) ) {
				update_option( $key, $settings );
				$updated = true; //* Flag to identify if at least one theme-related settings field was updated
			}
		}

		if ( $updated ) {
			$messages[ ] = array(
				'status' => 'success',
				'message' => __( 'Theme-related settings updated successfully.', 'somo' ),
			);
		} else {
			$messages[ ] = array(
				'status' => 'success',
				'message' => __( 'Theme-related settings import skipped.', 'somo' ),
			);
		}
		set_transient( '_somo_oneclick_import_messages', $messages, 600 );
		return true;
	}

	/**
	 * Executes Theme-related settings import using one-click options
	 *
	 * @param array $oneclick_options	One Click options array
	 * @return boolean					Status of import
	 */
	protected function oneclick_widgets_import( $oneclick_options ) {

		$messages = get_transient( '_somo_oneclick_import_messages' );

		if ( '1' === $oneclick_options[ 'delete_inactive_widgets' ] ) {
			$new_sidebars = get_option( 'sidebars_widgets' );
			$new_sidebars[ 'wp_inactive_widgets' ] = array( );
			update_option( 'sidebars_widgets', $new_sidebars );
			$messages[ ] = array(
				'status' => 'success',
				'message' => __( 'Inactive widgets deleted.', 'somo' ),
			);
			set_transient( '_somo_oneclick_import_messages', $messages, 600 );
		}

		if ( '1' !== $oneclick_options[ 'widgets' ] ) {
			$messages[ ] = array(
				'status' => 'success',
				'message' => __( 'Widget import skipped.', 'somo' ),
			);
			set_transient( '_somo_oneclick_import_messages', $messages, 600 );
			return;
		}

		$prefix_slug = SOMO_PARENT_THEME_SLUG ? SOMO_PARENT_THEME_SLUG : 'somo';
		$filename = $prefix_slug . '-widget-data.json';
		$upload = file_get_contents( SOMO_DATA_URL . '/' . $filename );
		$importables = json_decode( $upload, true );

		//* Check for errors
		if ( !$importables ) {
			$messages[ ] = array(
				'status' => 'error',
				'message' => sprintf( __( 'Sample widgets could not be created. Sample data file %s missing or malformed.', 'somo' ), genesis_code( $filename ) ),
			);
			set_transient( '_somo_oneclick_import_messages', $messages, 600 );
			return false;
		}

		$imported_sidebars = $importables[ 0 ];
		$imported_widgets_config = $importables[ 1 ];
		$existing_sidebars = get_option( 'sidebars_widgets' );
		if ( !$existing_sidebars || !is_array( $existing_sidebars ) || !$imported_sidebars || !is_array( $imported_sidebars ) || !$imported_widgets_config || !is_array( $imported_widgets_config ) ) {
			$messages[ ] = array(
				'status' => 'error',
				'message' => sprintf( __( 'We could not find any sidebar widgets to update.', 'somo' ), '' ),
			);
			set_transient( '_somo_oneclick_import_messages', $messages, 60 );
		}

		$delete_inactive_widgets = '1' === $oneclick_options[ 'delete_inactive_widgets' ] ? true : false;
		$this->widgets_importer( $imported_sidebars, $imported_widgets_config, $existing_sidebars, $delete_inactive_widgets );

		$messages[ ] = array(
			'status' => 'success',
			'message' => __( 'Sample widgets created successfully.', 'somo' ),
		);
		set_transient( '_somo_oneclick_import_messages', $messages, 600 );
		return true;
	}

}

