<?php
/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */

/**
 * Registers a new admin page, providing content and corresponding menu item for the SEO Settings page.
 *
 * @since 1.0.0
 */
class Somo_Admin_SEO_Settings extends Genesis_Admin_SEO_Settings {

	/**
	 * Create an admin menu item and settings page.
	 *
	 * @since 1.0.0
	 *
	 * @uses GENESIS_SEO_SETTINGS_FIELD Settings field key.
	 * @uses \Genesis_Admin::create()   Create an admin menu item and settings page.
	 */
	function __construct() {

		$page_id = 'somo-seo-settings';

		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => 'genesis',
				'page_title' => __( 'SEO Settings', 'genesis' ),
				'menu_title' => __( 'SEO Settings', 'genesis' )
			)
		);

		$page_ops = array(
			'screen_icon' => 'somo-screen-icon',
			'save_button_text' => __( 'Save Settings', 'genesis' ),
			'reset_button_text' => __( 'Reset Settings', 'genesis' ),
			'saved_notice_text' => __( 'Settings saved.', 'genesis' ),
			'reset_notice_text' => __( 'Settings reset.', 'genesis' ),
			'error_notice_text' => __( 'Error saving settings.', 'genesis' ),
		);

		$settings_field = GENESIS_SEO_SETTINGS_FIELD;

		$default_settings = apply_filters(
			'genesis_seo_settings_defaults', array(
			'append_description_home' => 1,
			'append_site_title' => 0,
			'doctitle_sep' => '-',
			'doctitle_seplocation' => 'right',
			'semantic_headings' => 1,
			'home_h1_on' => 'title',
			'home_doctitle' => '',
			'home_description' => '',
			'home_keywords' => '',
			'home_noindex' => 0,
			'home_nofollow' => 0,
			'home_noarchive' => 0,
			'home_author' => 0,
			'canonical_archives' => 1,
			'head_instant_pages' => 1,
			'head_adjacent_posts_rel_link' => 0,
			'head_wlwmanifest_link' => 0,
			'head_shortlink' => 0,
			'noindex_cat_archive' => 1,
			'noindex_tag_archive' => 1,
			'noindex_author_archive' => 1,
			'noindex_date_archive' => 1,
			'noindex_search_archive' => 1,
			'noarchive_cat_archive' => 0,
			'noarchive_tag_archive' => 0,
			'noarchive_author_archive' => 0,
			'noarchive_date_archive' => 0,
			'noarchive_search_archive' => 0,
			'noarchive' => 0,
			'noodp' => 1,
			'noydir' => 1,
			)
		);

		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );

		add_action( 'genesis_settings_sanitizer_init', array( $this, 'sanitizer_filters' ) );
	}

	/**
	 * Register each of the settings with a sanitization filter type.
	 *
	 * @since 1.0.0
	 *
	 * @uses genesis_add_option_filter() Assign filter to array of settings.
	 *
	 * @see \Genesis_Settings_Sanitizer::add_filter() Add sanitization filters to options.
	 */
	public function sanitizer_filters() {

		// No filter: doctitle_seplocation, home_h1_on

		genesis_add_option_filter(
			'one_zero', $this->settings_field, array(
			'append_description_home',
			'append_site_title',
			'semantic_headings',
			'home_noindex',
			'home_nofollow',
			'home_noarchive',
			'head_instant_pages',
			'head_adjacent_posts_rel_link',
			'head_wlwmanifest_link',
			'head_shortlink',
			'noindex_cat_archive',
			'noindex_tag_archive',
			'noindex_author_archive',
			'noindex_date_archive',
			'noindex_search_archive',
			'noarchive',
			'noarchive_cat_archive',
			'noarchive_tag_archive',
			'noarchive_author_archive',
			'noarchive_date_archive',
			'noarchive_search_archive',
			'noodp',
			'noydir',
			'canonical_archives',
			)
		);

		genesis_add_option_filter(
			'absint', $this->settings_field, array(
			'home_author',
			)
		);

		genesis_add_option_filter(
			'no_html', $this->settings_field, array(
			'home_doctitle',
			'home_description',
			'home_keywords',
			'doctitle_sep',
			)
		);
	}

	/**
	 * Contextual help content.
	 *
	 * @since 1.0.0
	 */
	public function help() {

		$screen = get_current_screen();

		$seo_settings_help =
			'<h3>' . __( 'SEO Settings', 'genesis' ) . '</h3>' .
			'<p>' . __( 'This SEO (search engine optimization) feature is polite, and will disable itself when most popular SEO plugins (e.g. All-in-One SEO, WordPress SEO etc.) are active.', 'somo' ) . '</p>' .
			'<p>' . __( 'If you don\'t see an SEO Settings sub menu, then you probably have another SEO plugin active.', 'genesis' ) . '</p>' .
			'<p>' . __( 'If you see the menu, then opening that menu item will let you set the General SEO settings for your site.', 'genesis' ) . '</p>' .
			'<p>' . __( 'Each page, post, and term will have its own SEO settings as well. The default settings are recommended for most users. If you wish to adjust your SEO settings, the boxes include internal descriptions.', 'genesis' ) . '</p>' .
			'<p>' . __( 'Below you\'ll find a few succinct notes on the options for each box:', 'genesis' ) . '</p>';

		$doctitle_help =
			'<h3>' . __( 'Doctitle Settings', 'genesis' ) . '</h3>' .
			'<p>' . __( '<strong>Append Site Description</strong> will insert the site description from your General Settings after the title on your home page.', 'genesis' ) . '</p>' .
			'<p>' . __( '<strong>Append Site Name</strong> will put the site name from the General Settings after the title on inner page.', 'genesis' ) . '</p>' .
			'<p>' . __( '<strong>Doctitle Append Location</strong> determines which side of the title to add the previously mentioned items.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The <strong>Doctitle Separator</strong> is the character that will go between the title and appended text.', 'genesis' ) . '</p>';

		$homepage_help =
			'<h3>' . __( 'Homepage Settings', 'genesis' ) . '</h3>' .
			'<p>' . __( 'These are the homepage specific SEO settings. Note: these settings will not apply if a static page is set as the front page. If you\'re using a static WordPress page as your hompage, you\'ll need to set the SEO settings on that particular page.', 'genesis' ) . '</p>' .
			'<p>' . __( 'You can also specify if the Site Title, Description, or your own custom text should be wrapped in an &lt;h1&gt; tag (the primary heading in HTML).', 'genesis' ) . '</p>' .
			'<p>' . __( 'To add custom text you\'ll have to either edit a php file, or use a text widget on a widget enabled homepage.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The home doctitle sets what will appear within the <title></title> tags (unseen in the browser) for the home page.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The home META description and keywords fill in the meta tags for the home page. The META description is the short text blurb that appear in search engine results.', 'genesis' ) . '</p>' .
			'<p>' . __( 'Most search engines do not use Keywords at this time or give them very little consideration; however, it\'s worth using in case keywords are given greater consideration in the future and also to help guide your content. If the content doesn\'t match with your targeted key words, then you may need to consider your content more carefully.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The Homepage Robots Meta Tags tell search engines how to handle the homepage. Noindex means not to index the page at all, and it will not appear in search results. Nofollow means do not follow any links from this page and noarchive tells them not to make an archive copy of the page.', 'genesis' ) . '</p>';

		$dochead_help =
			'<h3>' . __( 'Document Head Settings', 'genesis' ) . '</h3>' .
			'<p>' . __( 'Instant Pages, is a way of telling your browser about any one link on your page that visitors are most likely to click and the browser could then try to prefetch that page in the background. This results in the next page loading almost instantly and is currently supported in Firefox and Google Chrome. Enabling Instant Pages Support also enables Relational Links Markup.', 'genesis' ) . '</p>' .
			'<p>' . __( 'You can also add support for Windows Live Writer if you use software that supports this and include a shortlink tag if this is required by any third party service.', 'genesis' ) . '</p>';

		$robots_help =
			'<h3>' . __( 'Robots Meta Settings', 'genesis' ) . '</h3>' .
			'<p>' . __( 'Noarchive and noindex are explained in the home settings. Here you can select what other parts of the site to apply these options to.', 'genesis' ) . '</p>' .
			'<p>' . __( 'At least one archive should be indexed, but indexing multiple archives will typically result in a duplicate content penalization (multiple pages with identical content look manipulative to search engines).', 'genesis' ) . '</p>' .
			'<p>' . __( 'For most sites either the home page or blog page (using the blog template) will serve as this index which is why the default is not to index categories, tags, authors, dates, or searches.', 'genesis' ) . '</p>';

		$seoarchives_help =
			'<h3>' . __( 'Archives Settings', 'genesis' ) . '</h3>' .
			'<p>' . __( 'Canonical links will point search engines to the front page of paginated content (search engines have to choose the "preferred link" when there is duplicate content on pages).', 'genesis' ) . '</p>' .
			'<p>' . __( 'This tells them "this is paged content and the first page starts here" and helps to avoid spreading keywords across multiple pages.', 'genesis' ) . '</p>';

		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-seo-settings',
			'title' => __( 'Introduction', 'somo' ),
			'content' => $seo_settings_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-doctitle',
			'title' => __( 'Doctitle Settings', 'genesis' ),
			'content' => $doctitle_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-homepage',
			'title' => __( 'Homepage Settings', 'genesis' ),
			'content' => $homepage_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-dochead',
			'title' => __( 'Document Head Settings', 'genesis' ),
			'content' => $dochead_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-robots',
			'title' => __( 'Robots Meta Settings', 'genesis' ),
			'content' => $robots_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-seo-archives',
			'title' => __( 'SEO Archives', 'genesis' ),
			'content' => $seoarchives_help,
		) );

		//* Add help sidebar
		$screen->set_help_sidebar(
			'<p><strong>' . __( 'For more information:', 'somo' ) . '</strong></p>' .
			'<p><a href="http://somothemes.com/support/" target="_blank" title="' . __( 'Get Support', 'somo' ) . '">' . __( 'Get Support', 'somo' ) . '</a></p>' .
			'<p><a href="http://somothemes.com/tutorials/" target="_blank" title="' . __( 'SomoThemes Tutorials', 'somo' ) . '">' . __( 'SomoThemes Tutorials', 'somo' ) . '</a></p>' .
			'<p><a href="http://somothemes.com/themes/" target="_blank" title="' . __( 'More Themes', 'somo' ) . '">' . __( 'More Themes', 'somo' ) . '</a></p>'
		);
	}

	/**
	 * Register meta boxes on the SEO Settings page.
	 *
	 * @since 1.0.0
	 *
	 * @see \Genesis_Admin_SEO_Settings::doctitle_box()      Callback for document title box.
	 * @see \Genesis_Admin_SEO_Settings::homepage_box()      Callback for home page box.
	 * @see \Genesis_Admin_SEO_Settings::document_head_box() Callback for document head box.
	 * @see \Genesis_Admin_SEO_Settings::robots_meta_box()   Callback for robots meta box.
	 * @see \Genesis_Admin_SEO_Settings::archives_box()      Callback for archives box.
	 */
	function metaboxes() {

		add_meta_box( 'genesis-seo-settings-doctitle', __( 'Document Title Settings', 'genesis' ), array( $this, 'doctitle_box' ), $this->pagehook, 'main' );
		add_meta_box( 'genesis-seo-settings-homepage', __( 'Homepage Settings', 'genesis' ), array( $this, 'homepage_box' ), $this->pagehook, 'main' );
		add_meta_box( 'genesis-seo-settings-dochead', __( 'Document Head Settings', 'genesis' ), array( $this, 'document_head_box' ), $this->pagehook, 'main' );
		add_meta_box( 'genesis-seo-settings-robots', __( 'Robots Meta Settings', 'genesis' ), array( $this, 'robots_meta_box' ), $this->pagehook, 'main' );
		add_meta_box( 'genesis-seo-settings-archives', __( 'Archives Settings', 'genesis' ), array( $this, 'archives_box' ), $this->pagehook, 'main' );
	}

	/**
	 * Callback for SEO Settings Document Head meta box.
	 *
	 * @since 1.0.0
	 *
	 * @uses \Genesis_Admin::get_field_id()    Construct field ID.
	 * @uses \Genesis_Admin::get_field_name()  Construct field name.
	 * @uses \Genesis_Admin::get_field_value() Retrieve value of key under $this->settings_field.
	 *
	 * @see \Genesis_Admin_SEO_Settings::metaboxes() Register meta boxes on the SEO Settings page.
	 */
	function document_head_box() {
		?>
		<h4><?php _e( 'Instant Pages Support via Prefetch/Prerender', 'somo' ); ?></h4>
		<p><span class="description"><?php printf( __( 'Instant Pages, is a way of telling your browser about any one link on your page that visitors are most likely to click and the browser could then try to prefetch that page in the background. This results in the next page loading almost instantly and is currently supported in Firefox and Google Chrome.', 'somo' ), genesis_code( '<head>' ) ); ?></span></p>
		<p>
			<label for="<?php echo $this->get_field_id( 'head_instant_pages' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'head_instant_pages' ); ?>" id="<?php echo $this->get_field_id( 'head_instant_pages' ); ?>" value="1" <?php checked( $this->get_field_value( 'head_instant_pages' ) ); ?> />
				<?php printf( __( 'Enable Instant Pages Support (also enables Relational Links Markup)', 'genesis' ) ); ?></label>
		</p>
		<div id="somo_rel_markup_setting">
			<p>
				<label for="<?php echo $this->get_field_id( 'head_adjacent_posts_rel_link' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'head_adjacent_posts_rel_link' ); ?>" id="<?php echo $this->get_field_id( 'head_adjacent_posts_rel_link' ); ?>" value="1" <?php checked( $this->get_field_value( 'head_adjacent_posts_rel_link' ) ); ?> />
					<?php printf( __( 'Enable Relational Links Markup only', 'somo' ) ); ?></label>
			</p>
		</div>
		<h4><?php _e( 'Additional Markup', 'somo' ); ?></h4>
		<p><span class="description"><?php printf( __( 'By default, WordPress places several tags in your document %1$s. Most of these tags are completely unnecessary, and provide no <abbr title="Search engine optimization">SEO</abbr> value whatsoever; they just make your site slower to load. Choose which tags you would like included in your document %1$s. If you do not know what something is, leave it unchecked.', 'genesis' ), genesis_code( '<head>' ) ); ?></span></p>

		<p>
			<label for="<?php echo $this->get_field_id( 'head_wlmanifest_link' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'head_wlwmanifest_link' ); ?>" id="<?php echo $this->get_field_id( 'head_wlmanifest_link' ); ?>" value="1" <?php checked( $this->get_field_value( 'head_wlwmanifest_link' ) ); ?> />
				<?php printf( __( 'Include Windows Live Writer Support Tag?', 'genesis' ) ); ?></label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'head_shortlink' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'head_shortlink' ); ?>" id="<?php echo $this->get_field_id( 'head_shortlink' ); ?>" value="1" <?php checked( $this->get_field_value( 'head_shortlink' ) ); ?> />
				<?php printf( __( 'Include Shortlink tag?', 'genesis' ) ); ?></label>
		</p>
		<p>
			<span class="description"><?php _e( '<span class="genesis-admin-note">Note:</span> The shortlink tag might have some use for 3rd party service discoverability, but it has no <abbr title="Search engine optimization">SEO</abbr> value whatsoever.', 'genesis' ); ?></span>
		</p>
		<?php
	}

}
