<?php
/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */

/**
 * Registers a new admin page, providing content and corresponding menu item for the Theme Settings page.
 *
 * @since 1.0.0
 */
class Somo_Admin_Settings extends Genesis_Admin_Settings {

	/**
	 * Create an admin menu item and settings page.
	 *
	 * @since 1.0.0
	 *
	 * @uses GENESIS_ADMIN_IMAGES_URL     URL for admin images.
	 * @uses GENESIS_SETTINGS_FIELD       Settings field key.
	 * @uses PARENT_DB_VERSION            Genesis database version.
	 * @uses PARENT_THEME_VERSION         Genesis Framework version.
	 * @uses genesis_get_default_layout() Get default layout.
	 * @uses \Genesis_Admin::create()     Create an admin menu item and settings page.
	 */
	function __construct() {

		$page_id = 'genesis';

		$menu_ops = apply_filters(
			'somo_theme_settings_menu_ops', array(
			'main_menu' => array(
				'sep' => array(
					'sep_position' => '58.995',
					'sep_capability' => 'edit_theme_options',
				),
				'page_title' => 'Theme Settings',
				'menu_title' => 'SomoThemes',
				'capability' => 'edit_theme_options',
				'icon_url' => SOMO_ADMIN_IMAGES_URL . '/somo-menu.png',
				'position' => '58.996',
			),
			'first_submenu' => array( //* Do not use without 'main_menu'
				'page_title' => __( 'Theme Settings', 'genesis' ),
				'menu_title' => __( 'Theme Settings', 'genesis' ),
				'capability' => 'edit_theme_options',
			),
			) );

		$page_ops = apply_filters(
			'somo_theme_settings_page_ops', array(
			'screen_icon' => 'somo-screen-icon',
			'save_button_text' => __( 'Save Settings', 'genesis' ),
			'reset_button_text' => __( 'Reset Settings', 'genesis' ),
			'saved_notice_text' => __( 'Settings saved.', 'genesis' ),
			'reset_notice_text' => __( 'Settings reset.', 'genesis' ),
			'error_notice_text' => __( 'Error saving settings.', 'genesis' ),
			)
		);

		$settings_field = GENESIS_SETTINGS_FIELD;

		$default_settings = apply_filters(
			'genesis_theme_settings_defaults', array(
			'update' => 1,
			'update_email' => 0,
			'update_email_address' => '',
			'blog_title' => 'text',
			'style_selection' => '',
			'site_layout' => genesis_get_default_layout(),
			'superfish' => 0,
			'nav_extras' => '',
			'nav_extras_twitter_id' => '',
			'nav_extras_twitter_text' => __( 'Follow me on Twitter', 'genesis' ),
			'mobile_nav_extras' => 0,
			'feed_uri' => '',
			'redirect_feed' => 0,
			'comments_feed_uri' => '',
			'redirect_comments_feed' => 0,
			'comments_pages' => 0,
			'comments_posts' => 1,
			'trackbacks_pages' => 0,
			'trackbacks_posts' => 1,
			'breadcrumb_home' => 0,
			'breadcrumb_front_page' => 0,
			'breadcrumb_posts_page' => 0,
			'breadcrumb_single' => 0,
			'breadcrumb_page' => 0,
			'breadcrumb_archive' => 0,
			'breadcrumb_404' => 0,
			'breadcrumb_attachment' => 0,
			'content_archive' => 'full',
			'content_archive_thumbnail' => 0,
			'image_size' => '',
			'posts_nav' => 'prev-next',
			'blog_cat' => '',
			'blog_cat_exclude' => '',
			'blog_cat_num' => 10,
			'header_scripts' => '',
			'footer_scripts' => '',
			'theme_version' => SOMO_PARENT_THEME_VERSION,
			'db_version' => SOMO_PARENT_DB_VERSION,
			'somo_updates_api_username' => '',
			'somo_updates_api_key' => '',
			'somo_updates_api_status' => '', //Important to be empty i.e. '' and not '0'
			)
		);

		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );

		add_action( 'genesis_settings_sanitizer_init', array( $this, 'sanitizer_filters' ) );
	}

	/**
	 * Register each of the settings with a sanitization filter type.
	 *
	 * @since 1.0.0
	 *
	 * @uses genesis_add_option_filter() Assign filter to array of settings.
	 *
	 * @see \Genesis_Settings_Sanitizer::add_filter() Add sanitization filters to options.
	 */
	public function sanitizer_filters() {

// No filter: image_size

		genesis_add_option_filter(
			'one_zero', $this->settings_field, array(
			'breadcrumb_front_page',
			'breadcrumb_home',
			'breadcrumb_single',
			'breadcrumb_page',
			'breadcrumb_posts_page',
			'breadcrumb_archive',
			'breadcrumb_404',
			'breadcrumb_attachment',
			'comments_posts',
			'comments_pages',
			'content_archive_thumbnail',
			'superfish',
			'redirect_feed',
			'redirect_comments_feed',
			'trackbacks_posts',
			'trackbacks_pages',
			'update',
			'update_email',
			'mobile_nav_extras',
			)
		);

		genesis_add_option_filter(
			'no_html', $this->settings_field, array(
			'blog_cat_exclude',
			'blog_title',
			'content_archive',
			'nav_extras',
			'nav_extras_twitter_id',
			'posts_nav',
			'site_layout',
			'style_selection',
			'theme_version',
			)
		);

		genesis_add_option_filter(
			'absint', $this->settings_field, array(
			'blog_cat',
			'blog_cat_num',
			'content_archive_limit',
			'db_version',
			)
		);

		genesis_add_option_filter(
			'safe_html', $this->settings_field, array(
			'nav_extras_twitter_text',
			)
		);

		genesis_add_option_filter(
			'requires_unfiltered_html', $this->settings_field, array(
			'update_email_address',
			'header_scripts',
			'footer_scripts',
			)
		);

		genesis_add_option_filter(
			'url', $this->settings_field, array(
			'feed_uri',
			'comments_feed_uri',
			)
		);
	}

	/**
	 * Contextual help content.
	 *
	 * @since 1.0.0
	 */
	public function help() {

		$screen = get_current_screen();

		$theme_settings_help =
			'<h3>' . __( 'Theme Settings', 'genesis' ) . '</h3>' .
			'<p>' . __( 'Your Theme Settings provides control over how the theme works. You will be able to control a lot of common and even advanced features from this menu. Some themes may add additional menu items to this list, including the ability to select different color schemes or set theme specific features such as a slider. Each of the boxes can be collapsed by clicking the box header and expanded by doing the same. They can also be dragged into any order you desire or even hidden by clicking on "Screen Options" in the top right of the screen and "unchecking" the boxes you do not want to see. Below you\'ll find the items common to all themes.', 'somo' ) . '</p>';

		$information_help =
			'<h3>' . __( 'Information', 'genesis' ) . '</h3>' .
			'<p>' . __( 'The information box allows you to see the current theme information.', 'somo' ) . '</p>' .
			'<p>' . __( 'You can also set to enable automatic updates.', 'somo' ) . '</p>' .
			'<p>' . __( 'This does not mean the updates happen automatically without your permission; it will just notify you that an update is available. You can then use the auto-update link to perform the update.', 'somo' ) . '</p>' .
			'<p>' . __( 'If you provide an email address and select to notify that email address when the update is available, your site will email you when the update can be performed.', 'somo' ) . '</p>';

		$feeds_help =
			'<h3>' . __( 'Custom Feeds', 'genesis' ) . '</h3>' .
			'<p>' . __( 'If you use Feedburner to handle your rss feed(s) you can use this function to set your site\'s native feed to redirect to your Feedburner feed.', 'genesis' ) . '</p>' .
			'<p>' . __( 'By filling in the feed links calling for the main site feed, it will display as a link to Feedburner.', 'genesis' ) . '</p>' .
			'<p>' . __( 'By checking the "Redirect Feed" box, all traffic to default feed links will be redirected to the Feedburner link instead.', 'genesis' ) . '</p>';

		$layout_help =
			'<h3>' . __( 'Default Layout', 'genesis' ) . '</h3>' .
			'<p>' . __( 'This lets you select the default layout for your entire site. On most of the the themes you\'ll see these options:', 'somo' ) . '</p>' .
			'<ul>' .
			'<li>' . __( 'Content Sidebar', 'genesis' ) . '</li>' .
			'<li>' . __( 'Sidebar Content', 'genesis' ) . '</li>' .
			'<li>' . __( 'Sidebar Content Sidebar', 'genesis' ) . '</li>' .
			'<li>' . __( 'Content Sidebar Sidebar', 'genesis' ) . '</li>' .
			'<li>' . __( 'Sidebar Sidebar Content', 'genesis' ) . '</li>' .
			'<li>' . __( 'Full Width Content', 'genesis' ) . '</li>' .
			'</ul>' .
			'<p>' . __( 'These options can be extended or limited by the individual theme. Additionally, many of the themes do not allow different layouts on the home page as they have been designed for a specific home page layout.', 'somo' ) . '</p>' .
			'<p>' . __( 'This layout can also be overridden in the post/page/term layout options on each post/page/term.', 'genesis' ) . '</p>';

		$header_help =
			'<h3>' . __( 'Header', 'genesis' ) . '</h3>' .
			'<p>' . __( 'The <strong>Dynamic text</strong> option will use the Site Title and Site Description from your site\'s settings in your header.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The <strong>Image logo</strong> option will use a logo image file in the header instead of the site\'s title and description. This setting adds a .header-image class to your site, allowing you to specify the header image in your theme\'s style.css. By default, the logo can be saved as logo.png and saved to the images folder of your theme/child theme.', 'somo' ) . '</p>';

		$navigation_help =
			'<h3>' . __( 'Navigation', 'genesis' ) . '</h3>' .
			'<p>' . __( 'The Primary Navigation Extras typically display on the right side of your Primary Navigation menu.', 'genesis' ) . '</p>' .
			'<ul>' .
			'<li>' . __( 'Today\'s date displays the current date', 'genesis' ) . '</li>' .
			'<li>' . __( 'Search box displays a small search box utilizing the WordPress search functionality.', 'genesis' ) . '</li>' .
			'</ul>' .
			'<p>' . __( 'The Mobile Navigation Extras can be used to display a Search box at the top of Mobile Navigation section.', 'somo' ) . '</p>' .
			'<p>' . __( 'These options can be extended or limited by the individual theme.', 'somo' ) . '</p>';

		$breadcrumbs_help =
			'<h3>' . __( 'Breadcrumbs', 'genesis' ) . '</h3>' .
			'<p>' . __( 'This box lets you define where the "Breadcrumbs" display. The Breadcrumb is the navigation tool that displays where a visitor is on the site at any given moment.', 'genesis' ) . '</p>';

		$comments_help =
			'<h3>' . __( 'Comments and Trackbacks', 'genesis' ) . '</h3>' .
			'<p>' . __( 'This allows a site wide decision on whether comments and trackbacks (notifications when someone links to your page) are enabled for posts and pages.', 'genesis' ) . '</p>' .
			'<p>' . __( 'If you enable comments or trackbacks here, it can be disabled on an individual post or page. If you disable here, they cannot be enabled on an individual post or page.', 'genesis' ) . '</p>';

		$archives_help =
			'<h3>' . __( 'Content Archives', 'genesis' ) . '</h3>' .
			'<p>' . __( 'Under Theme Settings you may change the site wide Content Archives options to control what displays in the site\'s Archives.', 'somo' ) . '</p>' .
			'<p>' . __( 'Archives include any pages using the blog template, category pages, tag pages, date archive, author archives, and the latest posts if there is no custom home page.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The first option allows you to display the post content or the post excerpt. The Display post content setting will display the entire post including HTML code up to the <!--more--> tag if used (this is HTML for the comment tag that is not displayed in the browser).', 'genesis' ) . '</p>' .
			'<p>' . __( 'It may also be coupled with the second field "Limit content to [___] characters" to limit the content to a specific number of letters or spaces. This will strip any HTML, but allows for more precise and easily changed lengths than the excerpt.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The Display post excerpt setting will display the first 55 words of the post after also stripping any included HTML or the manual/custom excerpt added in the post edit screen.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The \'Include post image?\' setting allows you to show a thumbnail of the first attached image or currently set featured image.', 'genesis' ) . '</p>' .
			'<p>' . __( 'This option should not be used with the post content unless the content is limited to avoid duplicate images.', 'genesis' ) . '</p>' .
			'<p>' . __( 'The \'Image Size\' list is populated by the available image sizes defined in the theme.', 'genesis' ) . '</p>' .
			'<p>' . __( 'Post Navigation Technique allows you to select one of two navigation methods.', 'somo' ) . '</p>';

		$blog_help =
			'<h3>' . __( 'Blog Page', 'genesis' ) . '</h3>' .
			'<p>' . __( 'This works with the Blog Template, which is a page template that shows your latest posts. It\'s what people see when they land on your homepage.', 'genesis' ) . '</p>' .
			'<p>' . __( 'In the General Settings you can select a specific category to display from the drop down menu, and exclude categories by ID, or even select how many posts you\'d like to display on this page.', 'genesis' ) . '</p>' .
			'<p>' . __( 'There are some special features of the Blog Template that allow you to specify which category to show on each page using the template, which is helpful if you have a "News" category (or something else) that you want to display separately.', 'genesis' ) . '</p>';

		$scripts_help =
			'<h3>' . __( 'Header and Footer Scripts', 'genesis' ) . '</h3>' .
			'<p>' . __( 'This provides you with two fields that will output HTML code snippets and scripts to the <head></head> of your site and just before the </body>. These will appear on every page of the site and are a great way to add analytic code and other scripts. You cannot use PHP in these fields. If you need to use PHP then you should look into the Genesis Simple Hooks plugin.', 'somo' ) . '</p>';

		$home_help =
			'<h3>' . __( 'How Home Pages Work', 'genesis' ) . '</h3>' .
			'<p>' . __( 'Most of the themes include a custom home page.', 'somo' ) . '</p>' .
			'<p>' . __( 'This home page is typically setup via widgets in the sidebars for the home page. This can be accessed via the Widgets menu item under Appearance.', 'genesis' ) . '</p>' .
			'<p>' . __( 'It is recommended to have WordPress > Settings > Reading set to display your latest posts on homepage. It will show your latest posts in a blog type listing unless you put widgets into the home page widget areas. As you add widgets to the home page widget areas, the theme will automatically start displaying the widgets instead. You can setup a page with the Blog page template to show a blog style list of your latest posts on another page.', 'somo' ) . '</p>' .
			'<p>' . __( 'Another common home page is the "blog" type home page. This shows your latest posts and requires no additional setup.', 'somo' ) . '</p>';

		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-theme-settings',
			'title' => __( 'Introduction', 'somo' ),
			'content' => $theme_settings_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-information',
			'title' => __( 'Information', 'genesis' ),
			'content' => $information_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-feeds',
			'title' => __( 'Custom Feeds', 'genesis' ),
			'content' => $feeds_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-layout',
			'title' => __( 'Default Layout', 'genesis' ),
			'content' => $layout_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-header',
			'title' => __( 'Header', 'genesis' ),
			'content' => $header_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-navigation',
			'title' => __( 'Navigation', 'genesis' ),
			'content' => $navigation_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-breadcrumbs',
			'title' => __( 'Breadcrumbs', 'genesis' ),
			'content' => $breadcrumbs_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-comments',
			'title' => __( 'Comments and Trackbacks', 'genesis' ),
			'content' => $comments_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-archives',
			'title' => __( 'Content Archives', 'genesis' ),
			'content' => $archives_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-blog',
			'title' => __( 'Blog Page', 'genesis' ),
			'content' => $blog_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-scripts',
			'title' => __( 'Header and Footer Scripts', 'genesis' ),
			'content' => $scripts_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-home',
			'title' => __( 'Home Pages', 'genesis' ),
			'content' => $home_help,
		) );

//* Add help sidebar
		$screen->set_help_sidebar(
			'<p><strong>' . __( 'For more information:', 'somo' ) . '</strong></p>' .
			'<p><a href="http://somothemes.com/support/" target="_blank" title="' . __( 'Get Support', 'somo' ) . '">' . __( 'Get Support', 'somo' ) . '</a></p>' .
			'<p><a href="http://somothemes.com/tutorials/" target="_blank" title="' . __( 'SomoThemes Tutorials', 'somo' ) . '">' . __( 'SomoThemes Tutorials', 'somo' ) . '</a></p>' .
			'<p><a href="http://somothemes.com/themes/" target="_blank" title="' . __( 'More Themes', 'somo' ) . '">' . __( 'More Themes', 'somo' ) . '</a></p>'
		);
	}

	/**
	 * Save method.
	 *
	 * Modified to store the username/api key values separately so do not get
	 * exported accidentally when export tool is used.
	 *
	 * @param array $newvalue
	 * @param array $oldvalue
	 * @return array
	 */
	public function save( $newvalue, $oldvalue ) {

		if ( !isset( $newvalue[ 'somo_updates_api_username' ] ) || !isset( $newvalue[ 'somo_updates_api_key' ] ) ) {
			return $newvalue;
		}

		$api_username = esc_attr( $newvalue[ 'somo_updates_api_username' ] );
		$api_key = esc_attr( $newvalue[ 'somo_updates_api_key' ] );

		if ( !( empty( $api_username ) && empty( $api_key ) ) ) {
			update_site_option( 'somo_updates_api_username', $api_username );
			update_site_option( 'somo_updates_api_key', md5( $api_key ) );

			$status = somo_validate_api_key( $api_username, get_site_option( 'somo_updates_api_key', '' ) );
			if ( true === $status ) {
				$newvalue[ 'somo_updates_api_status' ] = '1';
			} else {
				$newvalue[ 'somo_updates_api_status' ] = '0';
			}
			update_site_option( 'somo_updates_api_status', $newvalue[ 'somo_updates_api_status' ] );
		} else {
			$newvalue[ 'somo_updates_api_status' ] = $oldvalue[ 'somo_updates_api_status' ];
		}

		$newvalue[ 'somo_updates_api_username' ] = '';
		$newvalue[ 'somo_updates_api_key' ] = '';
		return $newvalue;
	}

	/**
	 * Register meta boxes on the Theme Settings page.
	 *
	 * Some of the meta box additions are dependent on certain theme support or user capabilities.
	 *
	 * The 'genesis_theme_settings_metaboxes' action hook is called at the end of this function.
	 *
	 * @since 1.0.0
	 *
	 * @see \Genesis_Admin_Settings::info_box()          Callback for Information box.
	 * @see \Genesis_Admin_Settings::style_box()         Callback for Color Style box (if supported).
	 * @see \Genesis_Admin_Settings::feeds_box()         Callback for Custom Feeds box.
	 * @see \Genesis_Admin_Settings::layout_box()        Callback for Default Layout box.
	 * @see \Genesis_Admin_Settings::header_box()        Callback for Header box (if no custom header support).
	 * @see \Genesis_Admin_Settings::nav_box()           Callback for Navigation box.
	 * @see \Genesis_Admin_Settings::breadcrumb_box()    Callback for Breadcrumbs box.
	 * @see \Genesis_Admin_Settings::comments_box()      Callback for Comments and Trackbacks box.
	 * @see \Genesis_Admin_Settings::post_archives_box() Callback for Content Archives box.
	 * @see \Genesis_Admin_Settings::blogpage_box()      Callback for Blog Page box.
	 * @see \Genesis_Admin_Settings::scripts_box()       Callback for Header and Footer Scripts box (if user has
	 *                                                   unfiltered_html capability).
	 */
	function metaboxes() {

		add_action( 'genesis_admin_before_metaboxes', array( $this, 'hidden_fields' ) );

		add_meta_box( 'genesis-theme-settings-version', __( 'Information', 'genesis' ), array( $this, 'info_box' ), $this->pagehook, 'main', 'high' );

		if ( current_theme_supports( 'genesis-style-selector' ) )
			add_meta_box( 'genesis-theme-settings-style-selector', __( 'Color Style', 'genesis' ), array( $this, 'style_box' ), $this->pagehook, 'main' );

		add_meta_box( 'genesis-theme-settings-feeds', __( 'Custom Feeds', 'genesis' ), array( $this, 'feeds_box' ), $this->pagehook, 'main' );
		add_meta_box( 'genesis-theme-settings-layout', __( 'Default Layout', 'genesis' ), array( $this, 'layout_box' ), $this->pagehook, 'main' );

		if ( !current_theme_supports( 'genesis-custom-header' ) && !current_theme_supports( 'custom-header' ) )
			add_meta_box( 'genesis-theme-settings-header', __( 'Header', 'genesis' ), array( $this, 'header_box' ), $this->pagehook, 'main' );

		if ( current_theme_supports( 'genesis-menus' ) )
			add_meta_box( 'genesis-theme-settings-nav', __( 'Navigation', 'genesis' ), array( $this, 'nav_box' ), $this->pagehook, 'main' );

		if ( current_theme_supports( 'genesis-breadcrumbs' ) )
			add_meta_box( 'genesis-theme-settings-breadcrumb', __( 'Breadcrumbs', 'genesis' ), array( $this, 'breadcrumb_box' ), $this->pagehook, 'main' );

		add_meta_box( 'genesis-theme-settings-comments', __( 'Comments and Trackbacks', 'genesis' ), array( $this, 'comments_box' ), $this->pagehook, 'main' );
		add_meta_box( 'genesis-theme-settings-posts', __( 'Content Archives', 'genesis' ), array( $this, 'post_archives_box' ), $this->pagehook, 'main' );
		add_meta_box( 'genesis-theme-settings-blogpage', __( 'Blog Page Template', 'genesis' ), array( $this, 'blogpage_box' ), $this->pagehook, 'main' );

		if ( current_user_can( 'unfiltered_html' ) )
			add_meta_box( 'genesis-theme-settings-scripts', __( 'Header and Footer Scripts', 'genesis' ), array( $this, 'scripts_box' ), $this->pagehook, 'main' );

		if ( current_theme_supports( 'somo-affiliate-settings-option' ) )
			add_meta_box( 'genesis-theme-settings-somo-affiliate-settings', __( 'Affiliate Settings', 'somo' ), array( $this, 'affiliate_settings_box' ), $this->pagehook, 'main' );

		do_action( 'genesis_theme_settings_metaboxes', $this->pagehook );
	}

	function info_box() {
		?>
		<p><strong><?php _e( 'Version:', 'somo' ); ?></strong> <?php echo $this->get_field_value( 'theme_version' ); ?> &#x000B7; <strong><?php _e( 'DB Version:', 'somo' ); ?></strong> <?php echo $this->get_field_value( 'db_version' ); ?> &#x000B7; <strong><?php _e( 'Released:', 'genesis' ); ?></strong> <?php echo SOMO_THEME_RELEASE_DATE; ?></p>

		<?php
		if ( current_theme_supports( 'somo-auto-updates' ) ) :
			?>
			<p><span class="description"><?php sprintf( __( 'This can be helpful for diagnosing problems with your theme when seeking assistance in the <a href="%s" target="_blank">support forums</a>.', 'genesis' ), 'http://www.studiopress.com/support/' ); ?></span></p>

			<p>
				<label for="<?php echo $this->get_field_id( 'update' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'update' ); ?>" id="<?php echo $this->get_field_id( 'update' ); ?>" value="1"<?php checked( $this->get_field_value( 'update' ) ) . disabled( is_super_admin(), 0 ); ?> />
					<?php _e( 'Enable Automatic Updates', 'genesis' ); ?></label>
			</p>

			<div id="somo_update_notification_setting">
				<?php $status = get_site_option( 'somo_updates_api_status', '' ); ?>
				<input type="hidden" name="<?php echo $this->get_field_name( 'somo_updates_api_status' ); ?>" id="<?php echo $this->get_field_id( 'somo_updates_api_status' ); ?>" value="<?php echo esc_attr( $status ); ?>" />
				<div>
					<?php
					if ( '1' !== $status ) {
						if ( '0' === $status ) {
							$error = '<span style="color:red;">' . __( 'Credentials are not valid.', 'somo' ) . '</span> ';
							$placeholder = __( 'Please enter again', 'somo' );
						} else {
							$error = '';
							$placeholder = '';
						}
						echo $error . __( 'Please provide your credentials below to enable updates:', 'somo' );
						$display = 'block';
					} else {
						echo __( 'Your SomoThemes Updates API Credentials have been verified and saved.', 'somo' ) . ' <a href="#" id="somo_update_api_setting" onclick="javascript:somo_admin_toggle(\'somo_update_api_setting_content\')">' . __( 'Change', 'somo' ) . '</a>.';
						$display = 'none';
						$placeholder = __( 'Verified and saved', 'somo' );
					}
					?>
					<div id="somo_update_api_setting_content" style="display:<?php echo $display; ?>;margin:0.5em 0;">
						<label for="<?php echo $this->get_field_id( 'somo_updates_api_username' ); ?>" style="display:inline-block;min-width:170px;width:170px;"><?php _e( 'Your SomoThemes User ID', 'somo' ); ?></label>
						<input type="text" autocomplete="off" placeholder="<?php echo $placeholder; ?>" name="<?php echo $this->get_field_name( 'somo_updates_api_username' ); ?>" id="<?php echo $this->get_field_id( 'somo_updates_api_username' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'somo_updates_api_username' ) ); ?>" size="38" <?php disabled( false, is_super_admin() ); ?> /><br />
						<label for="<?php echo $this->get_field_id( 'somo_updates_api_key' ); ?>" style="display:inline-block;min-width:170px;width:170px;"><?php _e( 'Your SomoThemes API Key', 'somo' ); ?></label>
						<input type="text" autocomplete="off" placeholder="<?php echo $placeholder; ?>" name="<?php echo $this->get_field_name( 'somo_updates_api_key' ); ?>" id="<?php echo $this->get_field_id( 'somo_updates_api_key' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'somo_updates_api_key' ) ); ?>" size="38" <?php disabled( false, is_super_admin() ); ?> />
						<p>
							<span class="description"><?php printf( __( 'Provide your SomoThemes username and API key above so that your site receives update notifications whenever a new version of this theme is released. Your username and API key can be found inside your %s.', 'somo' ), sprintf( '<a href="%s" target="_blank">%s</a>', somo_get_membersite_url(), __( 'SomoThemes account', 'somo' ) ) ); ?></span>
						</p>
					</div>
				</div>


				<p>
					<label for="<?php echo $this->get_field_id( 'update_email' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'update_email' ); ?>" id="<?php echo $this->get_field_id( 'update_email' ); ?>" value="1"<?php checked( $this->get_field_value( 'update_email' ) ) . disabled( false, is_super_admin() ); ?> />
						<?php _e( 'Notify', 'genesis' ); ?></label>
					<input type="text" name="<?php echo $this->get_field_name( 'update_email_address' ); ?>" id="<?php echo $this->get_field_id( 'update_email_address' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'update_email_address' ) ); ?>" size="30"<?php disabled( false, is_super_admin() ); ?> />
					<label for="<?php echo $this->get_field_id( 'update_email_address' ); ?>"><?php _e( 'when updates are available', 'genesis' ); ?></label>
				</p>

				<p><span class="description"><?php _e( 'If you provide an email address above, you will be notified via email when a new version of this theme is available.', 'genesis' ); ?></span></p>
			</div>
			<?php
		endif;
	}

	/**
	 * Callback for Theme Settings Navigation Settings meta box.
	 *
	 * @since 1.0.0
	 *
	 * @uses genesis_nav_menu_supported()      Determine if a child theme supports a particular Genesis nav menu.
	 * @uses \Genesis_Admin::get_field_id()    Construct field ID.
	 * @uses \Genesis_Admin::get_field_name()  Construct field name.
	 * @uses \Genesis_Admin::get_field_value() Retrieve value of key under $this->settings_field.
	 *
	 * @see \Genesis_Admin_Settings::metaboxes() Register meta boxes on the Theme Settings page.
	 */
	function nav_box() {

		if ( !genesis_html5() ) :
			?>

			<p>
				<input type = "checkbox" name="<?php echo $this->get_field_name( 'superfish' ); ?>" id="<?php echo $this->get_field_id( 'superfish' ); ?>" value="1"<?php checked( $this->get_field_value( 'superfish' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'superfish' ); ?>"><?php _e( 'Load Superfish Script?', 'genesis' ); ?></label>
			</p>

			<?php
		endif;

		if ( genesis_nav_menu_supported( 'primary' ) ) :
			?>

			<h4><?php _e( 'Primary Navigation Extras', 'genesis' ); ?></h4>

			<?php if ( !has_nav_menu( 'primary' ) ) : ?>

				<p><span class="description"><?php printf( __( 'In order to view the Primary navigation menu settings, you must build a <a href="%s">custom menu</a>, then assign it to the Primary Menu Location.', 'genesis' ), admin_url( 'nav-menus.php' ) ); ?></span></p>

			<?php else : ?>

				<div id="genesis_nav_extras_settings">
					<p>
						<label for="<?php echo $this->get_field_id( 'nav_extras' ); ?>"><?php _e( 'Display the following:', 'genesis' ); ?></label>
						<select name="<?php echo $this->get_field_name( 'nav_extras' ); ?>" id="<?php echo $this->get_field_id( 'nav_extras' ); ?>">
							<option value=""><?php _e( 'None', 'genesis' ) ?></option>
							<option value="date"<?php selected( $this->get_field_value( 'nav_extras' ), 'date' ); ?>><?php _e( 'Today\'s date', 'genesis' ); ?></option>
							<option value="search"<?php selected( $this->get_field_value( 'nav_extras' ), 'search' ); ?>><?php _e( 'Search box', 'somo' ); ?></option>
						</select>
					</p>
				</div>
			<?php
			endif;
		endif;

		if ( current_theme_supports( 'somo-flyout-menus' ) ) {
			?>
			<h4><?php _e( 'Mobile Navigation Extras', 'somo' ); ?></h4>
			<div id="somo_mobile_nav_extras_settings">
				<p>
					<label for="<?php echo $this->get_field_id( 'mobile_nav_extras' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'mobile_nav_extras' ); ?>" id="<?php echo $this->get_field_id( 'mobile_nav_extras' ); ?>" value="1"<?php checked( $this->get_field_value( 'mobile_nav_extras' ) ); ?> />
						<?php _e( 'Show Search box on Mobile Navigation', 'somo' ); ?></label>
				</p>
			</div>
			<?php
		}
	}

	function affiliate_settings_box() {
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'somo_affiliate_id' ); ?>"><?php _e( 'Your ClickBank Username/Nickname:', 'somo' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'somo_affiliate_id' ); ?>" id="<?php echo $this->get_field_id( 'somo_affiliate_id' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'somo_affiliate_id' ) ); ?>" size="10" maxlength="10" />
		</p><p><span class="description"><?php _e( 'Specify your ClickBank username here if you would like to make money by promoting SomoThemes via a footer link on your site. If you do not already have a ClickBank account, you can easily <a href="https://www.clickbank.com/" target="_blank">sign up</a> here.', 'somo' ); ?></span></p>
		<?php
	}

}

