<?php
/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
add_action( 'admin_init', 'somo_add_user_profile_fields', 9 );
remove_action( 'admin_init', 'genesis_add_user_profile_fields' );

/**
 * Hook in the additional user profile fields.
 *
 * @since 1.0.0
 */
function somo_add_user_profile_fields() {

	add_action( 'show_user_profile', 'somo_user_social_fields' );
	add_action( 'edit_user_profile', 'somo_user_social_fields' );

	add_action( 'show_user_profile', 'somo_user_options_fields' );
	add_action( 'edit_user_profile', 'somo_user_options_fields' );

	add_action( 'show_user_profile', 'genesis_user_archive_fields' );
	add_action( 'edit_user_profile', 'genesis_user_archive_fields' );
	add_action( 'show_user_profile', 'genesis_user_seo_fields' );
	add_action( 'edit_user_profile', 'genesis_user_seo_fields' );
	add_action( 'show_user_profile', 'genesis_user_layout_fields' );
	add_action( 'edit_user_profile', 'genesis_user_layout_fields' );
}

/**
 * Add fields for user permissions for Genesis features to the user edit screen.
 *
 * Checkbox settings are:
 *
 * * Enable Genesis Admin Menu?
 * * Enable Social Settings Submenu?
 * * Enable SEO Settings Submenu?
 * * Enable Import/Export Submenu?
 *
 * @since 1.0.0
 *
 * @param \WP_User $user User object.
 *
 * @return false Return false if current user can not edit users.
 */
function somo_user_options_fields( $user ) {

	if ( !current_user_can( 'edit_users', $user->ID ) )
		return false;
	?>
	<h3><?php _e( 'User Permissions', 'genesis' ); ?></h3>
	<table class="form-table">
		<tbody>
			<tr>
				<th scope="row" valign="top"><?php _e( 'Genesis Admin Menus', 'genesis' ); ?></th>
				<td>
					<label for="meta[genesis_admin_menu]"><input id="meta[genesis_admin_menu]" name="meta[genesis_admin_menu]" type="checkbox" value="1" <?php checked( get_the_author_meta( 'genesis_admin_menu', $user->ID ) ); ?> />
						<?php _e( 'Enable Genesis Admin Menu?', 'genesis' ); ?></label><br />

					<?php if ( !( defined( 'SOMO_SOCIAL_SEO_DISABLED' ) && SOMO_SOCIAL_SEO_DISABLED ) ) { ?>
						<label for="meta[somo_social_settings_menu]"><input id="meta[somo_social_settings_menu]" name="meta[somo_social_settings_menu]" type="checkbox" value="1" <?php checked( get_the_author_meta( 'somo_social_settings_menu', $user->ID ) ); ?> />
							<?php _e( 'Enable Social Settings Submenu?', 'somo' ); ?></label><br />
					<?php } ?>
					<?php if ( !( defined( 'GENESIS_SEO_DISABLED' ) && GENESIS_SEO_DISABLED ) ) { ?>
						<label for = "meta[genesis_seo_settings_menu]"><input id = "meta[genesis_seo_settings_menu]" name = "meta[genesis_seo_settings_menu]" type = "checkbox" value = "1" <?php checked( get_the_author_meta( 'genesis_seo_settings_menu', $user->ID ) );
						?> />
							<?php _e( 'Enable SEO Settings Submenu?', 'genesis' ); ?></label><br />
					<?php } ?>

					<label for="meta[somo_quick_setup_menu]"><input id="meta[somo_quick_setup_menu]" name="meta[somo_quick_setup_menu]" type="checkbox" value="1" <?php checked( get_the_author_meta( 'somo_quick_setup_menu', $user->ID ) ); ?> />
						<?php _e( 'Enable Quick Setup Submenu?', 'somo' ); ?></label>
				</td>
			</tr>
		</tbody>
	</table>
	<?php
}

/** Add options for social profiles on the Author Profile Settings page */
function somo_user_social_fields( $user ) {
	if ( !current_user_can( 'edit_users', $user->ID ) )
		return false;
	?>
	<h3><?php _e( 'Social Profile Settings', 'somo' ); ?></h3>
	<p><span class="description"><?php _e( 'These settings apply to your author profile. Enter the URL(s) for your social profiles below. If you leave certain URLs blank, they will not be used. You can choose to display your social profiles in the author box on your posts and/or on your author archive page.', 'somo' ); ?></span></p>
	<table class="form-table">
		<tbody>
			<tr>
				<th scope="row" valign="top"><label for="social_author_twitter_profile"><?php _e( 'Twitter URL', 'somo' ); ?></label></th>
				<td><input name="meta[social_author_twitter_profile]" id="social_author_twitter_profile" type="text" value="<?php echo esc_url( get_the_author_meta( 'social_author_twitter_profile', $user->ID ) ); ?>" class="regular-text" /></td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="social_author_facebook_profile"><?php _e( 'Facebook URL', 'somo' ); ?></label></th>
				<td><input name="meta[social_author_facebook_profile]" id="social_author_facebook_profile" type="text" value="<?php echo esc_url( get_the_author_meta( 'social_author_facebook_profile', $user->ID ) ); ?>" class="regular-text" /></td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="social_author_gplus_profile"><?php _e( 'Google+ URL', 'somo' ); ?></label></th>
				<td><input name="meta[social_author_gplus_profile]" id="social_author_gplus_profile" type="text" value="<?php echo esc_url( get_the_author_meta( 'social_author_gplus_profile', $user->ID ) ); ?>" class="regular-text" /></td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="social_author_pinterest_profile"><?php _e( 'Pinterest URL', 'somo' ); ?></label></th>
				<td><input name="meta[social_author_pinterest_profile]" id="social_author_pinterest_profile" type="text" value="<?php echo esc_url( get_the_author_meta( 'social_author_pinterest_profile', $user->ID ) ); ?>" class="regular-text" /></td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="social_author_linkedin_profile"><?php _e( 'LinkedIn URL', 'somo' ); ?></label></th>
				<td><input name="meta[social_author_linkedin_profile]" id="social_author_linkedin_profile" type="text" value="<?php echo esc_url( get_the_author_meta( 'social_author_linkedin_profile', $user->ID ) ); ?>" class="regular-text" /></td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="social_author_youtube_profile"><?php _e( 'YouTube URL', 'somo' ); ?></label></th>
				<td><input name="meta[social_author_youtube_profile]" id="social_author_youtube_profile" type="text" value="<?php echo esc_url( get_the_author_meta( 'social_author_youtube_profile', $user->ID ) ); ?>" class="regular-text" /></td>
			</tr>
		</tbody>
	</table>
	<table class="form-table">
		<tbody>
			<tr>
				<th scope="row" valign="top"><?php _e( 'Display Options', 'somo' ); ?></th>
				<td>
					<input id="meta[social_author_social_profiles_single]" name="meta[social_author_social_profiles_single]" type="checkbox" value="1" <?php checked( get_the_author_meta( 'social_author_social_profiles_single', $user->ID ) ); ?> />
					<label for="meta[social_author_social_profiles_single]"><?php _e( 'Enable Social Profiles on Author Box on Your Posts?', 'somo' ); ?></label><br />
					<input id="meta[social_author_social_profiles_archive]" name="meta[social_author_social_profiles_archive]" type="checkbox" value="1" <?php checked( get_the_author_meta( 'social_author_social_profiles_archive', $user->ID ) ); ?> />
					<label for="meta[social_author_social_profiles_archive]"><?php _e( 'Enable Social Profiles on Author Box on Your Archives?', 'somo' ); ?></label>
				</td>
			</tr>
		</tbody>
	</table>
	<p><span class="description"></span></p>
	<?php
}

add_action( 'personal_options_update', 'somo_user_meta_save' );
add_action( 'edit_user_profile_update', 'somo_user_meta_save' );

function somo_user_meta_save( $user_id ) {

	if ( !current_user_can( 'edit_posts', $user_id ) )
		return;

	if ( !isset( $_POST[ 'meta' ] ) || !is_array( $_POST[ 'meta' ] ) )
		return;

	$meta = wp_parse_args(
		$_POST[ 'meta' ], array(
		'somo_social_settings_menu' => '',
		'somo_quick_setup_menu' => '',
		'social_author_twitter_profile' => '',
		'social_author_facebook_profile' => '',
		'social_author_gplus_profile' => '',
		'social_author_pinterest_profile' => '',
		'social_author_linkedin_profile' => '',
		'social_author_youtube_profile' => '',
		'social_author_social_profiles_single' => '',
		'social_author_social_profiles_archive' => '',
		)
	);

	foreach ( $meta as $key => $value ) {
		update_user_meta( $user_id, $key, $value );
	}
}

add_filter( 'get_the_author_somo_social_settings_menu', 'genesis_user_meta_default_on', 10, 2 );
add_filter( 'get_the_author_somo_quick_setup_menu', 'genesis_user_meta_default_on', 10, 2 );

