<?php
/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */

/**
 * Registers a new admin page, providing content and corresponding menu item for the "What's new" page.
 *
 * @package Genesis\Admin
 *
 * @since 1.0.0
 */
class Somo_Admin_Welcome extends Genesis_Admin_Basic {

	/**
	 * Create the page.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		$page_id = 'somo-welcome';

		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => 'genesis',
				'menu_title' => __( 'Getting Started', 'somo' ),
				'page_title' => sprintf( __( 'Welcome to %s %s', 'somo' ), SOMO_PARENT_THEME_NAME, SOMO_PARENT_THEME_BRANCH ),
			)
		);

		$this->create( $page_id, $menu_ops );

		add_action( 'admin_enqueue_scripts', 'add_thickbox' );
	}

	/**
	 * Callback for displaying the What's New admin page.
	 *
	 * @since 1.0.0
	 */
	public function admin() {
		?>
		<div class="wrap about-wrap">

			<img src="<?php echo get_template_directory_uri() . '/lib/admin/images/somo-badge.png'; ?>" class="alignright whats-new" />

			<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>

			<div class="about-text"><?php printf( __( 'Thank you for choosing SomoThemes. Every SomoTheme makes your website social and mobile friendly.', 'somo' ), 'SomoThemes' ); ?></div>
			<h2 class="nav-tab-wrapper">
				<a href="<?php menu_page_url( 'somo-welcome' ); ?>" class="nav-tab nav-tab-active">
					<?php _e( 'Getting Started', 'somo' ); ?>
				</a><a href="<?php menu_page_url( 'somo-about' ); ?>" class="nav-tab">
					<?php _e( 'About' ); ?>
				</a>
			</h2>
			<div id="welcome-panel" class="welcome-panel">
				<div class="welcome-panel-content">
					<h3><?php _e( 'Getting started is easy!' ); ?></h3>
					<p class="about-description"><?php _e( 'We&#8217;ve assembled some links to get you started:' ); ?></p>
					<div class="welcome-panel-column-container">
						<div class="welcome-panel-column">
							<?php if ( current_theme_supports( 'somo-quick-setup-menu' ) ) { ?>
								<h4><?php _e( 'Quick Setup' ); ?></h4>
								<a class="button button-primary button-hero" href="<?php menu_page_url( 'somo-quick-setup' ); ?>"><?php _e( 'Run Quick Setup' ); ?></a>
								<ul><li><?php printf( __( 'or, <a href="%s">configure theme settings</a>' ), menu_page_url( 'somo', false ) ); ?></li></ul>
							<?php } else { ?>
								<h4><?php _e( 'Theme Settings' ); ?></h4>
								<a class="button button-primary button-hero" href="<?php menu_page_url( 'somo' ); ?>"><?php _e( 'Configure Settings' ); ?></a>
							<?php } ?>
						</div>
						<div class="welcome-panel-column">
							<h4><?php _e( 'Next Steps' ); ?></h4>
							<ul>
								<?php if ( current_theme_supports( 'somo-social-settings-menu' ) ) { ?>
									<li><a href="<?php menu_page_url( 'somo-social-settings' ); ?>" class="welcome-icon welcome-comments"><?php _e( 'Optimize for social media' ); ?></a></li>
								<?php } else { ?>
									<li><s><a href="#" class="welcome-icon welcome-comments" title="<?php _e( 'We are guessing that some popular social media optimization plugins are already active on your site, so we thought of disabling this theme feature.' ); ?>"><?php _e( 'Optimize for social media' ); ?></a></s></li>
								<?php } ?>
								<?php if ( current_theme_supports( 'genesis-seo-settings-menu' ) ) { ?>
									<li><a href="<?php menu_page_url( 'somo-seo-settings' ); ?>" class="welcome-icon"><?php _e( 'Optimize for search engines' ); ?></a></li>
								<?php } else { ?>
									<li><s><a href="#" class="welcome-icon" title="<?php _e( 'We are guessing that some popular search engine optimization plugins are already active on your site, so we thought of disabling this theme feature.' ); ?>"><?php _e( 'Optimize for search engines' ); ?></a></s></li>
								<?php } ?>
								<li><?php printf( '<a href="%s" class="welcome-icon welcome-view-site">' . __( 'View your site' ) . '</a>', home_url( '/' ) ); ?></li>
							</ul>
						</div>
						<div class="welcome-panel-column welcome-panel-last">
							<h4><?php _e( 'More Actions' ); ?></h4>
							<ul>
								<li><?php printf( '<div class="welcome-icon welcome-widgets-menus">' . __( 'Manage <a href="%1$s">widgets</a> or <a href="%2$s">menus</a>' ) . '</div>', admin_url( 'widgets.php' ), admin_url( 'nav-menus.php' ) ); ?></li>
								<li><?php printf( '<a href="%s" class="welcome-icon welcome-learn-more">' . __( 'View online tutorials' ) . '</a>', __( 'http://somothemes.com/tutorials/' ) ); ?></li>
								<li><?php printf( '<a href="%s" class="welcome-icon welcome-edit-page">' . __( 'Reach us for help' ) . '</a>', __( 'http://one.somothemes.com/support/' ) ); ?></li>
							</ul>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

}
