<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
remove_action( 'genesis_meta', 'genesis_load_stylesheet' );
add_action( 'genesis_meta', 'somo_load_stylesheet' );

/**
 * Echo reference to the style sheet.
 *
 * If a child theme is active, it loads the child theme's stylesheet, otherwise, it loads the main style sheet.
 *
 * @since 1.0.0
 *
 * @see somo_enqueue_main_stylesheet() Enqueue main style sheet.
 */
function somo_load_stylesheet() {
	add_action( 'wp_enqueue_scripts', 'somo_enqueue_main_stylesheet', 5 );
}

function somo_enqueue_main_stylesheet() {
	$version = defined( 'CHILD_THEME_VERSION' ) && CHILD_THEME_VERSION ? CHILD_THEME_VERSION : SOMO_PARENT_THEME_VERSION;
	$handle = defined( 'CHILD_THEME_NAME' ) && CHILD_THEME_NAME ? sanitize_title_with_dashes( CHILD_THEME_NAME ) : SOMO_PARENT_THEME_SLUG;

	wp_enqueue_style( $handle, get_stylesheet_uri(), false, $version );

	$current_style = genesis_get_option( 'style_selection' );
	if ( $current_style ) {
		wp_enqueue_style( $current_style, CHILD_URL . '/' . $current_style . '.css', false, $version );
	}
}

add_action( 'admin_print_styles', 'somo_load_admin_styles' );

/**
 * Enqueue Somo admin styles.
 *
 * @since 1.0.0
 *
 * @uses GENESIS_CSS_URL
 * @uses PARENT_THEME_VERSION
 */
function somo_load_admin_styles() {
	$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
	wp_enqueue_style( 'somo_admin_css', SOMO_CSS_URL . "/admin$suffix.css", array( ), SOMO_PARENT_THEME_VERSION );
}
