<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
function somo_get_new_features() {

	$tagline = __( 'Your productivity is at the forefront of our thoughts.', 'somo' );

	$new_features = array( );

	$new_features[ ] = array(
		'title' => __( 'Quick Setup Tools', 'somo' ),
		'content' => __( 'We have added a set of productivity tools like One Click Setup, One Click Cleanup, along with import/export tools to help you get your sites up and running quickly. If you are a developer, these tools would be a great addition to your toolbox, helping you carry out mundane setup tasks in seconds.', 'somo' ),
	);
	$new_features[ ] = array(
		'title' => __( 'Automatic Updates', 'somo' ),
		'content' => __( 'Every SomoTheme will now support automatic updates, so you no longer have to do them manually. Updates are now just a click away. You can also set your site to send you email notifications to let you know when an update is available.', 'somo' ),
	);
	$new_features[ ] = array(
		'title' => __( 'Help at Your Fingertips', 'somo' ),
		'content' => __( 'We’ve added contextual help under the Help tab of every theme settings screen explaining all the options on the page right when you need it. Just click on the help tab located at top-right corner of the screen on the theme settings pages to access help content or to reach us.', 'somo' ),
	);
	$new_features[ ] = array(
		'title' => __( 'HTML5 Markup and Microdata', 'somo' ),
		'content' => sprintf( __( 'HTML5 is the new HTML standard and all our themes embrace the HTML5 standard. In addition, all our themes support microdata, thus adding to your web pages extra semantic information about your content. %s helps search engines to classify and index your content better.', 'somo' ), sprintf( '<a href="%s" target="_blank">%s</a>', 'http://schema.org/', __( 'Microdata', 'somo' ) ) ),
	);
	$new_features[ ] = array(
		'title' => __( 'Standalone Themes', 'somo' ),
		'content' => __( 'You can use our turn-key themes without having to install any child theme. We recommend using child themes only when you wish to customize the original theme by changing its code, and this should be done inhouse in almost all the cases. You may use sample child themes provided if you would like to customize any of our themes. Using child themes for inhouse customization ensures that you dont lose your changes whenever we release an update to the parent theme.', 'somo' ),
	);

	$new_features_content = array(
		'tagline' => $tagline,
		'data' => $new_features,
	);
	return apply_filters( 'somo_get_new_features', $new_features_content );
}

/**
 * Aggregate and return credits data
 *
 * @since 1.0.0
 *
 * @return string
 */
function somo_get_credits() {
	$credits = array( );

	$credits[ 'groups' ][ 'project-leaders' ] = array(
		'name' => __( 'Project Leads', 'somo' ),
		'type' => 'default',
		'shuffle' => '1',
		'data' => somo_get_credits_project_leads(),
	);

//	$credits[ 'groups' ][ 'contributing-developers' ] = array(
//		'name' => __( 'Contributors', 'somo' ),
//		'type' => 'default',
//		'shuffle' => '1',
//		'data' => somo_get_credits_contributors(),
//	);

	$credits[ 'groups' ][ 'credits-list' ] = array(
		'name' => __( 'External Libraries and Credits', 'somo' ),
		'type' => 'libraries',
		'data' => somo_get_credits_external_libraries(),
	);

	return $credits;
}

/**
 * Populate and return credits data for project leads
 *
 * @since 1.0.0
 *
 * @return array
 */
function somo_get_credits_project_leads() {
	$project_leads = array( );
	$project_leads[ ] = array(
		'name' => 'Riyaz Sayyad',
		'slug' => 'riyaz',
		'title' => __( 'Cofounder, Lead Developer', 'somo' ),
		'gravatar' => 'a4ce4ed9d35acd7ae72cb19a6906f10c',
		'web' => 'https://twitter.com/riyaznet',
	);
	$project_leads[ ] = array(
		'name' => 'Daniel Tan',
		'slug' => 'daniel',
		'title' => __( 'Cofounder, Project Lead', 'somo' ),
		'gravatar' => '255e5881f4d89c3d00fca318dc167582',
		'web' => 'https://plus.google.com/114142342968774552647/',
	);
	return $project_leads;
}

/**
 * Populate and return credits data for contributors
 *
 * @since 1.0.0
 *
 * @return array
 */
function somo_get_credits_contributors() {
	$contributors = array( );

	$contributors[ ] = array(
		'name' => 'Name 1',
		'slug' => '1',
		'title' => __( 'Contributor', 'somo' ),
		'gravatar' => '',
		'web' => '',
	);
	$contributors[ ] = array(
		'name' => 'Name 2',
		'slug' => '2',
		'title' => __( 'Contributor', 'somo' ),
		'gravatar' => '',
		'web' => '',
	);
	$contributors[ ] = array(
		'name' => 'Name 3',
		'slug' => '3',
		'title' => __( 'Contributor', 'somo' ),
		'gravatar' => '',
		'web' => '',
	);
	$contributors[ ] = array(
		'name' => 'Name 4',
		'slug' => '4',
		'title' => __( 'Contributor', 'somo' ),
		'gravatar' => '',
		'web' => '',
	);
	$contributors[ ] = array(
		'name' => 'Name 5',
		'slug' => '5',
		'title' => __( 'Contributor', 'somo' ),
		'gravatar' => '',
		'web' => '',
	);
	$contributors[ ] = array(
		'name' => 'Name 6',
		'slug' => '6',
		'title' => __( 'Contributor', 'somo' ),
		'gravatar' => '',
		'web' => '',
	);

	return $contributors;
}

/**
 * Populate and return credits data for external libraries
 *
 * @since 1.0.0
 *
 * @return array
 */
function somo_get_credits_external_libraries() {
	$external_libraries = array( );
	$adapted = __( '(adapted)', 'somo' );
	$external_libraries[ ] = array(
		'name' => 'Genesis Framework',
		'web' => 'http://studiopress.com',
	);
	$external_libraries[ ] = array(
		'name' => 'jQuery',
		'web' => 'http://jquery.com/',
	);
	$external_libraries[ ] = array(
		'name' => 'WordPress Importer',
		'web' => 'http://wordpress.org/plugins/wordpress-importer/',
		'extra' => $adapted,
	);
	$external_libraries[ ] = array(
		'name' => 'Widget Settings Importer/Exporter',
		'web' => 'http://vocecommunications.com',
		'extra' => $adapted,
	);

	$external_libraries = apply_filters( 'somo_get_credits_external_libraries', $external_libraries );
	usort( $external_libraries, 'somo_credits_natsort' );
	return $external_libraries;
}

/**
 * Builds a link with credits data array
 *
 * @since 1.0.0
 *
 * @param string $data Credits data
 */
function somo_credits_build_object_link( &$data ) {
	$extra = isset( $data[ 'extra' ] ) && !empty( $data[ 'extra' ] ) ? ' <span>' . esc_html( $data[ 'extra' ] ) . '</span>' : '';
	$data = '<a href="' . esc_url( $data[ 'web' ] ) . '">' . $data[ 'name' ] . '</a>' . $extra;
}

/**
 * Compares two credits array by value of the 'name' key using case-insensitive "natural order" algorithm
 *
 * @since 1.0.0
 *
 * @uses strnatcasecmp
 *
 * @param array $arr1
 * @param array $arr2
 * @return int
 */
function somo_credits_natsort( array $arr1, array $arr2 ) {
	if ( isset( $arr1[ 'name' ] ) && !empty( $arr1[ 'name' ] ) && isset( $arr2[ 'name' ] ) && !empty( $arr2[ 'name' ] ) ) {
		return ( int ) strnatcasecmp( strval( $arr1[ 'name' ] ), strval( $arr2[ 'name' ] ) );
	} else {
		return ( int ) 0;
	}
}

add_filter( 'admin_body_class', 'somo_add_freedoms_class', 15 );

/**
 * Add freedoms-php body class to about page
 *
 * @param string $classes
 * @return string $classes
 */
function somo_add_freedoms_class( $classes ) {
	$screen = get_current_screen();
	if ( 'admin_page_somo-about' == $screen->id ) {
		$classes .= " freedoms-php";
	}
	return $classes;
}
