<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
/**
 * Run the genesis_pre Hook
 *
 * @since 1.0.0
 */
do_action( 'genesis_pre' );

add_action( 'genesis_init', 'somo_theme_support' );

/**
 * Activates default theme features.
 *
 * @since 1.0.0
 *
 * @uses add_theme_support
 * @uses current_theme_supports
 */
function somo_theme_support() {

	add_theme_support( 'menus' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'genesis-inpost-layouts' );
	add_theme_support( 'genesis-archive-layouts' );
	add_theme_support( 'genesis-admin-menu' );
	add_theme_support( 'somo-social-settings-menu' );
	add_theme_support( 'genesis-seo-settings-menu' );
//	add_theme_support( 'genesis-import-export-menu' );
	add_theme_support( 'somo-quick-setup-menu' );
	add_theme_support( 'genesis-readme-menu' );
//	add_theme_support( 'genesis-auto-updates' );
	add_theme_support( 'somo-auto-updates' );
	add_theme_support( 'genesis-breadcrumbs' );

	//* Maybe add support for Genesis menus
	if ( !current_theme_supports( 'genesis-menus' ) ) {
		add_theme_support( 'genesis-menus', array(
			'primary' => __( 'Primary Navigation Menu', 'genesis' ),
			'secondary' => __( 'Secondary Navigation Menu', 'genesis' ),
			'mobile' => __( 'Mobile Navigation Menu', 'somo' ),
		) );
	}

	add_theme_support( 'somo-flyout-menus', array(
		'primary', //Primary Navigation Menu Location
		'secondary', //Secondary Navigation Menu Location
		'mobile', //Mobile menu (If set, other menus will not be displayed on small screen devices)
	) );

	//* Maybe add support for structural wraps
	if ( !current_theme_supports( 'genesis-structural-wraps' ) ) {
		add_theme_support( 'genesis-structural-wraps', array( 'header', 'menu-primary', 'menu-secondary', 'site-inner', 'footer-widgets', 'footer' ) );
	}

	//* Turn on HTML5, responsive viewport
	add_theme_support( 'html5' );
	add_theme_support( 'genesis-responsive-viewport' );

	//* default value can be overriden by individual themes
	add_theme_support( 'genesis-footer-widgets', 3 );

	//* Add Somo specific theme supports
	add_theme_support( 'somo-social-settings-menu' );
//	add_theme_support( 'somo-affiliate-settings-option' );
}

add_action( 'genesis_init', 'genesis_post_type_support' );

/**
 * Initialize post type support for Genesis features (Layout selector, SEO).
 *
 * @since 1.0.0
 *
 * @uses add_post_type_support
 */
function genesis_post_type_support() {

	add_post_type_support( 'post', array( 'genesis-seo', 'genesis-scripts', 'genesis-layouts' ) );
	add_post_type_support( 'page', array( 'genesis-seo', 'genesis-scripts', 'genesis-layouts' ) );
}

add_action( 'genesis_init', 'somo_constants' );

/**
 * This function defines the SomoThemes constants
 *
 * @since 1.0.0
 */
function somo_constants() {

	//* SomoThemes Directory Location Constants
	define( 'SOMO_PARENT_DIR', get_template_directory() );
	define( 'PARENT_DIR', SOMO_PARENT_DIR . '/lib/genesis' ); //* Modified */
	define( 'CHILD_DIR', get_stylesheet_directory() );
	define( 'SOMO_IMAGES_DIR', SOMO_PARENT_DIR . '/images' );
	define( 'SOMO_LIB_DIR', SOMO_PARENT_DIR . '/lib' );
	define( 'SOMO_ADMIN_DIR', SOMO_LIB_DIR . '/admin' );
	define( 'SOMO_ADMIN_IMAGES_DIR', SOMO_LIB_DIR . '/admin/images' );
	define( 'SOMO_JS_DIR', SOMO_LIB_DIR . '/js' );
	define( 'SOMO_CSS_DIR', SOMO_LIB_DIR . '/css' );
	define( 'SOMO_CLASSES_DIR', SOMO_LIB_DIR . '/classes' );
	define( 'SOMO_FUNCTIONS_DIR', SOMO_LIB_DIR . '/functions' );
	define( 'SOMO_SHORTCODES_DIR', SOMO_LIB_DIR . '/shortcodes' );
	define( 'SOMO_STRUCTURE_DIR', SOMO_LIB_DIR . '/structure' );
	define( 'SOMO_DATA_DIR', SOMO_PARENT_DIR . '/sample' );
//*    define('SOMO_TOOLS_DIR', SOMO_LIB_DIR . '/tools');
//*   define('SOMO_WIDGETS_DIR', SOMO_LIB_DIR . '/widgets');
//	if ( !defined( 'GENESIS_LANGUAGES_DIR' ) )
//		define( 'GENESIS_LANGUAGES_DIR', SOMO_PARENT_DIR . '/lib/languages/genesis' );

	if ( !defined( 'SOMO_LANGUAGES_DIR' ) ) {
		//* falls back to theme directory SOMO_PARENT_DIR if child theme is not active
		define( 'SOMO_LANGUAGES_DIR', CHILD_DIR . '/languages' );
	}

	//* SomoThemes Directory URL Location Constants
	define( 'SOMO_PARENT_URL', get_template_directory_uri() );
	define( 'PARENT_URL', get_template_directory_uri() . '/lib/genesis' ); //* Modified */
	define( 'CHILD_URL', get_stylesheet_directory_uri() );
	define( 'SOMO_IMAGES_URL', SOMO_PARENT_URL . '/images' );
	define( 'SOMO_LIB_URL', SOMO_PARENT_URL . '/lib' );
	define( 'SOMO_ADMIN_URL', SOMO_LIB_URL . '/admin' );
	define( 'SOMO_ADMIN_IMAGES_URL', SOMO_ADMIN_URL . '/images' );
	define( 'SOMO_JS_URL', SOMO_LIB_URL . '/js' );
	define( 'SOMO_CSS_URL', SOMO_LIB_URL . '/css' );
	define( 'SOMO_CLASSES_URL', SOMO_LIB_URL . '/classes' );
	define( 'SOMO_FUNCTIONS_URL', SOMO_LIB_URL . '/functions' );
	define( 'SOMO_SHORTCODES_URL', SOMO_LIB_URL . '/shortcodes' );
	define( 'SOMO_STRUCTURE_URL', SOMO_LIB_URL . '/structure' );
//    define('SOMO_WIDGETS_URL', SOMO_LIB_URL . '/widgets');
	define( 'SOMO_DATA_URL', SOMO_PARENT_URL . '/sample' );
	//* Define Genesis Theme Info Constants
	define( 'PARENT_THEME_NAME', 'Genesis' );
	define( 'PARENT_THEME_VERSION', '2.0.1' );
	define( 'PARENT_THEME_BRANCH', '2.0' );
	define( 'PARENT_DB_VERSION', '2007' );
#	define( 'PARENT_THEME_RELEASE_DATE', 'TBD' );
	define( 'PARENT_THEME_RELEASE_DATE', date_i18n( 'F j, Y', '1377061200' ) );

	//* Define Genesis Directory Location Constants

	define( 'GENESIS_IMAGES_DIR', PARENT_DIR . '/images' );
	define( 'GENESIS_LIB_DIR', PARENT_DIR . '/lib' );
	define( 'GENESIS_ADMIN_DIR', GENESIS_LIB_DIR . '/admin' );
	define( 'GENESIS_ADMIN_IMAGES_DIR', GENESIS_LIB_DIR . '/admin/images' );
	define( 'GENESIS_JS_DIR', GENESIS_LIB_DIR . '/js' );
	define( 'GENESIS_CSS_DIR', GENESIS_LIB_DIR . '/css' );
	define( 'GENESIS_CLASSES_DIR', GENESIS_LIB_DIR . '/classes' );
	define( 'GENESIS_FUNCTIONS_DIR', GENESIS_LIB_DIR . '/functions' );
	define( 'GENESIS_SHORTCODES_DIR', GENESIS_LIB_DIR . '/shortcodes' );
	define( 'GENESIS_STRUCTURE_DIR', GENESIS_LIB_DIR . '/structure' );
	define( 'GENESIS_TOOLS_DIR', GENESIS_LIB_DIR . '/tools' );
	define( 'GENESIS_WIDGETS_DIR', GENESIS_LIB_DIR . '/widgets' );

	//* Define Genesis URL Location Constants

	define( 'GENESIS_IMAGES_URL', SOMO_IMAGES_URL );
	define( 'GENESIS_LIB_URL', PARENT_URL . '/lib' );
	define( 'GENESIS_ADMIN_URL', GENESIS_LIB_URL . '/admin' );
	define( 'GENESIS_ADMIN_IMAGES_URL', SOMO_ADMIN_IMAGES_URL );
	define( 'GENESIS_JS_URL', GENESIS_LIB_URL . '/js' );
	define( 'GENESIS_CLASSES_URL', GENESIS_LIB_URL . '/classes' );
	define( 'GENESIS_CSS_URL', GENESIS_LIB_URL . '/css' );
	define( 'GENESIS_FUNCTIONS_URL', GENESIS_LIB_URL . '/functions' );
	define( 'GENESIS_SHORTCODES_URL', GENESIS_LIB_URL . '/shortcodes' );
	define( 'GENESIS_STRUCTURE_URL', GENESIS_LIB_URL . '/structure' );
	define( 'GENESIS_WIDGETS_URL', GENESIS_LIB_URL . '/widgets' );

	//* Define Settings Field Constants (for DB storage)
	define( 'GENESIS_SETTINGS_FIELD', apply_filters( 'somo_settings_field', 'somo-settings' ) );
	define( 'GENESIS_SEO_SETTINGS_FIELD', apply_filters( 'somo_seo_settings_field', 'somo-seo-settings' ) );
	define( 'SOMO_SOCIAL_SETTINGS_FIELD', apply_filters( 'somo_social_settings_field', 'somo-social-settings' ) );
	define( 'SOMO_QUICK_SETUP_SETTINGS_FIELD', apply_filters( 'somo_quick_setup_field', 'somo-quick-setup-settings' ) );
	define( 'GENESIS_CPT_ARCHIVE_SETTINGS_FIELD_PREFIX', apply_filters( 'genesis_cpt_archive_settings_field_prefix', 'somo-cpt-archive-settings-' ) );

	if ( !defined( 'SOMO_UPDATES_API_ROOT' ) )
		define( 'SOMO_UPDATES_API_ROOT', 'http://one.somothemes.com/' );
}

add_action( 'genesis_init', 'somo_i18n' );

/**
 * Load the Genesis textdomain for internationalization.
 *
 * @since 1.0.0
 *
 * @uses load_theme_textdomain()
 *
 */
function somo_i18n() {

	/** Load Genesis Localization text domain */
	load_theme_textdomain( 'genesis', SOMO_LANGUAGES_DIR );

	/** Load Somo Localization text domain */
	load_theme_textdomain( 'somo', SOMO_LANGUAGES_DIR );

	/** Load Child theme localization text domain if available */
	if ( defined( 'CHILD_TEXTDOMAIN' ) && defined( 'CHILD_LANGUAGES_DIR' ) ) {
		load_theme_textdomain( CHILD_TEXTDOMAIN, CHILD_LANGUAGES_DIR );
	}
}

add_action( 'genesis_init', 'somo_load_framework' );

/**
 * Loads all the framework files and features.
 *
 * The genesis_pre_framework action hook is called before any of the files are
 * required().
 *
 * If a child theme defines GENESIS_LOAD_FRAMEWORK as false before requiring
 * this init.php file, then this function will abort before any other framework
 * files are loaded.
 *
 * @since 1.0.0
 *
 * @uses require_if_theme_supports()
 *
 */
function somo_load_framework() {

	//* Run the genesis_pre_framework Hook
	do_action( 'genesis_pre_framework' );

	//* Short circuit, if necessary
	if ( defined( 'GENESIS_LOAD_FRAMEWORK' ) && GENESIS_LOAD_FRAMEWORK === false )
		return;

	//* Load Framework
	require_once( GENESIS_LIB_DIR . '/framework.php' );

	//* Load Classes
	require_once( GENESIS_CLASSES_DIR . '/admin.php' );
	require_if_theme_supports( 'genesis-breadcrumbs', GENESIS_CLASSES_DIR . '/breadcrumb.php' );
	require_once( GENESIS_CLASSES_DIR . '/sanitization.php' );

	//* Load Functions
//	require_once( GENESIS_FUNCTIONS_DIR . '/upgrade.php' );
	require_once( SOMO_ADMIN_DIR . '/upgrade.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/compat.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/general.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/options.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/image.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/markup.php' );
	require_if_theme_supports( 'genesis-breadcrumbs', GENESIS_FUNCTIONS_DIR . '/breadcrumb.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/menu.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/layout.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/formatting.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/seo.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/widgetize.php' );
	require_once( SOMO_FUNCTIONS_DIR . '/widgetize.php' );
	require_once( GENESIS_FUNCTIONS_DIR . '/feed.php' );
	if ( apply_filters( 'genesis_load_deprecated', true ) )
		require_once( GENESIS_FUNCTIONS_DIR . '/deprecated.php' );

	//* Load Shortcodes
	require_once( GENESIS_SHORTCODES_DIR . '/post.php' );
	require_once( GENESIS_SHORTCODES_DIR . '/footer.php' );

	//* Load Structure
	require_once( GENESIS_STRUCTURE_DIR . '/header.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/footer.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/menu.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/layout.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/post.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/loops.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/comments.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/sidebar.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/archive.php' );
	require_once( GENESIS_STRUCTURE_DIR . '/search.php' );

	//* Load Admin
	if ( is_admin() ) :
		require_once( GENESIS_ADMIN_DIR . '/menu.php' );
		require_once( GENESIS_ADMIN_DIR . '/theme-settings.php' );
		require_once( GENESIS_ADMIN_DIR . '/seo-settings.php' );
		require_once( GENESIS_ADMIN_DIR . '/cpt-archive-settings.php' );
//		require_once( GENESIS_ADMIN_DIR . '/import-export.php' );
		require_once( GENESIS_ADMIN_DIR . '/inpost-metaboxes.php' );
//		require_once( GENESIS_ADMIN_DIR . '/whats-new.php' );
	endif;
	require_once( GENESIS_ADMIN_DIR . '/term-meta.php' );
	require_once( GENESIS_ADMIN_DIR . '/user-meta.php' );

	//* Load Javascript
	require_once( GENESIS_JS_DIR . '/load-scripts.php' );

	//* Load CSS
	require_once( GENESIS_CSS_DIR . '/load-styles.php' );

	//* Load Widgets
	require_once( GENESIS_WIDGETS_DIR . '/widgets.php' );

	/** Initialize SomoThemes Routines */
	if ( is_admin() ) {
		require_once( SOMO_ADMIN_DIR . '/menu.php' );
		require_once( SOMO_ADMIN_DIR . '/theme-settings.php' );
		require_once( SOMO_ADMIN_DIR . '/social-settings.php' );
		require_once( SOMO_ADMIN_DIR . '/seo-settings.php' );
		require_once( SOMO_ADMIN_DIR . '/cpt-archive-settings.php' );
//		require_once( SOMO_ADMIN_DIR . '/import-export.php' );
		require_once( SOMO_ADMIN_DIR . '/quick-setup.php' );
//		require_once( SOMO_ADMIN_DIR . '/somo-importer.php' );
		require_once( SOMO_ADMIN_DIR . '/welcome.php' );
		require_once( SOMO_ADMIN_DIR . '/about.php' );
		require_once( SOMO_ADMIN_DIR . '/pointers.php' );
	}
	require_once( SOMO_ADMIN_DIR . '/user-meta.php' );
	require_once( SOMO_FUNCTIONS_DIR . '/helper.php' );
	require_once( SOMO_FUNCTIONS_DIR . '/credits.php' );

	require_once( SOMO_STRUCTURE_DIR . '/header.php' );
	require_once( SOMO_STRUCTURE_DIR . '/menu.php' );
	require_once( SOMO_STRUCTURE_DIR . '/post.php' );
	require_once( SOMO_STRUCTURE_DIR . '/footer.php' );

	require_once( SOMO_SHORTCODES_DIR . '/footer.php' );

	//* Load Javascript
	require_once( SOMO_JS_DIR . '/load-scripts.php' );

	//* Load CSS
	require_once( SOMO_CSS_DIR . '/load-styles.php' );

	if ( is_readable( SOMO_PARENT_DIR . '/functions.theme.php' ) )
		require_once( SOMO_PARENT_DIR . '/functions.theme.php' );

	global $_genesis_formatting_allowedtags;
	$_genesis_formatting_allowedtags = genesis_formatting_allowedtags();
}

//* Run the genesis_init hook
do_action( 'genesis_init' );

//* Run the genesis_setup hook
do_action( 'genesis_setup' );

