<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */

/**
 * Add javascripts to HTML Head
 *
 * @since 1.0.0
 *
 */
//add_action( 'genesis_meta', 'somo_scripts' );

function somo_scripts() {
	//nothing yet
}

remove_action( 'admin_enqueue_scripts', 'genesis_load_admin_scripts' );
add_action( 'admin_enqueue_scripts', 'somo_load_admin_scripts' );

/**
 * Conditionally enqueue the scripts used in the admin.
 *
 * @since 1.0.0
 *
 * @uses somo_load_admin_js() Enqueues the custom script and localizations used in the admin.
 * @uses genesis_is_menu_page()  Check that we're targeting a specific Genesis admin page.
 * @uses genesis_update_check()  Ping http://api.genesistheme.com/ asking if a new version of this theme is available.
 * @uses genesis_seo_disabled()  Detect whether or not Genesis SEO has been disabled.
 *
 * @global WP_Post $post Post object.
 *
 * @param string $hook_suffix Admin page identifier.
 */
function somo_load_admin_scripts( $hook_suffix ) {

	//* Only add thickbox/preview if there is an update available
	if ( somo_update_check() ) {
		add_thickbox();
		wp_enqueue_script( 'theme-preview' );
		somo_load_admin_js();
	}

	//* If we're on a Genesis admin screen
//	if ( genesis_is_menu_page( 'genesis' ) || genesis_is_menu_page( 'seo-settings' ) || genesis_is_menu_page( 'design-settings' ) )
//		somo_load_admin_js();
	//* If we're on an admin screen
	if ( genesis_is_menu_page( 'genesis' ) || genesis_is_menu_page( 'somo-seo-settings' ) || genesis_is_menu_page( 'somo-social-settings' ) || genesis_is_menu_page( 'somo-quick-setup' ) )
		somo_load_admin_js();

	global $post;

	//* If we're viewing an edit post page, make sure we need Genesis SEO JS
	if ( in_array( $hook_suffix, array( 'post-new.php', 'post.php' ) ) ) {
		if ( !genesis_seo_disabled() && post_type_supports( $post->post_type, 'genesis-seo' ) )
			somo_load_admin_js();
	}
	if ( genesis_is_menu_page( 'genesis' ) ) {
		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
		wp_enqueue_script( 'somo_admin_js', SOMO_JS_URL . "/admin$suffix.js", array( ), SOMO_PARENT_THEME_VERSION, true );
	}
}

/**
 * Just in case genesis_load_admin_js gets called directly e.g. via layout selector
 */
add_filter( 'genesis_toggles', 'somo_toggles', 10, 1 );

/**
 *
 * Uses the `somo_toggles` filter to add additional toggleable admin settings
 *
 * @param array $toggles
 * @return array $toggles
 */
function somo_toggles( $toggles = array( ) ) {
	$toggles = array(
		// Checkboxes - when checked, show extra settings
		'update' => array( '#somo-settings\\[update\\]', '#somo_update_notification_setting', '_checked' ),
		'content_archive_thumbnail' => array( '#somo-settings\\[content_archive_thumbnail\\]', '#genesis_image_size', '_checked' ),
		// Checkboxed - when unchecked, show extra settings
		'semantic_headings' => array( '#somo-seo-settings\\[semantic_headings\\]', '#genesis_seo_h1_wrap', '_unchecked' ),
		// Select toggles
		'content_archive' => array( '#somo-settings\\[content_archive\\]', '#genesis_content_limit_setting', 'full' ),
		'enable_opengraph' => array( '#somo-social-settings\\[enable_opengraph\\]', '#somo_opengraph_setting', '_checked' ),
		'head_instant_pages' => array( '#somo-seo-settings\\[head_instant_pages\\]', '#somo_rel_markup_setting', '_unchecked' ),
		'advanced_oneclick' => array( '#somo-oneclick-advanced', '#somo_oneclick_setting', '_checked' ),
		'advanced_cleanup' => array( '#somo-cleanup-advanced', '#somo_cleanup_setting', '_checked' ),
	);
	return apply_filters( 'somo_toggles', $toggles );
}

/**
 * Enqueues the custom script used in the admin, and localizes several strings or values used in the scripts.
 *
 * Applies the `somo_toggles` filter to toggleable admin settings, so plugin developers can add their own without
 * having to recreate the whole setup.
 *
 * @since 1.8.0
 *
 * @uses GENESIS_JS_URL
 * @uses PARENT_THEME_VERSION
 */
function somo_load_admin_js() {

	$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
	wp_enqueue_script( 'genesis_admin_js', GENESIS_JS_URL . "/admin$suffix.js", array( 'jquery' ), SOMO_PARENT_THEME_VERSION, true );

	$strings = array(
		'categoryChecklistToggle' => __( 'Select / Deselect All', 'genesis' ),
		'saveAlert' => __( 'The changes you made will be lost if you navigate away from this page.', 'genesis' ),
		'confirmUpgrade' => sprintf( __( 'Updating %s will overwrite the currently installed version of %s. Are you sure you want to update?. "Cancel" to stop, "OK" to update.', 'somo' ), SOMO_PARENT_THEME_NAME, SOMO_PARENT_THEME_NAME ),
		'confirmReset' => __( 'Are you sure you want to reset?', 'genesis' ),
	);

	wp_localize_script( 'genesis_admin_js', 'genesisL10n', $strings );

	$toggles = somo_toggles();
	wp_localize_script( 'genesis_admin_js', 'genesis_toggles', $toggles );
}

add_action( 'admin_enqueue_scripts', 'somo_pointer_load', 1000 );

/**
 * Load feature pointers, helping users navigate theme features
 *
 * @since 1.0.0
 *
 * @link http://wp.tutsplus.com/tutorials/integrating-with-wordpress-ui-admin-pointers/
 */
function somo_pointer_load() {

	// Don't run on WordPress < 3.3
	if ( get_bloginfo( 'version' ) < '3.3' )
		return;

	$screen = get_current_screen();
	$screen_id = $screen->id;

	// Get pointers for this screen
	$pointers = apply_filters( 'somo_admin_pointers_' . $screen_id, array( ) );

	if ( !$pointers || !is_array( $pointers ) )
		return;

	// Get dismissed pointers
	$dismissed = explode( ',', ( string ) get_user_meta( get_current_user_id(), 'dismissed_wp_pointers', true ) );
	$valid_pointers = array( );

	// Check pointers and remove dismissed ones.
	foreach ( $pointers as $pointer_id => $pointer ) {

		// Sanity check
		if ( in_array( $pointer_id, $dismissed ) || empty( $pointer ) || empty( $pointer_id ) || empty( $pointer[ 'target' ] ) || empty( $pointer[ 'options' ] ) )
			continue;

		$pointer[ 'pointer_id' ] = $pointer_id;

		// Add the pointer to $valid_pointers array
		$valid_pointers[ 'pointers' ][ ] = $pointer;
	}

	// No valid pointers? Stop here.
	if ( empty( $valid_pointers ) )
		return;

	// Add pointers style to queue.
	wp_enqueue_style( 'wp-pointer' );

	// Add pointers script to queue. Add custom script.
	$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
	wp_enqueue_script( 'somo-pointer', SOMO_JS_URL . "/somo.pointer$suffix.js", array( 'wp-pointer' ) );

	// Add pointer options to script.
	wp_localize_script( 'somo-pointer', 'somoPointer', $valid_pointers );
}

