<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization via functions.php file.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
add_shortcode( 'footer_somothemes_link', 'somo_footer_somothemes_link_shortcode' );

/**
 * Adds a footer link to the SomoThemes page on the SomoThemes website. If user has specified an affiliate ID,
 * it will be added to the target link. Applies somo_footer_somothemes_link_shortcode filter to the output.
 *
 * @uses genesis_get_option
 * @uses add_query_arg
 * @uses shortcode_atts
 *
 * @since 1.0.0
 *
 * @param array $atts		Arguments array
 * @return string			Formatted html output
 */
function somo_footer_somothemes_link_shortcode( $atts ) {

	$defaults = array(
		'after' => '',
		'before' => '',
		'url' => 'http://somothemes.com/',
	);

	$aff = genesis_get_option( 'somo_affiliate_id' );
	if ( $aff )
		$defaults[ 'url' ] = add_query_arg( 'aff', $aff, $defaults[ 'url' ] );

	$atts = shortcode_atts( $defaults, $atts );

	$output = $atts[ 'before' ] . '<a href="' . esc_url( $atts[ 'url' ] ) . '" title="SomoThemes">SomoThemes</a>' . $atts[ 'after' ];

	return apply_filters( 'somo_footer_somothemes_link_shortcode', $output, $atts );
}

add_shortcode( 'footer_theme_link', 'somo_footer_theme_link_shortcode' );

/**
 * Adds link to the SomoThemes Theme page on the SomoThemes website. If user has specified an affiliate ID,
 * it will be added to the target link. Applies somo_footer_theme_link_shortcode filter to the output.
 *
 * @uses genesis_get_option
 * @uses add_query_arg
 * @uses shortcode_atts
 * @uses SOMO_PARENT_THEME_URL
 * @uses SOMO_PARENT_THEME_NAME
 *
 * @since 1.0.0
 *
 * @param array $atts		Arguments array
 * @return string			Formatted html output
 */
function somo_footer_theme_link_shortcode( $atts ) {

	if ( !defined( 'SOMO_PARENT_THEME_NAME' ) || !defined( 'SOMO_PARENT_THEME_URL' ) )
		return;

	$defaults = array(
		'after' => '',
		'before' => '&#x000B7;',
	);
	$atts = shortcode_atts( $defaults, $atts, 'footer_theme_link' );

	$aff = trim( genesis_get_option( 'somo_affiliate_id' ) );
	if ( $aff )
		$url = add_query_arg( array( 'aff' => $aff, 'stid' => SOMO_PARENT_THEME_SLUG ), SOMO_PARENT_THEME_URL );
	else
		$url = SOMO_PARENT_THEME_URL;

	$output = sprintf( '%s<a href="%s" title="%s">%s</a>%s', $atts[ 'before' ], esc_url( $url ), esc_attr( SOMO_PARENT_THEME_NAME ), esc_html( SOMO_PARENT_THEME_NAME ), $atts[ 'after' ] );

	return apply_filters( 'somo_footer_theme_link_shortcode', $output, $atts );
}

