<?php
/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization via functions.php file.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
/**
 * Add mobile navigation flyout menu toggle buttons
 *
 * @since 1.0.0
 *
 * @uses current_theme_supports
 */
add_action( 'genesis_setup', 'somo_setup_flyout_menus' );

function somo_setup_flyout_menus() {
	if ( current_theme_supports( 'somo-flyout-menus' ) ) {
		add_action( 'genesis_before', 'somo_add_menu_toggle_buttons' );

		add_filter( 'genesis_attr_mnav-primary', 'genesis_attributes_mnav_primary' );
		add_filter( 'genesis_attr_mnav-secondary', 'genesis_attributes_mnav_secondary' );
		add_filter( 'genesis_attr_mnav-mobile', 'genesis_attributes_mnav_mobile' );

		add_filter( 'body_class', 'somo_add_body_class_flyout_menu' );
	}
}

function somo_add_body_class_flyout_menu( $classes ) {
	if ( current_theme_supports( 'somo-flyout-menus' ) ) {
		$classes[ ] = 'somo-flyout-menu';
	}
	return $classes;
}

/**
 * Output mobile menu toggle buttons
 *
 * @since 1.0.0
 *
 * @uses genesis_nav_menu_supported
 * @uses has_nav_menu
 *
 * @see lib\js\somo.menu.js
 * @see lib\js\somo.menu.min.js
 */
function somo_add_menu_toggle_buttons() {
	if ( !current_theme_supports( 'somo-flyout-menus' ) ) {
		return;
	}
	if ( ( genesis_nav_menu_supported( 'primary' ) && has_nav_menu( 'primary' ) ) ||
		( genesis_nav_menu_supported( 'secondary' ) && has_nav_menu( 'secondary' ) ) ||
		( genesis_nav_menu_supported( 'mobile' ) && has_nav_menu( 'mobile' ) ) ) {
		?>

		<div class="flyout-menu">
			<div class="flyout-menu-buttons">

				<a href="#flyout-menu" class="menu-toggle-open">Menu</a>
				<span id="flyout-menu-close"></span>
				<div class="menu-toggle" id="flyout-menu">
					<div class="menu-toggle-close-container">
						<a href="#flyout-menu-close" class="menu-toggle-close">×</a>
					</div>
					<div class="mobile-menu-container">
						<?php
						somo_add_flyout_menu_content();
						?>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
	?>
	<div class="clear"></div>
	<?php
}

/**
 * Generate and output mobile menu. Applies genesis_do_nav and genesis_do_subnav filters to
 * primary and secondary mobile navigation menus respoectively.
 *
 * @since 1.0.0
 *
 * @uses genesis_nav_menu_supported
 * @uses has_nav_menu
 * @uses genesis_superfish_enabled
 * @uses wp_nav_menu
 * @uses genesis_markup
 * @uses genesis_structural_wrap
 * @uses genesis_html5
 */
function somo_add_flyout_menu_content() {

	if ( '1' === genesis_get_option( 'mobile_nav_extras' ) ) {
		echo '<div class="search-form-container">';
		get_search_form();
		echo '</div>';
	}

	if ( genesis_nav_menu_supported( 'mobile' ) && has_nav_menu( 'mobile' ) ) {

		$class = 'menu somo-mobile-nav-menu mobile-menu mnav';
		if ( genesis_superfish_enabled() )
			$class .= ' js-superfish';

		$args = array(
			'theme_location' => 'mobile',
			'container' => '',
			'menu_class' => $class,
			'echo' => 0,
		);

		$nav = wp_nav_menu( $args );
		if ( $nav ) {
			$nav_markup_open = genesis_markup( array(
				'html5' => '<nav %s>',
				'xhtml' => '<div id="mnav">',
				'context' => 'mnav-mobile',
				'echo' => false,
				) );
			$nav_markup_open .= genesis_structural_wrap( 'mobile-menu', 'open', 0 );

			$nav_markup_close = genesis_structural_wrap( 'mobile-menu', 'close', 0 );
			$nav_markup_close .= genesis_html5() ? '</nav>' : '</div>';

			$nav_output = $nav_markup_open . $nav . $nav_markup_close;

			echo apply_filters( 'somo_do_mobile_nav_mobile', $nav_output, $nav, $args );
		}

		return; //* Do not show other menus if mobile menu is set.
	}

	if ( genesis_nav_menu_supported( 'primary' ) && has_nav_menu( 'primary' ) ) {
		remove_filter( 'wp_nav_menu_items', 'genesis_nav_right', 10, 2 );
		$class = 'menu somo-mobile-nav-menu mobile-menu-primary mnav';
		if ( genesis_superfish_enabled() )
			$class .= ' js-superfish';

		$args = array(
			'theme_location' => 'primary',
			'container' => '',
			'menu_class' => $class,
			'echo' => 0,
		);

		$nav = wp_nav_menu( $args );
		if ( $nav ) {
			$nav_markup_open = genesis_markup( array(
				'html5' => '<nav %s>',
				'xhtml' => '<div id="mnav">',
				'context' => 'mnav-primary',
				'echo' => false,
				) );
			$nav_markup_open .= genesis_structural_wrap( 'mobile-menu-primary', 'open', 0 );

			$nav_markup_close = genesis_structural_wrap( 'mobile-menu-primary', 'close', 0 );
			$nav_markup_close .= genesis_html5() ? '</nav>' : '</div>';

			$nav_output = $nav_markup_open . $nav . $nav_markup_close;

			echo apply_filters( 'somo_do_mobile_nav_primary', $nav_output, $nav, $args );
		}
		add_filter( 'wp_nav_menu_items', 'genesis_nav_right', 10, 2 );
	}

	if ( genesis_nav_menu_supported( 'secondary' ) && has_nav_menu( 'secondary' ) ) {

		$class = 'menu somo-mobile-nav-menu mobile-menu-secondary mnav';
		if ( genesis_superfish_enabled() )
			$class .= ' js-superfish';

		$args = array(
			'theme_location' => 'secondary',
			'container' => '',
			'menu_class' => $class,
			'echo' => 0,
		);

		$subnav = wp_nav_menu( $args );

		if ( $subnav ) {
			$subnav_markup_open = genesis_markup( array(
				'html5' => '<nav %s>',
				'xhtml' => '<div id="subnav">',
				'context' => 'mnav-secondary',
				'echo' => false,
				) );
			$subnav_markup_open .= genesis_structural_wrap( 'mobile-menu-secondary', 'open', 0 );

			$subnav_markup_close = genesis_structural_wrap( 'mobile-menu-secondary', 'close', 0 );
			$subnav_markup_close .= genesis_html5() ? '</nav>' : '</div>';

			$subnav_output = $subnav_markup_open . $subnav . $subnav_markup_close;

			echo apply_filters( 'somo_do_mobile_nav_secondary', $subnav_output, $subnav, $args );
		}
	}
}

/**
 * Add attributes for primary mobile navigation element.
 *
 * @since 1.0.0
 *
 * @param array $attributes		Existing attributes
 * @return array				Amended attributes
 */
function genesis_attributes_mnav_primary( $attributes ) {

	$attributes[ 'role' ] = 'navigation';
	$attributes[ 'itemscope' ] = 'itemscope';
	$attributes[ 'itemtype' ] = 'http://schema.org/SiteNavigationElement';

	return $attributes;
}

/**
 * Add attributes for secondary mobile navigation element.
 *
 * @since 1.0.0
 *
 * @param array $attributes		Existing attributes
 * @return array				Amended attributes
 */
function genesis_attributes_mnav_secondary( $attributes ) {

	$attributes[ 'role' ] = 'navigation';
	$attributes[ 'itemscope' ] = 'itemscope';
	$attributes[ 'itemtype' ] = 'http://schema.org/SiteNavigationElement';

	return $attributes;
}

/**
 * Add attributes for single mobile navigation element.
 *
 * @since 1.0.0
 *
 * @param array $attributes		Existing attributes
 * @return array				Amended attributes
 */
function genesis_attributes_mnav_mobile( $attributes ) {

	$attributes[ 'role' ] = 'navigation';
	$attributes[ 'itemscope' ] = 'itemscope';
	$attributes[ 'itemtype' ] = 'http://schema.org/SiteNavigationElement';

	return $attributes;
}
