<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization via functions.php file.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
add_filter( 'genesis_author_box', 'somo_author_box', 10, 6 );

/**
 * Modify the author box to add social profiles with Google Authorship markup.
 *
 * Applies following filters - genesis_author_box_gravatar_size, genesis_author_box_title and somo_author_box
 *
 * @since 1.0.0
 * 
 * @uses get_userdata
 * @uses get_avatar
 * @uses wpautop
 * @uses somo_add_author_social_profiles
 * @uses get_query_var
 *
 * @global WP_User $authordata	The current author's DB object
 *
 *
 * @return string				HTML formatted output
 */
function somo_author_box( $arg = '', $context = '', $pattern = '', $gravatar = '', $title = '', $description = '' ) {

	global $authordata;

	$authordata = is_object( $authordata ) ? $authordata : get_userdata( get_query_var( 'author' ) );
	$gravatar_size = apply_filters( 'genesis_author_box_gravatar_size', 70, $context );
	$gravatar = get_avatar( get_the_author_meta( 'email' ), $gravatar_size );
	$description = wpautop( get_the_author_meta( 'description' ) );
	//* Add author social profiles
	$description .= somo_add_author_social_profiles( ( is_object( $authordata ) ? $authordata->ID : get_query_var( 'author' ) ), $context );

	//* The author box markup, contextual
	if ( genesis_html5() ) {

		$title = apply_filters( 'genesis_author_box_title', sprintf( '%s <span itemprop="name">%s</span>', __( 'About', 'genesis' ), get_the_author() ), $context );

		$pattern = sprintf( '<section %s>', genesis_attr( 'author-box' ) );
		$pattern .= '%s<h1 class="author-box-title">%s</h1>';
		$pattern .= '<div class="author-box-content" itemprop="description">%s</div>';
		$pattern .= '</section>';
	} else {

		$title = apply_filters( 'genesis_author_box_title', sprintf( '<strong>%s %s</strong>', __( 'About', 'genesis' ), get_the_author() ), $context );
		$pattern = 'single' === $context ? '<div class="author-box"><div>%s %s<br />%s</div></div>' : '<div class="author-box">%s<h1>%s</h1><div>%s</div></div>';
	}

	$output = apply_filters( 'somo_author_box', sprintf( $pattern, $gravatar, $title, $description ), $context, $pattern, $gravatar, $title, $description );

	return $output;
}

add_filter( 'genesis_author_box_gravatar_size', 'somo_author_box_gravatar_size' );

/**
 * Modify the size of the Gravatar in the author box
 *
 * @since 1.0.0
 *
 * @param string $size		Existing gravatar size
 * @return string			New gravatar size
 */
function somo_author_box_gravatar_size( $size ) {
	return '90';
}
